(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    158175,       4300]*)
(*NotebookOutlinePosition[    159140,       4330]*)
(*  CellTagsIndexPosition[    159096,       4326]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Einstellungen", "Section"],

Cell[BoxData[
    \(\(<< Graphics`;\)\)], "Input"],

Cell["Hier wird die Test-Ausgabe geregelt.", "Text"],

Cell[BoxData[
    StyleBox[\(test\  = \ False;\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]], "Input"],

Cell["Hier wird die Status-Ausgabe geregelt.      ", "Text"],

Cell[BoxData[
    StyleBox[\(status\  = \ True;\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[0, 1, 0]]], "Input"],

Cell["\<\
Hier wird Speichern / Laden eingestellt: Speichern = True, Lesen = False \
\>", "Text"],

Cell[BoxData[
    StyleBox[\(SaveOrLoad\  = \ False; \ filename = "\<4er\>";\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[0, 0, 1]]], "Input"],

Cell["Hier wird die Zahl der Rechnungen eingestellt.", "Text"],

Cell[BoxData[
    StyleBox[\(loops\  = \ 1;\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 1]]], "Input"],

Cell["Hier wird die Darstellung geregelt.", "Text"],

Cell[BoxData[
    StyleBox[\(colors\  = \ 
          Join[{{Black}}, Table[{Dashing[{0.01}], Hue[i/5]}, {i, 1, 5}]];\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[0, 1, 1]]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Diplomarbeit \"Dynamik klassischer Spinsysteme\"", "Title"],

Cell[CellGroupData[{

Cell["Definitionen", "Section"],

Cell[CellGroupData[{

Cell["Systeme", "Subsection"],

Cell[CellGroupData[{

Cell["Ketten", "Subsubsection"],

Cell["An dieser Stelle werden Spin-Ketten definiert.", "Text"],

Cell[BoxData[{\(string2\  = \ {{1, 
            2}};\), "\[IndentingNewLine]", \(string3\  = \ 
        Append[string2, {2, 3}];\), "\[IndentingNewLine]", \(string4\  = \ 
        Append[string3, {3, 4}];\), "\[IndentingNewLine]", \(string5\  = \ 
        Append[string4, {4, 5}];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox["string5",
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ringe", "Subsubsection"],

Cell["An dieser Stelle werden Spin-Ringe definiert.      ", "Text"],

Cell[BoxData[{\(ring3\  = 
        Append[string3, {3, 1}];\), "\[IndentingNewLine]", \(ring4\  = 
        Append[string4, {4, 1}];\), "\[IndentingNewLine]", \(ring5\  = 
        Append[string5, {5, 1}];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, ring5]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sterne", "Subsubsection"],

Cell["An dieser Stelle werden Spin-Sterne definiert.", "Text"],

Cell[BoxData[{\(star5 = {{1, 5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, star5]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Weitere", "Subsubsection"],

Cell[BoxData[{\(ring4with1d\  = \ 
        Append[ring4, {1, 3}];\), "\[IndentingNewLine]", \(ring4with2d\  = \ 
        Append[ring4with1d, {2, 
            4}];\), "\[IndentingNewLine]", \(T1\  = \ {{1, 2}, {2, 3}, {3, 
            4}, {2, 4}};\), "\[IndentingNewLine]", 
    RowBox[{\(T2\  = \ {{1, 2}, {2, 3}, {2, 4}};\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(all4 = {string4, ring4, ring4with1d, ring4with2d, T1, T2};\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(A5 = {{1, 2}, {2, 
            3}, {3, 4}, {4, 1}, {4, 
            5}};\), "\[IndentingNewLine]", \(B5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {4, 
            5}};\), "\[IndentingNewLine]", \(C5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {4, 
            5}};\), "\[IndentingNewLine]", \(D5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {2, 4}, {4, 
            5}};\), "\[IndentingNewLine]", \(E5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 5}};\), "\[IndentingNewLine]", \(F5 = {{1, 2}, {2, 
            3}, {2, 4}, {3, 4}, {4, 
            5}};\), "\[IndentingNewLine]", \(G5\  = {{1, 2}, {2, 3}, {3, 
            4}, {3, 5}};\), "\[IndentingNewLine]", \(H5\  = {{1, 2}, {2, 
            3}, {3, 4}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(I5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 5}, {5, 1}};\), "\[IndentingNewLine]", \(J5 = {{1, 
            5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(K5 = {{1, 5}, {2, 5}, {3, 
            4}, {3, 5}, {4, 5}};\), "\[IndentingNewLine]", \(L5 = {{1, 
            2}, {1, 5}, {2, 5}, {3, 4}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(M5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(N5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(O5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {2, 4}, {1, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(P5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 5}, {3, 
            5}};\), "\[IndentingNewLine]", \(Q5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {3, 
            5}};\), "\[IndentingNewLine]", \(R5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {1, 5}, {3, 
            5}};\), "\[IndentingNewLine]", \(S5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(T5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {2, 4}, {1, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(U5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(V5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", 
    RowBox[{\(W5 = {{1, 2}, {2, 3}, {3, 4}, {4, 1}, {1, 3}, {2, 4}, {1, 
              5}, {2, 5}, {3, 5}, {4, 5}};\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(notint5\  = \ {A5, 
          B5, E5, F5, G5, H5, I5, M5, 
          N5};\), "\[IndentingNewLine]", \(int5\  = \ {C5, D5, J5, K5, L5, 
          05, P5, Q5, R5, S5, T5, U5, V5, W5};\), "\[IndentingNewLine]", 
    RowBox[{\(all5\  = \ Append[notint5, int5];\), "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[\(If[test, int5]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spin-Variablen", "Subsection"],

Cell[BoxData[{\(s[\[Mu]_] = 
        Table[\(s[\[Mu], i]\)[t], {i, 1, 3}];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, MatrixForm[s[\[Mu]]]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ljaponov-Exponenten", "Section"],

Cell[CellGroupData[{

Cell["Unterprogramme", "Subsection"],

Cell[BoxData[
    \(Dieses\ Unterprogramm\ liefert\ die\ Kopplungsmatrix\ J\_\(\(\[Mu]\[Nu]\
\)\(.\)\)\)], "Text",
  FontFamily->"Times"],

Cell[BoxData[{\(getJ[N_, coupling_, strength_]\  := \ 
        Module[{\[Mu], \[Nu]}, \[IndentingNewLine]J\  = \ 
            Table[If[
                MemberQ[coupling, {\[Mu], \[Nu]}] || 
                  MemberQ[coupling, {\[Nu], \[Mu]}], strength, 0], {\[Mu], 1, 
                N}, {\[Nu], 1, 
                N}]; \ \[IndentingNewLine]J];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, MatrixForm[getJ[2, string2, 1]]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[BoxData[
    \(Dieses\ Unterprogramm\ liefert\ die\ Hamiltonschen\ \
Bewegungsgleichungen . \[IndentingNewLine]H\  = \ \(\[Sum]\+\(\[Mu]\  < \ \
\[Nu]\)J\_\[Mu]\[Nu]\ s\_\[Mu]*
            s\_\[Nu]\ und\ s\& . \_\[Mu]\  = \ \(\[PartialD]\ H\/\[PartialD]\ \
s\_\(\_\[Mu]\)\ x\ s\_\[Mu]\ \  \[Rule] \ 
            s\& . \_\[Mu]\  = \ \[Sum]\+\(\[Mu]\  < \ \
\[Nu]\)\(\(J\_\[Mu]\[Nu]\)\(\ \)\(s\_\[Nu]\)\(\ \)\(x\)\(\ \)\(s\_\[Mu]\)\(\ \
\)\)\)\)\)], "Text",
  FontFamily->"Times"],

Cell[BoxData[{\(getEquations[N_, coupling_, strength_]\  := \ 
        Module[{\[Mu], \[Nu], i}, \[IndentingNewLine]J\  = \ 
            getJ[N, coupling, strength]; \[IndentingNewLine]equations\  = \ 
            Table[\(s[\[Mu], i]'\)[t] == \ 
                Sum[J[\([\[Mu], \[Nu]]\)]\ *\ \(Cross[s[\[Nu]], 
                        s[\[Mu]]]\)[\([i]\)], {\[Nu], 1, N}], {\[Mu], 1, 
                N}, {i, 1, 
                3}]; \[IndentingNewLine]equations];\), "\[IndentingNewLine]", 
  
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, getEquations[2, string2, 1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert die Anfangsbedingungen.", "Text"],

Cell[BoxData[{\(getInit[v_]\  := \ 
        Module[{N, init, \[Mu], i}, \[IndentingNewLine]N\  = \ 
            First[Dimensions[v]]; \[IndentingNewLine]init = 
            Table[\(s[\[Mu], i]\)[0] \[Equal] v[\([\[Mu], i]\)], {\[Mu], 1, 
                N}, {i, 1, 
                3}]; \[IndentingNewLine]init];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(getInit[{{0, 0, 1}}]\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert das DGL-System.", "Text"],

Cell[BoxData[{\(getSystem[equations_, v_]\  := \ 
        Module[{init}, \[IndentingNewLine]init\  = 
            getInit[v]; \[IndentingNewLine]Join[init, 
            equations]];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, 
        getSystem[getEquations[2, string2, 1], {{1, 0, 0}, {0, 1, 0}}]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[BoxData[{\(getVar[N_]\  := \ 
        Module[{var, \[Mu]}, \[IndentingNewLine]var\  = \ 
            Table[s[\[Mu]], {\[Mu], 1, 
                N}]; \[IndentingNewLine]var];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, getVar[2]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[BoxData[{\(getSolution[system_, var_, \[CapitalDelta]t_]\  := \ 
        Module[{solution}, \[IndentingNewLine]solution\  = \ 
            Flatten[NDSolve[Flatten[system], 
                Flatten[var], {t, 0, \[CapitalDelta]t}, 
                Method \[Rule] RungeKutta]]; \[IndentingNewLine]\(var\  //. \ 
              solution\)\  //. \ 
            t \[Rule] \ \[CapitalDelta]t];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, 
        getSolution[
          getSystem[getEquations[2, string2, 1], {{1, 0, 0}, {0, 1, 0}}], 
          getVar[2], 1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm f\[UDoubleDot]hrt die Zeitentwicklung durch.", \
"Text"],

Cell[BoxData[{\(flow[equations_, var_, v_, \[CapitalDelta]t_]\  := \ 
        Module[{system, solution}, \[IndentingNewLine]system\  = \ 
            getSystem[equations, v]; \[IndentingNewLine]solution = \ 
            getSolution[system, 
              var, \[CapitalDelta]t]; \[IndentingNewLine]solution];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, 
        flow[getEquations[2, string2, 1], getVar[2], {{1, 0, 0}, {0, 1, 0}}, 
          1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm berechnet den Betrag eines Vektors.", "Text"],

Cell[BoxData[{\(norm[v_] := Sqrt[v . v];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, norm[{1, 0, 0}]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramme liefern zuf\[ADoubleDot]llige Einheitsvektoren.", \
"Text"],

Cell[BoxData[{\(generate\  := \ 
        Module[{v}, \[IndentingNewLine]v\  = \ {2*Random[] - 1, 
              2*Random[] - 1, 2*Random[] - 1}; \[IndentingNewLine]v\  = \ 
            v\ /\ norm[v]; \[IndentingNewLine]v];\), "\[IndentingNewLine]", 
    RowBox[{\(generateAll[N_]\  := \ 
          Module[{v, \[Mu]}, \[IndentingNewLine]v\  = \ 
              Table[generate, {\[Mu], 1, N}]; \[IndentingNewLine]v];\), 
      "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[\(If[test, generateAll[1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[TextData[{
  "Dieses Unterprogramm wandelt den Vektor \[Omega] in eine antysymmetrische \
Matrix \[CapitalOmega] um.\nDie Signatur nimmt die Werte ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\))\)\^n\ an . \ 
          Dabei\ ist\ n\ die\ Zahl\ der\ ben\[ODoubleDot]tigten\ \
Transpositionen\ f\[UDoubleDot]r\ das\ Erreichen\ einer\ kanonische\ \
\(\(Reihenfolge\)\(.\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(\[CapitalOmega]\_ij\  = \ \(-\(\[Sum]\+k 
            signatur \((i, j, k)\)*\ \[Omega]\_k\)\)\)], "Text"],

Cell[BoxData[{\(getMatrix[\[Omega]_]\  := \ 
        Module[{i, j, k}, \[IndentingNewLine]\ \[CapitalOmega]\  = 
            Table[\(-Sum[
                  Signature[{i, j, k}] \[Omega][\([k]\)], {k, 1, 3}]\), {i, 
                1, 3}, {j, 1, 
                3}]; \[IndentingNewLine]\ \[CapitalOmega]];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(MatrixForm[getMatrix[{0, 0, 1}]]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm erstellt eine Drehmatrix zu der Drehachse \[Omega] und \
dem Winkel \[CurlyPhi] = |w| t.\
\>", "Text"],

Cell[BoxData[
    \(R\_ij\  = \ \(\[Delta]\_ij\) 
          cos\[CurlyPhi]\  + \ \(e\_i\) \(e\_j\) \((1 - 
              cos\[CurlyPhi])\)\  + \ \(\[CapitalOmega]\_ij\) 
          sin\[CurlyPhi]\)], "Text"],

Cell[BoxData[{
    RowBox[{\(getRotation[\[Omega]_, t_]\ \  := \ 
          Module[{e, \[CurlyPhi], \[CapitalOmega], i, j, 
              R}, \[IndentingNewLine]e = \ \[Omega]/
                norm[\[Omega]]; \[IndentingNewLine]\[CurlyPhi]\  = \ 
              norm[\[Omega]]\ *\ t; \[IndentingNewLine]\[CapitalOmega]\  = \ 
              getMatrix[e]; \[IndentingNewLine]R = 
              Table[If[i \[Equal] j, Cos[\[CurlyPhi]], 0] + 
                  e[\([i]\)] 
                    e[\([j]\)] \((1 - 
                        Cos[\[CurlyPhi]])\) + \[CapitalOmega][\([i, j]\)] 
                    Sin[\[CurlyPhi]], {i, 1, 3}, {j, 1, 
                  3}]; \[IndentingNewLine]R];\), "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(MatrixForm[getRotation[{0, 0, 1}, Pi/2]]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm liefert die normierte Drehachse \[Omega] = a x b.\
\>", "Text"],

Cell[BoxData[{\(getAxes[a_, b_]\  := \ 
        Module[{\[Omega], e}, \[IndentingNewLine]\[Omega]\  = \ 
            Cross[a, b]; \[IndentingNewLine]e\  = \ \[Omega]/
              norm[\[Omega]]; \[IndentingNewLine]e];\), "\[IndentingNewLine]",
   
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, getAxes[{1, 0, 0}, {0, 1, 0}]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert den Winkel zwischen a und b.", "Text"],

Cell[BoxData[{\(getAngle[a_, b_]\  := \ 
        Module[{\[CurlyPhi]}, \[IndentingNewLine]\[CurlyPhi]\  = \ 
            ArcCos[a . 
                  b\ /\ \((norm[a]\ *\ 
                    norm[b])\)]; \[IndentingNewLine]\[CurlyPhi]];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(getAngle[{1, 0, 0}, {0, 1, 0}]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert die Drehmatrix von a nach b.", "Text"],

Cell[BoxData[{\(getRotationFromTo[a_, b_] := 
        Module[{e, \[CurlyPhi], R}, \[IndentingNewLine]e\  = \ 
            getAxes[a, b]; \[IndentingNewLine]\[CurlyPhi]\  = \ 
            getAngle[a, b]; \[IndentingNewLine]R\  = \ 
            getRotation[
              e, \[CurlyPhi]]; \[IndentingNewLine]R];\), \
"\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(MatrixForm[getRotationFromTo[{1, 0, 0}, {0, 1, 0}]]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm erzeugt einen Vektor c, der auf dem Gro\[SZ]kreis durch \
a und b liegt und den Abstand d(a,c) = \[Delta] hat.\
\>", "Text"],

Cell[BoxData[{\(shrink[a_, b_, \[Delta]_]\  := \ 
        Module[{e, R, c}, \[IndentingNewLine]e = 
            getAxes[a, b]; \[IndentingNewLine]R\  = \ 
            getRotation[e, \[Delta]]; \[IndentingNewLine]c\  = \ 
            R . a; \[IndentingNewLine]c];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0],
      Background->None], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(shrink[{1, 0, 0}, {0, 1, 0}, Pi/2]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0],
      Background->None]}], "Input"],

Cell["\<\
Dieses Unterprogramm erweitert die Funktion auf mehrere Vektoren.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{\(shrinkAll[a_, b_, \[Delta]_]\  := \ 
          Module[{N, \[CurlyPhi], \[Phi], 
              c, \[Mu]}, \[IndentingNewLine]N\  = \ 
              First[Dimensions[a]]; \[IndentingNewLine]\[CurlyPhi]\  = \ 
              Table[getAngle[a[\([\[Mu]]\)], b[\([\[Mu]]\)]], {\[Mu], 1, 
                  N}]; \[IndentingNewLine]\[Phi]\  = \ 
              Sqrt[Sum[\[CurlyPhi][\([\[Mu]]\)]^2, {\[Mu], 1, 
                    N}]]; \[IndentingNewLine]c\  = \ 
              Table[shrink[a[\([\[Mu]]\)], 
                  b[\([\[Mu]]\)], \[Delta]/\[Phi]\ *\ \
\[CurlyPhi][\([\[Mu]]\)]], {\[Mu], 1, N}]; \[IndentingNewLine]{c, \[Phi]}];\),
       "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(shrinkAll[{{1, 0, 0}}, {{0, 1, 0}}, Pi/2]\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm zeigt den Status der Rechnung in Prozent an.\
\>", "Text"],

Cell[BoxData[{\(showPercentage[i_, max_]\  := \ 
        Module[{percentage}, \[IndentingNewLine]percentage\  = \ 
            i/\((max/100)\); \[IndentingNewLine]If[
            Mod[percentage, 10]\  \[Equal] \ 0, 
            Print[percentage\ "\<%\>"\ ]];\[IndentingNewLine]];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, showPercentage[10, 100]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm gibt das Erbenis der Rechnung aus.    ", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(showResults[results_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          RowBox[{\({loglogresults, g}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(loglogresults\  = \ N[Log[10, results]]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"g", " ", "=", 
                RowBox[{"MultipleListPlot", "[", 
                  RowBox[{
                  "loglogresults", ",", 
                    "\[IndentingNewLine]", \(PlotJoined \[Rule] True\), ",", 
                    "\[IndentingNewLine]", \(PlotRange \[Rule] Automatic\), 
                    ",", "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
                    "\[IndentingNewLine]", \(Ticks \[Rule] \ {LogScale, 
                        LogScale}\), ",", 
                    "\[IndentingNewLine]", \(Frame \[Rule] True\), ",", 
                    "\[IndentingNewLine]", \(FrameTicks \[Rule] {LogScale, 
                        LogScale}\), ",", 
                    "\[IndentingNewLine]", \(SymbolShape \[Rule] None\), ",", 
                    "\[IndentingNewLine]", 
                    StyleBox[\(PlotStyle \[Rule] colors\),
                      FontColor->RGBColor[0, 1, 1]], 
                    StyleBox[",",
                      FontColor->RGBColor[0, 1, 1]], 
                    "\[IndentingNewLine]", \(FrameLabel \[Rule] \
{StyleForm["\<K\>", FontSize \[Rule] 16], 
                        StyleForm[\*"\"\<\!\(\[CapitalLambda]\_k\)(\!\(s\_0\))\
\>\"", FontSize \[Rule] 16], "\<\>", "\<\>"}\), ",", 
                    "\[IndentingNewLine]", \(AspectRatio \[Rule] 0.5\)}], 
                  "]"}]}], ";", "\[IndentingNewLine]", "g"}]}], "]"}]}], 
      ";"}]], "Input"],

Cell["\<\
Dieses Unterprogramm schreibt das Ergebnis der Rechnung in eine Datei.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(saveResults[results_, filename_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            
            StyleBox[\( (*Es\ k\[ODoubleDot]nnen\ nur\ zweidimensionale\ \
Tabellen\ geschrieben\ \(\(werden\)\(.\)\)*) \),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
            
            StyleBox[\( (*Deswegen\ gehen\ wir\ von\ 3  
                  D\ auf\ 2 \( \(D\)\(.\)\)*) \),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->GrayLevel[0.500008]], 
            "\[IndentingNewLine]", \(Export[filename, 
                Flatten[results, 1]];\)}], "\[IndentingNewLine]", "]"}]}], 
      ";"}]], "Input"],

Cell["\<\
Dieses Unterprogramm liest das Ergebnis der Rechnung aus einer Datei.    \
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(loadResults[from_]\), " ", ":=", " ", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({results, temp, allTemp, i}\), ",", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*Es\ k\[ODoubleDot]nnen\ nur\ zweidimensionale\ \
Tabellen\ gelesen\ \(\(werden\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
              
              StyleBox[\( (*Deswegen\ gehen\ wir\ von\ 2  
                    D\ auf\ 3 \( \(D\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], 
              "\[IndentingNewLine]", \(results\  = \ 
                Import[from]; \[IndentingNewLine]temp\  = \ {}; \
\[IndentingNewLine]allTemp\  = \ {}; \[IndentingNewLine]For[i\  = \ 1, 
                i\  \[LessEqual] \ 
                  Length[results], \(i++\), \[IndentingNewLine]temp\  = \ 
                  Append[temp, results[\([i]\)]]; \[IndentingNewLine]If[\ 
                  Mod[i, 100]\  \[Equal] \ 
                    0, \[IndentingNewLine]allTemp\  = \ 
                    Append[allTemp, 
                      temp]; \[IndentingNewLine]temp\  = \ {};\
\[IndentingNewLine]];\[IndentingNewLine]]; \[IndentingNewLine]allTemp\)}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[\(If[test, loadResults[filename\  <> \ "\<.dat\>"]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hauptprogramm", "Subsection"],

Cell["\<\
Das Hauptprogramm berechnet numerisch den (approximativen) \
Ljapunov-Exponenten.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ljapunov[spins_, systems_, steps_, \[Delta]_, t_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({a, b, c, u, v, w, i, j, \[CapitalDelta], summation, 
              results, allResults, coupling, equations}\), ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*An\ dieser\ Stelle\ werden\ die\ Spin - 
                  Variablen\ \(\(erstellt\)\(.\)\)*) \),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
            RowBox[{\(var\  = \ getVar[spins]\), ";", "\[IndentingNewLine]", 
              StyleBox[\(If[status, Print["\<Coordinates created.\>"]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
              StyleBox[\(If[test, Print[var]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*An\ dieser\ Stelle\ werden\ zuf\[ADoubleDot]llige\
\ Anfangsbedingungen\ \(\(erstellt\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
              StyleBox[\(a\  = \ generateAll[spins]\),
                Background->RGBColor[1, 0, 0]], ";", "\[IndentingNewLine]", 
              StyleBox[\(b\  = \ generateAll[spins]\),
                Background->RGBColor[1, 0, 0]], ";", 
              "\[IndentingNewLine]", \({c, \[CapitalDelta]}\  = \ 
                shrinkAll[a\ , b, \[Delta]]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\(If[status, 
                  Print["\<Initial Conditions created.\>"\ ]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
              StyleBox[\(If[status, Print[a]; \ Print[b]; \ Print[c]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(allResults\  = \ {}\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              
              StyleBox[\( (*Diese\ Schleife\ durchl\[ADoubleDot]uft\ die\ \
Spin - \(\(Systeme\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
                
                RowBox[{\(i\  = \ 1\), 
                  ",", \(i\  \[LessEqual] Length[systems]\), ",", \(i++\), 
                  ",", "\[IndentingNewLine]", 
                  RowBox[{
                    
                    StyleBox[\(If[status, 
                        Print["\<System \>"\  <> \ 
                            ToString[i]\  <> \ "\< of \>"\  <> \ 
                            ToString[Length[systems]]\  <> \ "\< ...\>"]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*Jedes\ Spin - 
                          System\ beginnt\ mit\ den\ gleichen\ \
\(\(Anfangsbedingugen\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], 
                    "\[IndentingNewLine]", \(u\  = \ a\), ";", 
                    " ", \(v\  = \ b\), ";", " ", \(w\  = \ c\), ";", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\(If[status, 
                        Print["\<Initial Conditions reset.\>"\ ]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    StyleBox[\(If[test, Print[u]; \ Print[v]; \ Print[w]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*An\ dieser\ Stelle\ werden\ die\ Kopplungen\
\ \(\(erstellt\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], 
                    "\[IndentingNewLine]", \(coupling\  = \ 
                      systems[\([i]\)]\), ";", "\[IndentingNewLine]", 
                    StyleBox[\(If[status, Print["\<Coupling created.\>"]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    StyleBox[\(If[test, Print[coupling]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*An\ dieser\ Stelle\ werden\ die\ \
Bewegungsgleichungen\ \(\(erstellt\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], 
                    "\[IndentingNewLine]", \(equations\  = \ 
                      getEquations[spins, coupling, 1]\), ";", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\(If[status, 
                        Print["\<Equations created.\>"\ ]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    StyleBox[\(If[test, Print[equations]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", \(summation\  = \ 0\), ";", 
                    "\[IndentingNewLine]", \(results\  = \ {}\), ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*Diese\ Schleife\ \(d  
                            urchl\[ADoubleDot]uft\)\ abwechselnd\ eine\ \
Zeitentwicklung\ und\ einen\ \(\(Schrumpfprozess\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
                    
                    StyleBox[\(If[status, Print["\<Calculating...\>"\ ]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    RowBox[{"For", "[", 
                      
                      RowBox[{\(j = 1\), ",", \(j \[LessEqual] \ steps\), 
                        ",", \(j++\), ",", "\[IndentingNewLine]", 
                        RowBox[{
                          StyleBox[\(If[status, showPercentage[j, steps]]\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 1, 0]], 
                          StyleBox[";",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 1, 0]], 
                          "\[IndentingNewLine]", "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*An\ dieser\ Stelle\ findet\ die\ \
Zeitentwicklung\ \(\(statt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \(u\  = \ 
                            flow[equations, var, u, t]\), ";", 
                          "\[IndentingNewLine]", \(v\  = \ 
                            flow[equations, var, w, t]\), ";", 
                          "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*An\ dieser\ Stelle\ findet\ der\ \
Schrumpfprozess\ \(\(statt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \({w, \[CapitalDelta]}\  = \ 
                            shrinkAll[u, v, \[Delta]]\), ";", 
                          "\[IndentingNewLine]", "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*An\ dieser\ Stelle\ wird\ der\ \
Ljapunov - Exponent\ \(\(bestimmt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \(summation\  = \ 
                            summation\  + \ Log[\[CapitalDelta]/\[Delta]]\), 
                          ";", "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*Nicht\ jeder\ Punkt\ wird\ in\ die\ \
Liste\ \(\(aufgenommen\)\(:\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          StyleBox["\[IndentingNewLine]",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          
                          StyleBox[\( (*\(\(-der\)\ Einschwingvorgang\ wird\ \
ber\[UDoubleDot]cksichtigt\)\(,\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          StyleBox["\[IndentingNewLine]",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          
                          StyleBox[\( (*\(-die\)\ Aufl\[ODoubleDot]sung\ wird\
\ \(\(ber\[UDoubleDot]cksichtigt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          StyleBox[" ",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*\(-der\)\ Imgagin\[ADoubleDot]rteil \
\((numerischer\ Fehler)\)\ wird\ \(\(gestrichen\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \(If[
                            j\  \[GreaterEqual] \((steps/100)\) && \ 
                              Mod[j, \((steps/100)\)] \[Equal] 0, 
                            results\  = \ 
                              Append[
                                results, {j, Re[summation]/\((j\ *\ t)\)}]]\),
                           ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
                    "\[IndentingNewLine]", \(allResults\  = \ 
                      Append[allResults, results]\), ";", 
                    "\[IndentingNewLine]", 
                    StyleBox[\(If[status, showResults[allResults]];\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]]}]}], 
                "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
              "allResults"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["If",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["[",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox["SaveOrLoad",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\[IndentingNewLine]",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          RowBox[{
            RowBox[{
              StyleBox["For",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 1]], 
              StyleBox["[",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 1]], 
              RowBox[{
                StyleBox[\(i = 1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[",",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[\(i \[LessEqual] \ loops\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[",",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[\(i++\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[",",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox["\[IndentingNewLine]",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], 
                RowBox[{
                  
                  StyleBox[\(If[status, 
                      Print["\<Loop \>"\  <> \ 
                          ToString[i]\  <> \ "\< of \>"\  <> \ 
                          ToString[loops]\  <> \ "\< ...\>"]]\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 1, 0]], 
                  StyleBox[";",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                  RowBox[{"results", " ", "=", 
                    
                    StyleBox[\(ljapunov[4, all4, 10\^5, 10\^\(-3\), 
                        10\^\(-1\)]\),
                      Background->RGBColor[1, 0, 0]]}], 
                  StyleBox[";",
                    Background->None], 
                  "\[IndentingNewLine]", \(saveResults[results, 
                    filename\  <> "\<_\>" <> ToString[\ i] <> \ "\<.dat\>"]\),
                   ";", "\[IndentingNewLine]", \(showResults[results]\), 
                  ";"}]}], "\[IndentingNewLine]", 
              StyleBox["]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 1]]}], 
            StyleBox[";",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 1]]}]}], 
        StyleBox["\[IndentingNewLine]",
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[";",
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1]]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["If",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["[",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox[\(! SaveOrLoad\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1]], 
          "\[IndentingNewLine]", \(results\  = 
            loadResults[
              filename\  <> \ "\<.dat\>"]; \[IndentingNewLine]showResults[
            results];\)}], "\[IndentingNewLine]", 
        StyleBox["]",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[";",
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1]]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.40476 0.47619 0.63584 0.214376 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.16716 -0.0125 -14 -12.5625 ]
[.16716 -0.0125 14 0 ]
[.35665 -0.0125 -14 -12.5625 ]
[.35665 -0.0125 14 0 ]
[.5 -0.0125 -17 -12.5625 ]
[.5 -0.0125 17 0 ]
[.64335 -0.0125 -17 -12.5625 ]
[.64335 -0.0125 17 0 ]
[.83284 -0.0125 -17 -12.5625 ]
[.83284 -0.0125 17 0 ]
[.97619 -0.0125 -23 -12.5625 ]
[.97619 -0.0125 23 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -26.4375 ]
[.5 -0.0125 6.78125 -12.5625 ]
[-0.0125 .05724 -34 -6.28125 ]
[-0.0125 .05724 0 6.28125 ]
[-0.0125 .14255 -34 -6.28125 ]
[-0.0125 .14255 0 6.28125 ]
[-0.0125 .20709 -28 -6.28125 ]
[-0.0125 .20709 0 6.28125 ]
[-0.0125 .27162 -28 -6.28125 ]
[-0.0125 .27162 0 6.28125 ]
[-0.0125 .35693 -28 -6.28125 ]
[-0.0125 .35693 0 6.28125 ]
[-0.0125 .42146 -22 -6.28125 ]
[-0.0125 .42146 0 6.28125 ]
[-0.0125 .486 -22 -6.28125 ]
[-0.0125 .486 0 6.28125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .25 -48.9375 -28.4375 ]
[-0.01875 .25 -34 28.4375 ]
[.02381 .5125 -14 0 ]
[.02381 .5125 14 12.5625 ]
[.16716 .5125 -14 0 ]
[.16716 .5125 14 12.5625 ]
[.35665 .5125 -14 0 ]
[.35665 .5125 14 12.5625 ]
[.5 .5125 -17 0 ]
[.5 .5125 17 12.5625 ]
[.64335 .5125 -17 0 ]
[.64335 .5125 17 12.5625 ]
[.83284 .5125 -17 0 ]
[.83284 .5125 17 12.5625 ]
[.97619 .5125 -23 0 ]
[.97619 .5125 23 12.5625 ]
[ 0 .5 .125 0 ]
[1.0125 .05724 0 -6.28125 ]
[1.0125 .05724 34 6.28125 ]
[1.0125 .14255 0 -6.28125 ]
[1.0125 .14255 34 6.28125 ]
[1.0125 .20709 0 -6.28125 ]
[1.0125 .20709 28 6.28125 ]
[1.0125 .27162 0 -6.28125 ]
[1.0125 .27162 28 6.28125 ]
[1.0125 .35693 0 -6.28125 ]
[1.0125 .35693 28 6.28125 ]
[1.0125 .42146 0 -6.28125 ]
[1.0125 .42146 22 6.28125 ]
[1.0125 .486 0 -6.28125 ]
[1.0125 .486 22 6.28125 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .5005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16716 0 m
.16716 .00625 L
s
gsave
.16716 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.35665 0 m
.35665 .00625 L
s
gsave
.35665 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.64335 0 m
.64335 .00625 L
s
gsave
.64335 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.83284 0 m
.83284 .00625 L
s
gsave
.83284 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -84 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.25101 0 m
.25101 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.39436 0 m
.39436 .00375 L
s
.42624 0 m
.42624 .00375 L
s
.45385 0 m
.45385 .00375 L
s
.47821 0 m
.47821 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.7867 0 m
.7867 .00375 L
s
.87055 0 m
.87055 .00375 L
s
.90243 0 m
.90243 .00375 L
s
.93004 0 m
.93004 .00375 L
s
.9544 0 m
.9544 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7813 -30.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.875 translate 1 -1 scale
63.000 14.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
72.563 14.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05724 m
.00625 .05724 L
s
gsave
-0.0125 .05724 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.002) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14255 m
.00625 .14255 L
s
gsave
-0.0125 .14255 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .20709 m
.00625 .20709 L
s
gsave
-0.0125 .20709 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .27162 m
.00625 .27162 L
s
gsave
-0.0125 .27162 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .35693 m
.00625 .35693 L
s
gsave
-0.0125 .35693 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42146 m
.00625 .42146 L
s
gsave
-0.0125 .42146 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .486 m
.00625 .486 L
s
gsave
-0.0125 .486 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .09499 m
.00375 .09499 L
s
0 .12178 m
.00375 .12178 L
s
0 .15953 m
.00375 .15953 L
s
0 .17388 m
.00375 .17388 L
s
0 .18631 m
.00375 .18631 L
s
0 .19728 m
.00375 .19728 L
s
0 .30937 m
.00375 .30937 L
s
0 .33615 m
.00375 .33615 L
s
0 .3739 m
.00375 .3739 L
s
0 .38826 m
.00375 .38826 L
s
0 .40069 m
.00375 .40069 L
s
0 .41165 m
.00375 .41165 L
s
.25 Mabswid
0 0 m
0 .5 L
s
gsave
-0.01875 .25 -130.906 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
89.4375 11.4688 translate
90 rotate
-89.4375 -11.4688 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.9375 translate 1 -1 scale
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
72.563 17.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 14.938 moveto
(H) show
89.438 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
99.000 17.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.313 14.938 moveto
(L) show
115.875 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .49375 m
.02381 .5 L
s
gsave
.02381 .5125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16716 .49375 m
.16716 .5 L
s
gsave
.16716 .5125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.35665 .49375 m
.35665 .5 L
s
gsave
.35665 .5125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .49375 m
.5 .5 L
s
gsave
.5 .5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.64335 .49375 m
.64335 .5 L
s
gsave
.64335 .5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.83284 .49375 m
.83284 .5 L
s
gsave
.83284 .5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 .49375 m
.97619 .5 L
s
gsave
.97619 .5125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.25101 .49625 m
.25101 .5 L
s
.3105 .49625 m
.3105 .5 L
s
.39436 .49625 m
.39436 .5 L
s
.42624 .49625 m
.42624 .5 L
s
.45385 .49625 m
.45385 .5 L
s
.47821 .49625 m
.47821 .5 L
s
.7272 .49625 m
.7272 .5 L
s
.7867 .49625 m
.7867 .5 L
s
.87055 .49625 m
.87055 .5 L
s
.90243 .49625 m
.90243 .5 L
s
.93004 .49625 m
.93004 .5 L
s
.9544 .49625 m
.9544 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 .05724 m
1 .05724 L
s
gsave
1.0125 .05724 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.002) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .14255 m
1 .14255 L
s
gsave
1.0125 .14255 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .20709 m
1 .20709 L
s
gsave
1.0125 .20709 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .27162 m
1 .27162 L
s
gsave
1.0125 .27162 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .35693 m
1 .35693 L
s
gsave
1.0125 .35693 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .42146 m
1 .42146 L
s
gsave
1.0125 .42146 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .486 m
1 .486 L
s
gsave
1.0125 .486 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.99625 .09499 m
1 .09499 L
s
.99625 .12178 m
1 .12178 L
s
.99625 .15953 m
1 .15953 L
s
.99625 .17388 m
1 .17388 L
s
.99625 .18631 m
1 .18631 L
s
.99625 .19728 m
1 .19728 L
s
.99625 .30937 m
1 .30937 L
s
.99625 .33615 m
1 .33615 L
s
.99625 .3739 m
1 .3739 L
s
.99625 .38826 m
1 .38826 L
s
.99625 .40069 m
1 .40069 L
s
.99625 .41165 m
1 .41165 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 0 r
.001 w
.02381 .4695 m
.16716 .48135 L
.25101 .48278 L
.3105 .48218 L
.35665 .48281 L
.39436 .48797 L
.42624 .48617 L
.45385 .487 L
.47821 .48766 L
.5 .48492 L
.51971 .48549 L
.53771 .4861 L
.55426 .48439 L
.56958 .48539 L
.58385 .48507 L
.5972 .48445 L
.60974 .48558 L
.62156 .48525 L
.63274 .48576 L
.64335 .48575 L
.65344 .48561 L
.66306 .4867 L
.67225 .48696 L
.68105 .4881 L
.6895 .48657 L
.69761 .48531 L
.70541 .48536 L
.71293 .48577 L
.72019 .48574 L
.7272 .48541 L
.73398 .48608 L
.74055 .48635 L
.74691 .4862 L
.75309 .48647 L
.75908 .48673 L
.76491 .48714 L
.77057 .48741 L
.77609 .4873 L
.78146 .48696 L
.7867 .48691 L
.7918 .48684 L
.79679 .48674 L
.80165 .4863 L
.80641 .4865 L
.81105 .48659 L
.8156 .48639 L
.82005 .486 L
.8244 .48609 L
.82866 .48611 L
.83284 .48654 L
Mistroke
.83694 .48688 L
.84095 .48723 L
.84489 .48728 L
.84876 .48618 L
.85255 .48517 L
.85628 .48509 L
.85994 .48479 L
.86354 .48488 L
.86707 .48493 L
.87055 .48527 L
.87397 .48568 L
.87733 .48538 L
.88064 .48587 L
.8839 .48569 L
.8871 .48573 L
.89026 .48578 L
.89337 .48566 L
.89643 .48567 L
.89945 .48588 L
.90243 .48617 L
.90536 .48619 L
.90825 .4861 L
.91111 .48591 L
.91392 .48572 L
.9167 .48551 L
.91944 .48555 L
.92214 .48527 L
.92481 .48514 L
.92744 .4854 L
.93004 .48541 L
.93261 .4855 L
.93515 .48559 L
.93766 .48557 L
.94013 .48562 L
.94258 .48566 L
.945 .48587 L
.94739 .48578 L
.94975 .48607 L
.95209 .4861 L
.9544 .48617 L
.95669 .48601 L
.95895 .48584 L
.96118 .48589 L
.96339 .48626 L
.96558 .48636 L
.96775 .48637 L
.96989 .48632 L
.97201 .48631 L
.97411 .48598 L
.97619 .48622 L
Mistroke
Mfstroke
.8 1 0 r
[ .01 ] 0 setdash
.02381 .36302 m
.16716 .31029 L
.25101 .27909 L
.3105 .25643 L
.35665 .23865 L
.39436 .22465 L
.42624 .21279 L
.45385 .2024 L
.47821 .19323 L
.5 .18473 L
.51971 .17728 L
.53771 .17093 L
.55426 .16482 L
.56958 .15907 L
.58385 .15372 L
.5972 .14859 L
.60974 .14421 L
.62156 .14021 L
.63274 .13603 L
.64335 .13208 L
.65344 .12841 L
.66306 .12495 L
.67225 .122 L
.68105 .119 L
.6895 .11577 L
.69761 .11289 L
.70541 .11024 L
.71293 .10775 L
.72019 .1055 L
.7272 .10299 L
.73398 .10043 L
.74055 .09835 L
.74691 .09636 L
.75309 .09439 L
.75908 .09248 L
.76491 .09033 L
.77057 .08839 L
.77609 .08688 L
.78146 .08523 L
.7867 .08352 L
.7918 .08185 L
.79679 .08008 L
.80165 .07868 L
.80641 .07747 L
.81105 .07595 L
.8156 .07442 L
.82005 .07303 L
.8244 .07168 L
.82866 .07061 L
.83284 .06946 L
Mistroke
.83694 .06801 L
.84095 .06674 L
.84489 .06567 L
.84876 .06461 L
.85255 .06364 L
.85628 .06249 L
.85994 .06118 L
.86354 .06026 L
.86707 .05943 L
.87055 .05845 L
.87397 .05748 L
.87733 .05639 L
.88064 .05538 L
.8839 .05473 L
.8871 .05394 L
.89026 .05293 L
.89337 .05203 L
.89643 .05116 L
.89945 .05042 L
.90243 .04983 L
.90536 .04896 L
.90825 .04799 L
.91111 .04731 L
.91392 .04665 L
.9167 .046 L
.91944 .04534 L
.92214 .04445 L
.92481 .04369 L
.92744 .04323 L
.93004 .04263 L
.93261 .04192 L
.93515 .04123 L
.93766 .04049 L
.94013 .03997 L
.94258 .03957 L
.945 .03888 L
.94739 .03815 L
.94975 .0376 L
.95209 .03707 L
.9544 .03663 L
.95669 .03612 L
.95895 .03538 L
.96118 .03479 L
.96339 .03445 L
.96558 .03398 L
.96775 .03345 L
.96989 .03289 L
.97201 .03227 L
.97411 .0319 L
.97619 .0316 L
Mistroke
Mfstroke
0 1 .4 r
.02381 .3628 m
.16716 .30974 L
.25101 .2785 L
.3105 .25603 L
.35665 .23839 L
.39436 .22425 L
.42624 .21206 L
.45385 .20145 L
.47821 .19235 L
.5 .18397 L
.51971 .17643 L
.53771 .16975 L
.55426 .16335 L
.56958 .15754 L
.58385 .15228 L
.5972 .14711 L
.60974 .14242 L
.62156 .13808 L
.63274 .13375 L
.64335 .12984 L
.65344 .12615 L
.66306 .12243 L
.67225 .11911 L
.68105 .11589 L
.6895 .11264 L
.69761 .10976 L
.70541 .10691 L
.71293 .10403 L
.72019 .10151 L
.7272 .09894 L
.73398 .09638 L
.74055 .09414 L
.74691 .09179 L
.75309 .0895 L
.75908 .08748 L
.76491 .08533 L
.77057 .08326 L
.77609 .08143 L
.78146 .07944 L
.7867 .07758 L
.7918 .0759 L
.79679 .07405 L
.80165 .07236 L
.80641 .07081 L
.81105 .06908 L
.8156 .06754 L
.82005 .0661 L
.8244 .06449 L
.82866 .06307 L
.83284 .06172 L
Mistroke
.83694 .06022 L
.84095 .05892 L
.84489 .05765 L
.84876 .05623 L
.85255 .05504 L
.85628 .05384 L
.85994 .05251 L
.86354 .05141 L
.86707 .05026 L
.87055 .04902 L
.87397 .048 L
.87733 .04691 L
.88064 .04574 L
.8839 .04479 L
.8871 .04374 L
.89026 .04264 L
.89337 .04176 L
.89643 .04075 L
.89945 .03972 L
.90243 .03889 L
.90536 .03792 L
.90825 .03695 L
.91111 .03617 L
.91392 .03524 L
.9167 .03433 L
.91944 .03359 L
.92214 .0327 L
.92481 .03184 L
.92744 .03114 L
.93004 .03028 L
.93261 .02947 L
.93515 .0288 L
.93766 .02797 L
.94013 .02721 L
.94258 .02657 L
.945 .02578 L
.94739 .02505 L
.94975 .02445 L
.95209 .02368 L
.9544 .02299 L
.95669 .02241 L
.95895 .02167 L
.96118 .02102 L
.96339 .02047 L
.96558 .01975 L
.96775 .01913 L
.96989 .0186 L
.97201 .01791 L
.97411 .01732 L
.97619 .01681 L
Mistroke
Mfstroke
0 .4 1 r
.02381 .36279 m
.16716 .30993 L
.25101 .2785 L
.3105 .25603 L
.35665 .23853 L
.39436 .2242 L
.42624 .21206 L
.45385 .20154 L
.47821 .19225 L
.5 .18395 L
.51971 .17644 L
.53771 .16958 L
.55426 .16329 L
.56958 .15746 L
.58385 .15204 L
.5972 .14698 L
.60974 .14223 L
.62156 .13776 L
.63274 .13354 L
.64335 .12954 L
.65344 .12574 L
.66306 .12212 L
.67225 .11867 L
.68105 .11538 L
.6895 .11222 L
.69761 .10919 L
.70541 .10628 L
.71293 .10349 L
.72019 .10079 L
.7272 .0982 L
.73398 .09569 L
.74055 .09327 L
.74691 .09093 L
.75309 .08866 L
.75908 .08646 L
.76491 .08433 L
.77057 .08226 L
.77609 .08025 L
.78146 .0783 L
.7867 .0764 L
.7918 .07455 L
.79679 .07276 L
.80165 .071 L
.80641 .0693 L
.81105 .06763 L
.8156 .066 L
.82005 .06442 L
.8244 .06287 L
.82866 .06135 L
.83284 .05987 L
Mistroke
.83694 .05842 L
.84095 .05701 L
.84489 .05562 L
.84876 .05427 L
.85255 .05294 L
.85628 .05164 L
.85994 .05036 L
.86354 .04911 L
.86707 .04789 L
.87055 .04669 L
.87397 .04551 L
.87733 .04435 L
.88064 .04322 L
.8839 .0421 L
.8871 .04101 L
.89026 .03993 L
.89337 .03888 L
.89643 .03784 L
.89945 .03682 L
.90243 .03582 L
.90536 .03483 L
.90825 .03386 L
.91111 .03291 L
.91392 .03197 L
.9167 .03105 L
.91944 .03014 L
.92214 .02925 L
.92481 .02837 L
.92744 .0275 L
.93004 .02665 L
.93261 .02581 L
.93515 .02498 L
.93766 .02416 L
.94013 .02336 L
.94258 .02256 L
.945 .02178 L
.94739 .02101 L
.94975 .02025 L
.95209 .01951 L
.9544 .01877 L
.95669 .01804 L
.95895 .01732 L
.96118 .01661 L
.96339 .01591 L
.96558 .01522 L
.96775 .01454 L
.96989 .01387 L
.97201 .01321 L
.97411 .01255 L
.97619 .0119 L
Mistroke
Mfstroke
.8 0 1 r
.02381 .35946 m
.16716 .30494 L
.25101 .27538 L
.3105 .25367 L
.35665 .23604 L
.39436 .22237 L
.42624 .20886 L
.45385 .20008 L
.47821 .19139 L
.5 .1832 L
.51971 .17635 L
.53771 .16842 L
.55426 .16397 L
.56958 .15863 L
.58385 .15355 L
.5972 .14914 L
.60974 .14355 L
.62156 .14099 L
.63274 .13713 L
.64335 .13365 L
.65344 .13043 L
.66306 .12618 L
.67225 .12465 L
.68105 .12159 L
.6895 .1191 L
.69761 .11656 L
.70541 .11321 L
.71293 .11227 L
.72019 .10971 L
.7272 .1079 L
.73398 .10574 L
.74055 .10307 L
.74691 .1025 L
.75309 .10026 L
.75908 .09894 L
.76491 .09701 L
.77057 .09489 L
.77609 .09452 L
.78146 .09253 L
.7867 .09157 L
.7918 .08979 L
.79679 .08812 L
.80165 .08786 L
.80641 .08608 L
.81105 .08539 L
.8156 .08369 L
.82005 .08243 L
.8244 .0822 L
.82866 .0806 L
.83284 .08011 L
Mistroke
.83694 .07846 L
.84095 .07756 L
.84489 .07732 L
.84876 .07589 L
.85255 .07554 L
.85628 .07393 L
.85994 .07334 L
.86354 .07305 L
.86707 .07181 L
.87055 .07153 L
.87397 .06997 L
.87733 .06965 L
.88064 .06929 L
.8839 .06823 L
.8871 .06798 L
.89026 .06648 L
.89337 .06639 L
.89643 .06594 L
.89945 .06506 L
.90243 .0648 L
.90536 .06338 L
.90825 .06348 L
.91111 .06294 L
.91392 .06224 L
.9167 .06194 L
.91944 .06063 L
.92214 .06086 L
.92481 .06024 L
.92744 .05971 L
.93004 .05934 L
.93261 .05817 L
.93515 .05848 L
.93766 .0578 L
.94013 .05743 L
.94258 .05698 L
.945 .05597 L
.94739 .05631 L
.94975 .05558 L
.95209 .05536 L
.9544 .05481 L
.95669 .05399 L
.95895 .05432 L
.96118 .05356 L
.96339 .05346 L
.96558 .05281 L
.96775 .0522 L
.96989 .05247 L
.97201 .05173 L
.97411 .05171 L
.97619 .05097 L
Mistroke
Mfstroke
1 0 0 r
.02381 .36046 m
.16716 .30598 L
.25101 .27534 L
.3105 .25413 L
.35665 .2368 L
.39436 .22259 L
.42624 .20902 L
.45385 .19933 L
.47821 .19111 L
.5 .18302 L
.51971 .17554 L
.53771 .16746 L
.55426 .16221 L
.56958 .15737 L
.58385 .15224 L
.5972 .14712 L
.60974 .14133 L
.62156 .13811 L
.63274 .1348 L
.64335 .13114 L
.65344 .1272 L
.66306 .12276 L
.67225 .1207 L
.68105 .11825 L
.6895 .11548 L
.69761 .11223 L
.70541 .10871 L
.71293 .10741 L
.72019 .10549 L
.7272 .10331 L
.73398 .1005 L
.74055 .09769 L
.74691 .09689 L
.75309 .09532 L
.75908 .09354 L
.76491 .09105 L
.77057 .0888 L
.77609 .08834 L
.78146 .08701 L
.7867 .08552 L
.7918 .08327 L
.79679 .08149 L
.80165 .08126 L
.80641 .08009 L
.81105 .07881 L
.8156 .07675 L
.82005 .07537 L
.8244 .07527 L
.82866 .07423 L
.83284 .0731 L
Mistroke
.83694 .0712 L
.84095 .07016 L
.84489 .07014 L
.84876 .06919 L
.85255 .06817 L
.85628 .06641 L
.85994 .06568 L
.86354 .06567 L
.86707 .06481 L
.87055 .06387 L
.87397 .06223 L
.87733 .06176 L
.88064 .06175 L
.8839 .06095 L
.8871 .06006 L
.89026 .05855 L
.89337 .05831 L
.89643 .05825 L
.89945 .05751 L
.90243 .05667 L
.90536 .05528 L
.90825 .05523 L
.91111 .05511 L
.91392 .05444 L
.9167 .05361 L
.91944 .05236 L
.92214 .05245 L
.92481 .05228 L
.92744 .05166 L
.93004 .05084 L
.93261 .04973 L
.93515 .04994 L
.93766 .04969 L
.94013 .04914 L
.94258 .04832 L
.945 .04736 L
.94739 .04764 L
.94975 .04733 L
.95209 .04683 L
.9544 .046 L
.95669 .04521 L
.95895 .04552 L
.96118 .04516 L
.96339 .0447 L
.96558 .04387 L
.96775 .04325 L
.96989 .04355 L
.97201 .04315 L
.97411 .04274 L
.97619 .04189 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{904, 452},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>80001a2000`400?l00000o`00003oo`3ooooo
0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00
o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooolX0oooo0`000003
0?ooo`800000o`3ooonh0?ooo`00o`3oooo;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3ooong0?ooo`00o`3oooo;0?ooo`050000003oool0oooo0?ooo`000000o`3ooonj0?oo
o`00o`3oooo;0?ooo`050000003oool0oooo0?ooo`000000o`3ooonj0?ooo`00o`3oooo;0?ooo`@0
0000o`3ooonk0?ooo`00o`3oooo;0?ooo`030000003oool000000?l0oooo_03oool00?l0oooob`3o
ool010000000oooo0?ooo`00003o0?oook/0oooo003o0?oool/0oooo00D000000?ooo`3oool0oooo
0000003o0?oookX0oooo003o0?ooolX0oooo0`0000000`3oool000000000000200000?l0oooo^03o
ool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0
ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00C03oool5
00000080oooo0P0000040?ooo`800000103oool2000005`0oooo100000030?ooo`800000103oool2
000000@0oooo0P0000200?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000F@3oool5
00000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001E0?ooo`@000000`3oool2
000000@0oooo0P0000040?ooo`800000103oool2000007/0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000D03oool500000080oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool200000380oooo001>0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001n0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000005X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00001i0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
D@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0e0?ooo`00CP3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000P@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1H
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000O03oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo04l0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
=@3oool004h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1K0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0O@3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000005X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo05@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo07P0oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000540oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0=@3oool004h0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`1I0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000007l0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000FP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0DP3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000007X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001A0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo03D0oooo001=0?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000G@3oool2000000@0oooo0P0000040?ooo`800000103oool200000800oooo0`0000030?ooo`80
0000103oool2000000@0oooo0P00001J0?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000103oool2000005H0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000N`3oool3000000<0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001A0?ooo`80
0000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000h0?ooo`00
o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;
0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0oooo
o`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?oo
ool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo
003o0?ooool0ooooo`3ooon;0?ooo`00A@3ooooo00000?l00000o`00000D00000380oooo00150?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0<03oool004D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooood0oooo00<006Ko0?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool0
0`000000oooo0?ooo`3o0?ooool0oooon@3oool4001Voa80oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?ooooP0oooo00<006Ko0?ooo`3oool0503oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3oooo_0?ooo`8006Ko
2P3oool3003oIQ40oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooon`0oooo0`00I_l;0?ooo`03003oIP3oool0oooo0180oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooonT0oooo0`00I_lS0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooa0?ooo`800?mV703oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooook@3oool4003oIQh0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooon00oooo
0P00I_l90?ooo`800?mV8P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?oo
o`3o0?ooool0oooog03oool4001Vobl0oooo00<000000?ooo`3oool0<03oool004D0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooomX0oooo0P00I_l70?ooo`03003oIP3oool0oooo02T0oooo00<00000
0?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooon00oooo0`00ofH/0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooL0?ooo`@0
0?mV;`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo
d03oool4001Vo`P0oooo00<00?mV0?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`00A@3o
ool00`000000oooo0?ooo`3o0?ooool0oooocP3oool2001Vocl0oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oool/0oooo0`00I_l40?ooo`<00?mV>P3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool2003o
IR80oooo103<o`0G0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0
ooooo`3oooo=0?ooo`<00?mV8@3oool30<co01/0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooooo0?oool80oooo0`00I_lZ0?ooo`80c?l07P3oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo_P3oool4001Vo`<0oooo00<0
0?mV0?ooo`3oool07`3oool00`3<o`00oooo0?ooo`0U0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0?l0ooooo`3ooonl0?ooo`8006Ko103oool4003oIQh0oooo0`3<o`0X
0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3oooo00?oo
o`800?mV7P3oool40<co02/0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0o`3ooooo0?oookh0oooo0P00ofI?0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0?l0ooooo`3ooond0?ooo`8006Ko8P3oool00`3<o`00oooo0?ooo`0d0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooona0?ooo`<006Ko0P3o
ool00`00ofH0oooo0?ooo`0K0?ooo`@0c?l0703oool40?l001L0oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooojd0oooo1000I_l30?ooo`800?mV6`3oool3
0<co01/0oooo1@3o000K0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0?l0ooooo`3ooona0?ooo`<00?mVF`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000
oooo0?ooo`3o0?ooool0oooo[`3oool2003oIQH0oooo0`3<o`0J0?ooo`D0o`009P3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooX`3oool4001Voah0oooo
0P3<o`0I0?ooo`@0o`00:`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?oo
o`3o0?ooool0ooooX@3oool2001Vo`<0oooo0P00ofHI0?ooo`@0c?l0BP3oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooW`3oool2001Vo`80oooo0`00ofH`
0?ooo`@0o`007`3oool00`3<0?l0oooo0?ooo`0C0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo0?l0ooooo`3ooonQ0?ooo`800?mV5P3oool20<co01H0oooo1@3o000N0?oo
o`D0c03o5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooX03oool00`00ofH0oooo0?ooo`0C0?ooo`<0c?l0>@3oool20<`0oa/0oooo00<000000?ooo`3o
ool0<03oool001d0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000030?ooo`@00000
3@3oool00`000000oooo0?ooo`3o0?ooool0ooooU@3oool3001VoaX0oooo103<o`0?0?ooo`D0o`00
7P3oool30<`0ob@0oooo00<000000?ooo`3oool02`3oool2000000@0oooo0P0000040?ooo`800000
103oool2000000<0oooo1000000:0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0?l0ooooo`3ooonB0?ooo`<006Ko0`3oool00`00ofH0oooo0?ooo`0W0?oo
o`<0o`007@3oool60<`0obL0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0;0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0=0?ooo`D00000o`3ooooo0?oo
ohh0oooo0P00I_l30?ooo`<00?mV4`3oool00`3<o`00oooo0?ooo`0/0?ooo`80c03o;P3oool60000
00`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool02P3oool001`0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooTP3oool3003oIQ40oooo1@3<o`0>0?oo
o`80o`007@3oool20<`0ocD0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`090?ooo`00703oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo0?l0ooooo`3ooon;0?ooo`8006Ko103oool00`00ofH0oooo0?ooo`0?0?ooo`<0c?l0403oool3
0?l001X0oooo1@3<0?lg0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000002P3oool001d0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon80?ooo`<006Ko0P00ofHV0?ooo`<0o`00F@3oool00`000000
oooo0?ooo`0;0?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`8000002`3oool004D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo0P00I_l00`3oool00?mV003oIP0P0?ooo`030?l0
003oool0oooo01L0oooo00@0c03o0?ooo`3oool0oooo103<0?m20?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooon70?ooo`800?mV3`3oool50<co00`0oooo
0P3o000I0?ooo`030<`0o`3oool0c03o0080c03oAP3oool00`000000oooo0?ooo`0`0?ooo`00A@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool00`00I_l0oooo0?ooo`0D0?ooo`80c?l0303o
ool50?l006H0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooogh0oooo0P00I_l00`00ofH0oooo0?ooo`0A0?ooo`80c?l08`3oool40<`0oe80oooo00<00000
0?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooogX0oooo1000I_l2003o
IQ/0oooo0P3o000H0?ooo`@0c03oEP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000
oooo0?ooo`3o0?ooool0ooooN03oool2001Vo`@00?mV3P3oool20<co00X0oooo0`3o001d0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooomh0?ooo`800?mV
4@3oool00`3<o`00oooo0?ooo`060?ooo`@0o`00503oool20<`0of40oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooojL0oooo1@3<0?mS0?ooo`030000003o
ool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooom_0?ooo`8006Ko00<00?mV
0?ooo`3oool03@3oool30<co00P0oooo0P3o000H0?ooo`030<`0o`3oool0oooo06H0oooo00<00000
0?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooof/0oooo1000I_l2003o
IPd0oooo0`3<o`0M0?ooo`030<`0o`3oool0oooo06h0oooo00<000000?ooo`3oool0<03oool004D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo0P00I_l0103oool00?mV003oIP00ofH=0?oo
o`80c?l00`3oool40?l001@0oooo1@3<0?ma0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0?l0ooooo`3ooomZ0?ooo`800?mV4`3oool20?l001H0oooo0P3<0?mf0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`030<co
003oool0oooo00H0oooo0P3o002@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0ooooo`3ooomQ0?ooo`03001Vo`3oool0oooo00h0oooo0P3<o`0J0?ooo`80c03oO`3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooGP3oool3
001Vo`030?ooo`00ofH0oooo00/0oooo0`3<o`030?ooo`030?l0003oool0oooo00l0oooo0P3<0?l3
0?ooo`80c03oP@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooF`3oool3001Vo`@00?mV2`3oool20<co00030?ooo`3o0000o`0000<0o`003@3oool50<`0
ohP0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oooeX0
oooo00@006Ko003oIP00ofH00?mV403oool20?l00100oooo0P3<0?n=0?ooo`030000003oool0oooo
0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooomU0?ooo`030<co003oool0oooo0:L0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo
00<006Ko0?ooo`3oool03@3oool20<co00030?ooo`3o0000oooo00l0oooo0`3<0?nE0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`8006Ko00<0
0?mV0?ooo`3oool0203oool50<co00<0o`003`3oool20<`0oiP0oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodd0oooo1000I_l00`00ofH0oooo0?ooo`0;
0?ooo`@0o`003P3oool40<`0oiX0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3ooooo0?oood/0oooo0P00I_l00`3oool00?mV003oIP2o0?ooo`030000003oool0oooo
0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`800?mV1`3oool00`3<o`00
o`000?l0000B0?ooo`030<`0o`3oool0oooo0:80oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo0`3<o`020?l000h0oooo1P3<0?nU0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooom30?ooo`8006Ko00<0
0?mV0?ooo`3oool01`3oool20<co00030?ooo`3o0000o`0000h0oooo0P3<0?n[0?ooo`030000003o
ool0oooo0300oooo00150?ooo`<00000o`3ooooo0?oood40oooo0P00I_l2003oIP/0oooo0P3o002j
0?ooo`@00000<P3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooocl0oooo0P00I_l00`00
ofH0oooo0?ooo`0E0?ooo`80c03o]03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000
oooo0?ooo`3o0?ooool0oooo?@3oool2001Vo`D0oooo1@3o000=0?ooo`<0c03o]P3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo@P3oool20?l00080c?l0
3@3oool30<`0okT0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooocD0oooo00<006Ko0?ooo`3oool0203oool00`3<o`00o`000<co003<0?ooo`030000003o
ool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`8006Ko0P00ofHD
0?ooo`030<`0o`3oool0oooo0<40oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3ooooo0?oooc00oooo0`00I_lD0?ooo`@0c03oa03oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo;P3oool2001Vo`P0oooo0P3o000:0?ooo`<0
c03ob03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo
=P3oool20?l00=L0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?oooc40oooo00<0c?l00?l0003o00000P3o00050?ooo`80c03odP3oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo9@3oool2001Vo`03003oIP3oool0
oooo00l0oooo0P3<0?oD0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0?l0ooooo`3ooolQ0?ooo`@006Ko00<00?mV0?ooo`3o00000`3o000<0?ooo`80c03oeP3oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo7`3oool2001Vo`04
0?ooo`00ofH00?mV0?ooo`80o`00103<o`0:0?ooo`80c03of03oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo803oool2003oIP030?ooo`3o0000o`000080
c?l0j03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo
8P3oool20<co00L0oooo0`3<0?oQ0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0ooooo`3ooolG0?ooo`8006Ko3`3oool30<`0on@0oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oooa@0oooo0`00I_l01000ofH0oooo0?ooo`3o
ool20?l000T0oooo0P3<0?oW0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0
oooo0?l0ooooo`3ooolB0?ooo`8006Ko0P00ofH30?ooo`80o`0000<0c?l00?ooo`3oool0l@3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo403oool2001V
o`800?mV0`3oool20?l000030<co003oool0oooo0080oooo00<0c03o0?ooo`3oool0kP3oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo503oool30?l000@0
oooo0`3<0?oa0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooolC0?ooo`80c?l0103oool20<`0oo@0oooo00<000000?ooo`3oool0<03oool004D0oooo0`00
003o0?ooool0oooo2@3oool00`00I_l00?mV0?l000020?l000T0oooo0P3<0?oc0?ooo`@00000<P3o
ool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<006Ko0?l0003o00000P3o0002
0<co0?l0oooo0`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo103oool00`00I_l0o`000?l000020?ooo`80c?l01@3oool00`3<0?l0oooo0?ooo`3l0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`80
06Ko0`3oool20<co00<0oooo103<0?oo0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0?l0ooooo`3oool50?ooo`80c?l000<0oooo0<`0o`3<0?l00P3<0?oo0?ooo`@0oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooh0?ooo`8006Ko00@0
0?mV0?ooo`3o0000o`00o`3ooolA0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0oooomP3oool2001Vo`800?mV0P3o00000`3<o`00oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooood0?ooo`8006Ko0P00ofH2
0?l000030<co003oool0oooo00@0c03oo`3oool>0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo0?l0oooolP3oool2001Vo`04003oIP3oool0o`000?l00080oooo0`3<0?oo
0?oooa80oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooe0?oo
o`030<co003oool0oooo0080c03oo`3ooolE0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooooZ0?ooo`8006Ko00<0oooo0?l0003o0000o`3ooolP0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooi`3oool2001Vo`@0o`001@3<
0?oo0?oooad0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooU
0?ooo`8006Ko0P3o00020<co0080c03oo`3ooolR0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo0?l0ooooh`3oool2001Vo`040?ooo`3<o`00c?l00?ooo`80c03oo`3ooolT
0?ooo`030000003oool0oooo0300oooo000M0?ooo`800000103oool2000000@0oooo0P0000040?oo
o`800000103oool2000000h0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`80o`00o`3oool_0?oo
o`030000003oool0oooo00/0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?oo
o`8000002`3oool001`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`3o0?ooom/0oooo00<006Ko0?l0003o00000P3oool30<`0ool0oooo;03oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo000L0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo00/0oooo1@00003o0?ooomL0oooo00<006Ko0?l0003o0000103<0?oo0?ooobX0
oooo1P00000<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo00P0oooo000L0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`80
00003P3oool00`000000oooo0?ooo`3o0?ooomL0oooo00<006Ko0?l0003o00000P3<0?l20<co0?l0
oooo<@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000002`3oool001`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooomD0oooo0P00I_l20?ooo`80
c?l0o`3ooold0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3o
ool001d0oooo0P00000:0?ooo`800000103oool2000000@0oooo0`00000=0?ooo`030000003oool0
oooo0?l0ooooe`3oool20<co0?l0oooo=P3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool2
000000@0oooo0P0000040?ooo`<000002P3oool004D0oooo00<000000?ooo`3oool0o`3oooo@0?oo
o`80o`0000<0oooo0<`0o`3oool0o`3ooolj0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0?l0ooooc03oool2001Vo`80o`0000<0c?l00<`0o`3<0?l0o`3oooll0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooobP3oool01000I_l0o`00
0?l0003o00030<`0ool0oooo?P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo
0?ooo`3o0?ooolP0oooo00@006Ko0?l0003o0000c?l00P3<0?oo0?oood40oooo00<000000?ooo`3o
ool0<03oool004D0oooo00<000000?ooo`3oool0o`3oooo60?ooo`8006Ko00<0oooo0<co003<o`00
o`3ooom40?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo`@3o
ool20?l00?l0ooooC03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o
0?oookl0oooo0P3o00020?ooo`80c03oo`3ooom:0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo0?l0oooo_03oool30?l000@0c03oo`3ooom<0?ooo`030000003oool0oooo
0300oooo00150?ooo`030000003oool0oooo0?l0oooo^@3oool01000I_l0o`000?l0003oool20<`0
o`80c?l0o`3ooom>0?ooo`030000003oool0oooo0300oooo00150?ooo`<00000o`3ooong0?ooo`80
06Ko00<00?mV0?ooo`3oool00`3<o`3o0?ooodd0oooo1000000b0?ooo`00A@3oool00`000000oooo
0?ooo`3o0?oook<0oooo00<0o`000?ooo`3oool0103oool20<co0?l0ooooD`3oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oook00oooo0`3o00000`3oool0c03o0<`0
o`3o0?oooeT0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooon^
0?ooo`80o`00103<0?oo0?oooe/0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3ooon/0?ooo`80o`000P3<0?l30<co0?l0ooooG03oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?oooj/0oooo0P00I_l30<co0?l0ooooG`3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooj<0oooo0P3o0000103oool0c03o
0?ooo`3oool2001Vo`80c?l0o`3ooomR0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0?l0ooooX@3oool20?l000<0c03oo`3ooomY0?ooo`030000003oool0oooo0300oooo
00150?ooo`030000003oool0oooo0?l0ooooW`3oool20?l00080c03oo`3ooom/0?ooo`030000003o
ool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooW@3oool20?l00080c03o00@006Ko
003oIP3<o`00c?l0o`3ooomZ0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0
oooo0?l0ooooW03oool4001Vo`03003oIP3<o`00c?l00?l0ooooK03oool00`000000oooo0?ooo`0`
0?ooo`00A@3oool300000?l0ooooVP3oool2001Vo`03003oIP3<o`00c?l00?l0ooooK@3oool40000
0380oooo00150?ooo`030000003oool0oooo0?l0ooooUP3oool00`3o0000c03o0<`0o`3o0?ooogH0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`80o`00
00<0c03o0?ooo`3oool0o`3ooomf0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0ooooT03oool40?l000030<`0o`3<o`00oooo0?l0ooooN03oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooohh0oooo0P3o00001000I_l0c03o0<`0o`3<
o`3o0?ooog/0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooon=
0?ooo`<006Ko0P3<o`3o0?ooogd0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3ooon90?ooo`050<`0o`3oool006Ko001Vo`00ofH00P3<o`3o0?ooogl0oooo00<00000
0?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooon60?ooo`80o`0000<0c03o0?oo
o`3oool0o`3ooon40?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0
ooooQ03oool20?l000030<`0o`3oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0`0?ooo`00
A@3oool00`000000oooo0?ooo`3o0?oooh80oooo0P3o00000`3<0?l0c?l00<co003o0?ooohP0oooo
00<000000?ooo`3oool0<03oool004D0oooo0`00003o0?oooh00oooo0P3o00000`00I_l0c?l00<co
003o0?ooohL0oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooogl0oooo0P00I_oo
0?ooohh0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooomh0?oo
o`030?l0003<0?l0c03o0080oooo0P00I_oo0?oooi00oooo00<000000?ooo`3oool0<03oool004D0
oooo00<000000?ooo`3oool0o`3ooomf0?ooo`80o`0000<0c03o0?ooo`3oool0o`3ooonD0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooM03oool20?l000030<`0
o`3<o`00c?l00?l0ooooUP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?oo
o`3o0?ooog40oooo0`3o00000`3<0?l006Ko0<co003o0?oooiP0oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`@006Koo`3ooonK0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooJ`3oool20<`0o`030?ooo`00I_l006Ko
0080c?l0o`3ooonM0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0
ooooJ@3oool20?l00?l0ooooY03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool300000?l0oooo
I@3oool40?l00?l0ooooX`3oool400000380oooo00150?ooo`030000003oool0oooo0?l0ooooHP3o
ool30?l000030<`0o`00I_l006Ko0080c?l0o`3ooonU0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0?l0ooooI03oool2001Vo`80c?l0o`3ooonW0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooG03oool20<`0o`<0oooo0`00I_l20<co
0?l0ooooZ@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooeX0
oooo0P3o00030?ooo`8006Ko00<00?mV0<co003<o`00o`3ooon[0?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0?l0ooooEP3oool40?l00?l0oooo]@3oool00`000000oooo
0?ooo`0`0?ooo`008`3oool2000000@0oooo0P0000040?ooo`8000000`3oool5000000`0oooo00<0
00000?ooo`3oool0o`3ooomC0?ooo`<0o`0000<0c03o003oIP00ofH00P3<o`3o0?oook@0oooo00<0
00000?ooo`3oool02`3oool2000000@0oooo0P0000040?ooo`8000000`3oool5000000l0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0<0?ooo`D00000o`3ooomC0?ooo`800?mV0P00I_oo0?oook40oooo1P00000<0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?oo
o`008P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooodh0oooo00<0c03o0?ooo`3oool00P3oool4
001Vool0oooo^03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`008P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?oood/0oooo0P3o0000103<0?l0oooo0?ooo`3oool2001Vo`80c?l0o`3ooonj0?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00l0oooo000R0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo
B@3oool20?l00?l0ooooa03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`008`3oool2000000X0
oooo0P0000040?ooo`8000003P3oool00`000000oooo0?ooo`3o0?ooodL0oooo0P3o003o0?ooolH0
oooo00<000000?ooo`3oool02`3oool2000000X0oooo0P0000040?ooo`8000004@3oool004D0oooo
00<000000?ooo`3oool0o`3ooom50?ooo`80o`0000@0oooo001Vo`00I_l00?mV0P3<o`3o0?oool80
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooom60?ooo`8006Ko
00<00?mV0<co003<o`00o`3oooo40?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0oooo?P3oool20<`0o`@0oooo0P00I_l00`00ofH0c?l00<co003o0?ooolH0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3oooll0?ooo`80o`00103oool2
001Vo`80c?l0o`3oooo90?ooo`030000003oool0oooo0300oooo000?0?ooo`0304A4A03oool0oooo
03<0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`80o`00o`3ooooC0?ooo`030000003oool0oooo
0300oooo000=0?ooo`030:ZZZP0c<c<0000003D0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`80
o`000P3oool20<co0?l0ooood@3oool00`000000oooo0?ooo`0`0?ooo`002P3oool01P3MgMd0IVIV
014A4@1VIVH0c<c<000003D0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`80o`000P3oool2001V
ool0ooood`3oool00`000000oooo0?ooo`0`0?ooo`00203oool0102ZZZX0<c<c028R8P2IVIT30?oo
o`030<c<c03oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`800?mV0P00I_oo0?oo
omD0oooo00<000000?ooo`3oool0<03oool000L0oooo00<04A4A0000001gMgL0>`3oool00`000000
oooo0?ooo`3o0?oooc00oooo0P3<0?l20?ooo`04003oIP00I_l006Ko001Vool0ooooe`3oool00`00
0000oooo0?ooo`0`0?ooo`00203oool01@2IVIT08R8R028R8P28R8P0k^k^0080oooo00<0R8R80?oo
o`3oool0<`3oool00`000000oooo0?ooo`3o0?ooobh0oooo0P3o00030?ooo`8006Koo`3ooooJ0?oo
o`030000003oool0oooo0300oooo000:0?ooo`060=gMg@1VIVH04A4A05EEE@2k^k/00000=@3oool0
0`000000oooo0?ooo`3o0?ooob/0oooo00<0c03o0?l0003o0000o`3ooooQ0?ooo`030000003oool0
oooo0300oooo000=0?ooo`030:ZZZP0c<c<0000003D0oooo00<000000?ooo`3oool0o`3ooolY0?oo
o`040<`0o`3o0000o`00001Vo`80c?l0o`3ooooP0?ooo`030000003oool0oooo0300oooo000?0?oo
o`0304A4A03oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`80o`0000<006Ko0<co
003<o`00o`3ooooR0?ooo`030000003oool0oooo0300oooo000;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooob40oooo0P3<0?l40?ooo`80
06Ko0P3<o`3o0?ooon@0oooo00<000000?ooo`3oool0<03oool000/0oooo1`00000c0?ooo`030000
003oool0oooo0?l0oooo7`3oool20<`0o`@0oooo0P00I_l20<co0?l0ooooiP3oool00`000000oooo
0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo7@3o
ool20<`0o`80o`00o`3oooo^0?ooo`030000003oool0oooo0300oooo000=0?ooo`050000003oool0
00000?ooo`000000<`3oool00`000000oooo0?ooo`3o0?oooa/0oooo103o00020<co0?l0ooookP3o
ool00`000000oooo0?ooo`0`0?ooo`003@3oool2000000030?ooo`000000000003<0oooo00<00000
0?ooo`3oool0o`3ooolI0?ooo`80o`0000@0oooo001Vo`00I_l00?mVo`3oooo`0?ooo`030000003o
ool0oooo0300oooo000=0?ooo`050000003oool0oooo0?ooo`000000<`3oool00`000000oooo0?oo
o`3o0?oooaT0oooo00@00?mV001Vo`00I_l00?mVo`3oooob0?ooo`030000003oool0oooo0300oooo
00150?ooo`030000003oool0oooo0?l0oooo4P3oool20<`0o`80oooo0P00ofH2001Vool0oooom@3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0c03o
0?l0003o00000`3oool2001Vool0oooom`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`3o0?ooo`h0oooo00<0c03o0?l0003o0000o`3oooon0?ooo`030000003oool0oooo
0300oooo00150?ooo`030000003oool0oooo0?l0oooo303oool30?l00003001Vo`3<o`00c?l00?l0
ooooo@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
0P3o0002001Vo`80c?l0o`3ooooo0?ooo`030000003oool0oooo0300oooo00090?ooo`L00000=@3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo0P3<0?l30?ooo`<006Ko0P3<o`3o0?ooool0oooo0P3o
ool00`000000oooo0?ooo`0`0?ooo`001`3oool2000000L0oooo0P00000c0?ooo`030000003oool0
oooo0?l0oooo0P3oool20<`0o`<0oooo0P00I_l00`00ofH0c?l00<co003o0?ooool0oooo103oool0
0`000000oooo0?ooo`0`0?ooo`001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0oP3oool30<`0o`80o`00o`3ooooo0?ooo``0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o03oool00`3<0?l0o`000?l000020?l00003
0<co003oool0oooo0?l0ooooo`3oool;0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0?X0oooo0`3o00000`3oool006Ko001Vo`3o0?ooool0oooo3`3oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3l0?ooo`8006Koo`3ooooo0?oooa40oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0m03oool20<`0o`@0oooo0P00I_oo
0?ooool0oooo4`3oool00`000000oooo0?ooo`0`0?ooo`002P3oool200000080oooo0P00000e0?oo
o`030000003oool0oooo0?80oooo0P3o00040?ooo`8006Koo`3ooooo0?oooaD0oooo00<000000?oo
o`3oool0<03oool000T0oooo00H000000?ooo`3oool000000?ooo`00000f0?ooo`030000003oool0
oooo0?00oooo0P3o003o0?ooool0oooo7@3oool00`000000oooo0?ooo`0`0?ooo`002@3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0kP3oool2
0?l000040?ooo`00ofH0c?l00<co0?l0ooooo`3ooolK0?ooo`030000003oool0oooo0300oooo0009
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`3/0?ooo`80o`0000@0oooo001Vo`00I_l0c?l0o`3ooooo0?oooad0oooo00<000000?ooo`3oool0
<03oool000T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0>D0oooo0P3<0?l40?ooo`@006Koo`3ooooo0?ooob00oooo00<000000?ooo`3oool0
<03oool000T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0><0oooo0P3o00040?ooo`8006Ko0P3<o`3o0?ooool0oooo8P3oool00`000000oooo
0?ooo`0`0?ooo`002@3oool200000080oooo0P00000f0?ooo`030000003oool0oooo0>40oooo0P3o
003o0?ooool0oooo;03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3O
0?ooo`80o`00o`3ooooo0?ooobh0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0g@3oool20?l00080oooo0P00I_l20<co0?l0ooooo`3ooolZ0?ooo`030000003oool0oooo
0300oooo00150?ooo`030000003oool0oooo0=l0oooo0P00I_l20<co0?l0ooooo`3oool/0?ooo`03
0000003oool0oooo0300oooo000<0?ooo`D00000=03oool00`000000oooo0?ooo`3G0?ooo`80c03o
0`3oool3001Vool0ooooo`3oool`0?ooo`030000003oool0oooo0300oooo000;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3E0?ooo`80o`000`3o
ool2001Vo`03003oIP3oool0oooo0?l0ooooo`3oool`0?ooo`030000003oool0oooo0300oooo000;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3A
0?ooo`@0o`00o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0<03oool000/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`800000103oool2000000@0oooo0P0000030?oo
o`@000003@3oool00`000000oooo0?ooo`3>0?ooo`<0o`0000<0c03o0?ooo`3oool00P3<o`3o0?oo
ool0oooo>@3oool00`000000oooo0?ooo`0;0?ooo`800000103oool2000000@0oooo0P0000030?oo
o`@00000403oool000`0oooo1@00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=80oooo0P00I_oo
0?ooool0oooo>`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`008P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool500000<H0
oooo0P3<0?l40?ooo`800?mV0P00I_oo0?ooool0oooo>03oool6000000`0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100oooo000R0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0<H0oooo0P3o00040?ooo`800?mV0P00I_oo0?ooool0oooo?`3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0?0?ooo`008P3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`34
0?ooo`80o`001P3oool2001Vool0ooooo`3ooom10?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000100
oooo000S0?ooo`8000002P3oool2000000@0oooo0P00000>0?ooo`030000003oool0oooo0<40oooo
0`3o003o0?ooool0ooooB`3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool2000000@0oooo
0P00000A0?ooo`001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0_`3oool20?l000<0oooo00@006Ko003oIP3<o`00c?l0o`3ooooo0?ooodL0oooo
00<000000?ooo`3oool0<03oool000L0oooo0P0000070?ooo`800000<`3oool00`000000oooo0?oo
o`310?ooo`<006Ko0P3<o`3o0?ooool0ooooB@3oool00`000000oooo0?ooo`0`0?ooo`002@3oool7
000003D0oooo00<000000?ooo`3oool0]`3oool20?l00080c03o103oool2001Vo`<0c?l0o`3ooooo
0?oood/0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0]@3oool20?l0
0080c03o103oool2001Vo`80c?l0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool0<03oool004D0
oooo00<000000?ooo`3oool0/`3oool20?l00?l0ooooo`3ooomJ0?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0;40oooo0P3o00040?ooo`80c?l0o`3ooooo0?oooeH0oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0]@3oool2001Vool0ooooo`3o
oomH0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0:X0oooo0P3<0?l5
0?ooo`800?mV0P00I_oo0?ooool0ooooFP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`2V0?ooo`80c03o0P3o00050?ooo`04003oIP00I_l006Ko001Vool0ooooo`3ooomL
0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0:@0oooo103o00060?oo
o`8006Koo`3ooooo0?oooel0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0XP3oool20?l00?l0ooooo`3ooom[0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0:H0oooo0P00I_l20<co0?l0ooooo`3ooomU0?ooo`030000003oool0oooo0300oooo
00150?ooo`030000003oool0oooo09/0oooo0P3<0?l70?ooo`8006Ko0P3<o`3o0?ooool0ooooI`3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`2I0?ooo`030<`0o`3o0000
o`0000H0oooo0P00I_l20<co0?l0ooooo`3ooomY0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo09L0oooo00<0c03o0?l0003o00001P3oool2001Vo`80c?l0o`3ooooo0?oo
of/0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0U@3oool30?l00?l0
ooooo`3ooomg0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo09<0oooo
0P3o00040?ooo`80c?l0o`3ooooo0?ooog@0oooo00<000000?ooo`3oool0<03oool004D0oooo00<0
00000?ooo`3oool0S@3oool20<`0o`P0oooo0P00I_l00`00ofH0oooo0?ooo`3o0?ooool0ooooL`3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`2;0?ooo`80o`001`3oool0
1000ofH006Ko001Vo`00ofKo0?ooool0ooooM`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool0
0`000000oooo0?ooo`280?ooo`030<`0o`3o0000o`0000H0oooo0P00ofH2001Vool0ooooo`3ooomj
0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo08H0oooo0`3o00080?oo
o`8006Koo`3ooooo0?ooog`0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0Q03oool20?l00?l0ooooo`3ooon90?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo07h0oooo0P3<0?l80?ooo`8006Ko00<00?mV0<co003<o`00o`3ooooo0?oooh80oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0O03oool20<`0o`P0oooo0P00
I_l00`00ofH0c?l00<co003o0?ooool0ooooQ03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool0
0`000000oooo0?ooo`1i0?ooo`<0c03o0P3o00060?ooo`8006Ko00<00?mV0<co003<o`00o`3ooooo
0?ooohH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0M`3oool20<`0
o`030?ooo`3o0000o`0000H0oooo0P00I_l00`00ofH0c?l00?ooo`3o0?ooool0ooooR03oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool3000007P0oooo0P3o003o0?ooool0ooooTP3oool400000380
oooo00150?ooo`030000003oool0oooo07H0oooo0P3o00040?ooo`80c?l0o`3ooooo0?oooi40oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0K`3oool20<`0o`T0oooo0P00
I_oo0?ooool0ooooT`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`1]
0?ooo`80o`001`3oool2003oIP8006Koo`3ooooo0?oooiD0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0J`3oool20?l000L0oooo00@00?mV001Vo`00I_l006Koo`3ooooo
0?oooiL0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0J@3oool20?l0
00P0oooo0P00I_oo0?ooool0ooooVP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000
oooo0?ooo`1W0?ooo`80o`00o`3ooooo0?ooojH0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0J`3oool2001Vo`80c?l0o`3ooooo0?oooj00oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0H03oool20<`0o`L0oooo0P00I_l20<co0?l0ooooo`3o
oonR0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo05`0oooo0`3<0?l2
0?l000H0oooo0P00I_oo0?ooool0ooooYP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`1J0?ooo`80c03o00<0oooo0?l0003o00001P3oool2001Vool0ooooo`3ooonX0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo05X0oooo0`3o003o0?ooool0
oooo/P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`1H0?ooo`80o`00
0`3oool2003oIP80c?l0o`3ooooo0?ooojh0oooo00<000000?ooo`3oool0<03oool004D0oooo00<0
00000?ooo`3oool0DP3oool20<`0o`L0oooo00@00?mV001Vo`00I_l0c?l0o`3ooooo0?oook00oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0D03oool20<`0o`H0oooo1000
I_l00`3<o`00oooo0?ooo`3o0?ooool0oooo/03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool0
0`000000oooo0?ooo`1=0?ooo`<0c03o0P3o00040?ooo`8006Ko0P3<o`3o0?ooool0oooo]@3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`1;0?ooo`030<`0o`3o0000o`00
0080o`00o`3ooooo0?oookl0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0BP3oool20?l00?l0ooooo`3oooo30?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo04h0oooo0P00I_l20<co0?l0ooooo`3ooonm0?ooo`030000003oool0oooo0300oooo
00150?ooo`030000003oool0oooo04<0oooo0P3<0?l70?ooo`8006Ko0P3<o`3o0?ooool0oooo_`3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`110?ooo`80o`001P3oool3
001Vool0ooooo`3oooo30?ooo`030000003oool0oooo0300oooo00150?ooo`<00000?`3oool20?l0
00H0oooo0P00I_l00`00ofH0oooo0?ooo`3o0?ooool0oooo`03oool400000380oooo00150?ooo`03
0000003oool0oooo03d0oooo0P3o003o0?ooool0ooood03oool00`000000oooo0?ooo`0`0?ooo`00
A@3oool00`000000oooo0?ooo`0k0?ooo`80o`000P3oool2003oIP80c?l0o`3ooooo0?oool`0oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0=03oool20<`0o`L0oooo0P00
ofH2001Vool0ooooo`3oooo>0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0
oooo0380oooo0P3<0?l70?ooo`@006Koo`3ooooo0?ooom00oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0<03oool20<`0o`030?ooo`3o0000o`0000<0oooo0`00I_l20<co
0?l0ooooo`3ooooB0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo02h0
oooo0P3<0?l00`3oool0o`000?l0003o0?ooool0oooog03oool00`000000oooo0?ooo`0`0?ooo`00
A@3oool00`000000oooo0?ooo`0^0?ooo`<0o`0000<0oooo0<co003<o`00o`3ooooo0?ooom/0oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0;03oool20?l00080oooo0P00
I_l00`00ofH0oooo0?ooo`3o0?ooool0oooofP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool0
0`000000oooo0?ooo`0V0?ooo`80c03o1@3oool01000ofH006Ko001Vo`00ofKo0?ooool0oooogP3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0T0?ooo`80o`00103oool2
003oIP8006Koo`3ooooo0?ooon40oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool08@3oool00`3<0?l0o`000?l000060?ooo`8006Koo`3ooooo0?ooon<0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool07`3oool00`3<0?l0o`000?l0003o0?ooool0
ooook@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0N0?ooo`80o`00
00@0oooo001Vo`00I_l00?mV0P3<o`3o0?ooool0ooooj@3oool00`000000oooo0?ooo`0`0?ooo`00
8`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000h0oooo00<000000?ooo`3oool0
5`3oool20<`0o`H0oooo0P00I_l00`00ofH0c?l00<co003o0?ooool0ooooj`3oool00`000000oooo
0?ooo`0;0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000004@3oool00280oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool05@3oool20<`0o`H0oooo0P00I_l00`00ofH0oooo0?ooo`3o0?oo
ool0ooook@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000@0?ooo`008P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool02`3oool500000140
oooo0P3<0?l20?l000@0oooo0P00I_oo0?ooool0ooook@3oool6000000`0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00h0oooo000R0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool2000000h0oooo00<0
00000?ooo`3oool04@3oool20<`0o`80o`00o`3ooooo0?ooooX0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00000A0?ooo`00
8P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`80o`000P3oool20<co0?l0ooooo`3ooooh0?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0100oooo000S0?ooo`8000002P3oool2000000@0oooo0`00000=
0?ooo`030000003oool0oooo00l0oooo0P3o0000103oool006Ko001Vo`00I_oo0?ooool0oooonP3o
ool00`000000oooo0?ooo`0;0?ooo`8000002P3oool2000000@0oooo0`00000@0?ooo`00A@3oool0
0`000000oooo0?ooo`0?0?ooo`<006Ko00<0c?l00?ooo`3oool0o`3ooooo0?ooooX0oooo00<00000
0?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool03`3oool20<co0?l0ooooo`3oooon0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo0`00003o0?ooool0ooooo`3o
ool=0?ooo`@00000<P3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool300000?l0ooooo`3ooooo
0?ooo`d0oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool300000?l0ooooo`3ooooo
0?ooo`d0oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo0`00003o0?ooool0ooooo`3o
ool=0?ooo`@00000<P3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool@0?ooo`030000003oool0oooo0300oooo000Y0?ooo`800000103oool2000000<0oooo1@00000<
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool02`3oool2
000000@0oooo0P0000030?ooo`D000005@3oool002P0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0<0?ooo`D00000o`3ooooo0?ooool0oooo2@3oool6000000`0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`0E0?ooo`00:03oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
5@3oool002P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo01D0oooo000X0?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0E0?oo
o`00:@3oool2000000X0oooo0P00000>0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00
oooo00<000000?ooo`3oool02`3oool2000000X0oooo0P00000G0?ooo`00A@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo403oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa00
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool0<03oool004D0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`0?0?ooo`L00000o`3ooooo0?ooooT0oooo00<000000?ooo`3oool0<03oool004D0
oooo00<000000?ooo`3oool05P3oool<00000?l0ooooo`3oooo]0?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0280oooo3@00003o0?ooool0ooooh03oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0_0?ooo``00000o`3ooooo0?ooom@0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0>`3oool=00000?l0ooooo`3oooo7
0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo04P0oooo3@00003o0?oo
ool0oooo^P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`1E0?ooo``0
0000o`3ooooo0?ooojh0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0
H@3oool=00000?l0ooooo`3ooonQ0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo06h0oooo3000003o0?ooool0ooooU@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool0
0`000000oooo0?ooo`1j0?oooaL00000o`3ooooo0?ooogh0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0T@3ooolQ000002P0oooo:000003o0?ooool0oooo3@3oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`2b0?ooobP00000:03ooolF00000?l0
oooomP3oool00`000000oooo0?ooo`0`0?ooo`00:@3oool2000000@0oooo0P0000030?ooo`@00000
3@3oool00`000000oooo0?ooo`3o0?oooaT0oooo2000001Q0?ooo``000007@3oool<000000`0oooo
500000330?ooo`h00000:`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00/0oooo
0P0000040?ooo`8000000`3oool4000001H0oooo000X0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool03P3oool500000?l0oooo7`3oool7000001h0oooo4@00000S0?ooo`P00000
303ooolM000000`0oooo3000000D0?ooob/000007@3oool/000002L0oooo0`0000080?ooo`d00000
3@3oool3000000h0oooo:`0000000`3oool000000000000W000000`0oooo1P00000<0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool002P0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo:03oool8000000X0
oooo3000000A0?ooob<00000R03oool?000000L0oooo1`00000/0?ooobL000000`3oool8000000d0
oooo3@00001g0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0F0?ooo`00:03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3oool`0?ooo`X00000e`3oool700000?H0oooo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oool@0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000F0?ooo`00:@3oool2000000X0oooo0P00000>0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooa00oooo00<000000?ooo`3oool02`3oool2000000X0oooo
0P00000G0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool@0?ooo`030000003o
ool0oooo0300oooo00150?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool004D0ooooo`00003o
00000?l000005000000b0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0
oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo
0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0oooo
o`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool0
0?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0oooo
R`3oool00?l0ooooo`3ooooo0?oooh/0oooo001<0?ooo`D000000P3oool2000000@0oooo0P000004
0?ooo`800000G03oool4000000<0oooo0P0000040?ooo`800000103oool200000800oooo0P000004
0?ooo`800000103oool2000000@0oooo0P00001I0?ooo`D000000P3oool2000000@0oooo0P000004
0?ooo`800000103oool2000005D0oooo100000030?ooo`800000103oool2000000@0oooo0P000004
0?ooo`800000N`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001@
0?ooo`D000000P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000004
0?ooo`800000<P3oool004h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000007h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000FP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000007T0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00001A0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03D0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000210?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo05P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00001l0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0C`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0e0?ooo`00CP3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo05/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1m0?ooo`800000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000FP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0E03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0N03oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000D@3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0e0?ooo`00CP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo05T0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000O`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001J0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1B0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000NP3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000540oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0=@3oool004d0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001M0?ooo`800000103oool2000000@0
oooo0P0000040?ooo`800000P03oool3000000<0oooo0P0000040?ooo`800000103oool2000005X0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000EP3oool2000000@0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001k0?ooo`<000000`3oool2000000@0
oooo0P0000040?ooo`800000103oool200000540oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000040?ooo`800000103oool2000003P0oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3o
oooo0?ooool0ooooR`3oool00001\
\>"],
  ImageRangeCache->{{{0, 903}, {451, 0}} -> {2.76524, -3.18147, 0.002676, \
0.00594416}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "rsteinig", "notebooks"}, \
"ljapunov_4er.nb.ps", CharacterEncoding -> "WindowsANSI"],
"Magnification"->1},
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 32, 0, 53, "Section"],
Cell[1774, 53, 50, 1, 30, "Input"],
Cell[1827, 56, 52, 0, 33, "Text"],
Cell[1882, 58, 150, 4, 30, "Input"],
Cell[2035, 64, 60, 0, 33, "Text"],
Cell[2098, 66, 151, 4, 30, "Input"],
Cell[2252, 72, 97, 2, 33, "Text"],
Cell[2352, 76, 180, 4, 30, "Input"],
Cell[2535, 82, 62, 0, 33, "Text"],
Cell[2600, 84, 147, 4, 30, "Input"],
Cell[2750, 90, 51, 0, 33, "Text"],
Cell[2804, 92, 220, 5, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3061, 102, 65, 0, 69, "Title"],

Cell[CellGroupData[{
Cell[3151, 106, 31, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[3207, 110, 29, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[3261, 114, 31, 0, 43, "Subsubsection"],
Cell[3295, 116, 62, 0, 33, "Text"],
Cell[3360, 118, 696, 16, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4093, 139, 30, 0, 43, "Subsubsection"],
Cell[4126, 141, 67, 0, 33, "Text"],
Cell[4196, 143, 510, 11, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4743, 159, 31, 0, 43, "Subsubsection"],
Cell[4777, 161, 62, 0, 33, "Text"],
Cell[4842, 163, 377, 9, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5256, 177, 32, 0, 43, "Subsubsection"],
Cell[5291, 179, 3662, 63, 730, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9002, 248, 36, 0, 47, "Subsection"],
Cell[9041, 250, 396, 9, 70, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9486, 265, 38, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[9549, 269, 36, 0, 47, "Subsection"],
Cell[9588, 271, 137, 3, 33, "Text"],
Cell[9728, 276, 679, 14, 110, "Input"],
Cell[10410, 292, 483, 9, 75, "Text"],
Cell[10896, 303, 796, 16, 130, "Input"],
Cell[11695, 321, 68, 0, 33, "Text"],
Cell[11766, 323, 818, 19, 130, "Input"],
Cell[12587, 344, 60, 0, 33, "Text"],
Cell[12650, 346, 554, 12, 110, "Input"],
Cell[13207, 360, 490, 11, 110, "Input"],
Cell[13700, 373, 812, 17, 110, "Input"],
Cell[14515, 392, 83, 1, 33, "Text"],
Cell[14601, 395, 703, 15, 130, "Input"],
Cell[15307, 412, 72, 0, 33, "Text"],
Cell[15382, 414, 357, 8, 70, "Input"],
Cell[15742, 424, 87, 1, 33, "Text"],
Cell[15832, 427, 746, 15, 190, "Input"],
Cell[16581, 444, 399, 8, 52, "Text"],
Cell[16983, 454, 126, 2, 44, "Text"],
Cell[17112, 458, 751, 18, 110, "Input"],
Cell[17866, 478, 133, 3, 33, "Text"],
Cell[18002, 483, 206, 4, 32, "Text"],
Cell[18211, 489, 1145, 24, 170, "Input"],
Cell[19359, 515, 94, 2, 33, "Text"],
Cell[19456, 519, 553, 12, 130, "Input"],
Cell[20012, 533, 73, 0, 33, "Text"],
Cell[20088, 535, 681, 17, 110, "Input"],
Cell[20772, 554, 73, 0, 33, "Text"],
Cell[20848, 556, 773, 18, 150, "Input"],
Cell[21624, 576, 155, 3, 33, "Text"],
Cell[21782, 581, 755, 18, 150, "Input"],
Cell[22540, 601, 89, 2, 33, "Text"],
Cell[22632, 605, 1202, 26, 170, "Input"],
Cell[23837, 633, 89, 2, 33, "Text"],
Cell[23929, 637, 606, 13, 130, "Input"],
Cell[24538, 652, 75, 0, 33, "Text"],
Cell[24616, 654, 1745, 32, 290, "Input"],
Cell[26364, 688, 94, 2, 33, "Text"],
Cell[26461, 692, 852, 19, 110, "Input"],
Cell[27316, 713, 97, 2, 33, "Text"],
Cell[27416, 717, 1809, 39, 330, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29262, 761, 35, 0, 31, "Subsection"],
Cell[29300, 763, 105, 3, 33, "Text"],
Cell[29408, 768, 14457, 284, 1250, "Input"],
Cell[43868, 1054, 3949, 102, 171, "Input"],

Cell[CellGroupData[{
Cell[47842, 1160, 1048, 31, 90, "Input"],
Cell[48893, 1193, 109230, 3101, 460, 45141, 2305, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

