(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    195777,       6159]*)
(*NotebookOutlinePosition[    196742,       6189]*)
(*  CellTagsIndexPosition[    196698,       6185]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Einstellungen", "Section"],

Cell[BoxData[
    \(\(<< Graphics`;\)\)], "Input"],

Cell["Hier wird die Test-Ausgabe geregelt.", "Text"],

Cell[BoxData[
    StyleBox[\(test\  = \ False;\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]], "Input"],

Cell["Hier wird die Status-Ausgabe geregelt.      ", "Text"],

Cell[BoxData[
    StyleBox[\(status\  = \ True;\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[0, 1, 0]]], "Input"],

Cell["\<\
Hier wird Speichern / Laden eingestellt: Speichern = True, Lesen = False \
\>", "Text"],

Cell[BoxData[
    StyleBox[\(SaveOrLoad\  = \ False; \ filename = "\<5er\>";\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[0, 0, 1]]], "Input"],

Cell["Hier wird die Zahl der Rechnungen eingestellt.", "Text"],

Cell[BoxData[
    StyleBox[\(loops\  = \ 1;\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 1]]], "Input"],

Cell["Hier wird die Darstellung geregelt.", "Text"],

Cell[BoxData[
    StyleBox[\(colors\  = \ 
          Join[Table[GrayLevel[i/18], {i, 1, 9}], 
            Table[{Dashing[{0.01}], Hue[i/14]}, {i, 1, 14}]];\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[0, 1, 1]]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Diplomarbeit \"Dynamik klassischer Spinsysteme\"", "Title"],

Cell[CellGroupData[{

Cell["Definitionen", "Section"],

Cell[CellGroupData[{

Cell["Systeme", "Subsection"],

Cell[CellGroupData[{

Cell["Ketten", "Subsubsection"],

Cell["An dieser Stelle werden Spin-Ketten definiert.", "Text"],

Cell[BoxData[{\(string2\  = \ {{1, 
            2}};\), "\[IndentingNewLine]", \(string3\  = \ 
        Append[string2, {2, 3}];\), "\[IndentingNewLine]", \(string4\  = \ 
        Append[string3, {3, 4}];\), "\[IndentingNewLine]", \(string5\  = \ 
        Append[string4, {4, 5}];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox["string5",
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ringe", "Subsubsection"],

Cell["An dieser Stelle werden Spin-Ringe definiert.      ", "Text"],

Cell[BoxData[{\(ring3\  = 
        Append[string3, {3, 1}];\), "\[IndentingNewLine]", \(ring4\  = 
        Append[string4, {4, 1}];\), "\[IndentingNewLine]", \(ring5\  = 
        Append[string5, {5, 1}];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, ring5]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sterne", "Subsubsection"],

Cell["An dieser Stelle werden Spin-Sterne definiert.", "Text"],

Cell[BoxData[{\(star5 = {{1, 5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, star5]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Weitere", "Subsubsection"],

Cell[BoxData[{\(ring4with1d\  = \ 
        Append[ring4, {1, 3}];\), "\[IndentingNewLine]", \(ring4with2d\  = \ 
        Append[ring4with1d, {2, 
            4}];\), "\[IndentingNewLine]", \(T1\  = \ {{1, 2}, {2, 3}, {3, 
            4}, {2, 4}};\), "\[IndentingNewLine]", 
    RowBox[{\(T2\  = \ {{1, 2}, {2, 3}, {2, 4}};\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(all4 = {string4, ring4, ring4with1d, ring4with2d, T1, T2};\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(A5 = {{1, 2}, {2, 
            3}, {3, 4}, {4, 1}, {4, 
            5}};\), "\[IndentingNewLine]", \(B5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {4, 
            5}};\), "\[IndentingNewLine]", \(C5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {4, 
            5}};\), "\[IndentingNewLine]", \(D5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {2, 4}, {4, 
            5}};\), "\[IndentingNewLine]", \(E5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 5}};\), "\[IndentingNewLine]", \(F5 = {{1, 2}, {2, 
            3}, {2, 4}, {3, 4}, {4, 
            5}};\), "\[IndentingNewLine]", \(G5\  = {{1, 2}, {2, 3}, {3, 
            4}, {3, 5}};\), "\[IndentingNewLine]", \(H5\  = {{1, 2}, {2, 
            3}, {3, 4}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(I5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 5}, {5, 1}};\), "\[IndentingNewLine]", \(J5 = {{1, 
            5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(K5 = {{1, 5}, {2, 5}, {3, 
            4}, {3, 5}, {4, 5}};\), "\[IndentingNewLine]", \(L5 = {{1, 
            2}, {1, 5}, {2, 5}, {3, 4}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(M5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(N5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(O5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {2, 4}, {1, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(P5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 5}, {3, 
            5}};\), "\[IndentingNewLine]", \(Q5\  = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {3, 
            5}};\), "\[IndentingNewLine]", \(R5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {1, 5}, {3, 
            5}};\), "\[IndentingNewLine]", \(S5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(T5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 3}, {2, 4}, {1, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(U5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {1, 5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", \(V5 = {{1, 2}, {2, 3}, {3, 
            4}, {4, 1}, {2, 4}, {1, 5}, {2, 5}, {3, 5}, {4, 
            5}};\), "\[IndentingNewLine]", 
    RowBox[{\(W5 = {{1, 2}, {2, 3}, {3, 4}, {4, 1}, {1, 3}, {2, 4}, {1, 
              5}, {2, 5}, {3, 5}, {4, 5}};\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(notint5\  = \ {A5, 
          B5, E5, F5, G5, H5, I5, M5, 
          N5};\), "\[IndentingNewLine]", \(int5\  = \ {C5, D5, J5, K5, L5, 
          05, P5, Q5, R5, S5, T5, U5, V5, W5};\), "\[IndentingNewLine]", 
    RowBox[{\(all5\  = \ Join[notint5, int5];\), "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[\(If[test, int5]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spin-Variablen", "Subsection"],

Cell[BoxData[{\(s[\[Mu]_] = 
        Table[\(s[\[Mu], i]\)[t], {i, 1, 3}];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, MatrixForm[s[\[Mu]]]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ljaponov-Exponenten", "Section"],

Cell[CellGroupData[{

Cell["Unterprogramme", "Subsection"],

Cell[BoxData[
    \(Dieses\ Unterprogramm\ liefert\ die\ Kopplungsmatrix\ J\_\(\(\[Mu]\[Nu]\
\)\(.\)\)\)], "Text",
  FontFamily->"Times"],

Cell[BoxData[{\(getJ[N_, coupling_, strength_]\  := \ 
        Module[{\[Mu], \[Nu]}, \[IndentingNewLine]J\  = \ 
            Table[If[
                MemberQ[coupling, {\[Mu], \[Nu]}] || 
                  MemberQ[coupling, {\[Nu], \[Mu]}], strength, 0], {\[Mu], 1, 
                N}, {\[Nu], 1, 
                N}]; \ \[IndentingNewLine]J];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, MatrixForm[getJ[2, string2, 1]]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[BoxData[
    \(Dieses\ Unterprogramm\ liefert\ die\ Hamiltonschen\ \
Bewegungsgleichungen . \[IndentingNewLine]H\  = \ \(\[Sum]\+\(\[Mu]\  < \ \
\[Nu]\)J\_\[Mu]\[Nu]\ s\_\[Mu]*
            s\_\[Nu]\ und\ s\& . \_\[Mu]\  = \ \(\[PartialD]\ H\/\[PartialD]\ \
s\_\(\_\[Mu]\)\ x\ s\_\[Mu]\ \  \[Rule] \ 
            s\& . \_\[Mu]\  = \ \[Sum]\+\(\[Mu]\  < \ \
\[Nu]\)\(\(J\_\[Mu]\[Nu]\)\(\ \)\(s\_\[Nu]\)\(\ \)\(x\)\(\ \)\(s\_\[Mu]\)\(\ \
\)\)\)\)\)], "Text",
  FontFamily->"Times"],

Cell[BoxData[{\(getEquations[N_, coupling_, strength_]\  := \ 
        Module[{\[Mu], \[Nu], i}, \[IndentingNewLine]J\  = \ 
            getJ[N, coupling, strength]; \[IndentingNewLine]equations\  = \ 
            Table[\(s[\[Mu], i]'\)[t] == \ 
                Sum[J[\([\[Mu], \[Nu]]\)]\ *\ \(Cross[s[\[Nu]], 
                        s[\[Mu]]]\)[\([i]\)], {\[Nu], 1, N}], {\[Mu], 1, 
                N}, {i, 1, 
                3}]; \[IndentingNewLine]equations];\), "\[IndentingNewLine]", 
  
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, getEquations[2, string2, 1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert die Anfangsbedingungen.", "Text"],

Cell[BoxData[{\(getInit[v_]\  := \ 
        Module[{N, init, \[Mu], i}, \[IndentingNewLine]N\  = \ 
            First[Dimensions[v]]; \[IndentingNewLine]init = 
            Table[\(s[\[Mu], i]\)[0] \[Equal] v[\([\[Mu], i]\)], {\[Mu], 1, 
                N}, {i, 1, 
                3}]; \[IndentingNewLine]init];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(getInit[{{0, 0, 1}}]\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert das DGL-System.", "Text"],

Cell[BoxData[{\(getSystem[equations_, v_]\  := \ 
        Module[{init}, \[IndentingNewLine]init\  = 
            getInit[v]; \[IndentingNewLine]Join[init, 
            equations]];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, 
        getSystem[getEquations[2, string2, 1], {{1, 0, 0}, {0, 1, 0}}]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[BoxData[{\(getVar[N_]\  := \ 
        Module[{var, \[Mu]}, \[IndentingNewLine]var\  = \ 
            Table[s[\[Mu]], {\[Mu], 1, 
                N}]; \[IndentingNewLine]var];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, getVar[2]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[BoxData[{\(getSolution[system_, var_, \[CapitalDelta]t_]\  := \ 
        Module[{solution}, \[IndentingNewLine]solution\  = \ 
            Flatten[NDSolve[Flatten[system], 
                Flatten[var], {t, 0, \[CapitalDelta]t}, 
                Method \[Rule] RungeKutta]]; \[IndentingNewLine]\(var\  //. \ 
              solution\)\  //. \ 
            t \[Rule] \ \[CapitalDelta]t];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, 
        getSolution[
          getSystem[getEquations[2, string2, 1], {{1, 0, 0}, {0, 1, 0}}], 
          getVar[2], 1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm f\[UDoubleDot]hrt die Zeitentwicklung durch.", \
"Text"],

Cell[BoxData[{\(flow[equations_, var_, v_, \[CapitalDelta]t_]\  := \ 
        Module[{system, solution}, \[IndentingNewLine]system\  = \ 
            getSystem[equations, v]; \[IndentingNewLine]solution = \ 
            getSolution[system, 
              var, \[CapitalDelta]t]; \[IndentingNewLine]solution];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, 
        flow[getEquations[2, string2, 1], getVar[2], {{1, 0, 0}, {0, 1, 0}}, 
          1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm berechnet den Betrag eines Vektors.", "Text"],

Cell[BoxData[{\(norm[v_] := Sqrt[v . v];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, norm[{1, 0, 0}]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramme liefern zuf\[ADoubleDot]llige Einheitsvektoren.", \
"Text"],

Cell[BoxData[{\(generate\  := \ 
        Module[{v}, \[IndentingNewLine]v\  = \ {2*Random[] - 1, 
              2*Random[] - 1, 2*Random[] - 1}; \[IndentingNewLine]v\  = \ 
            v\ /\ norm[v]; \[IndentingNewLine]v];\), "\[IndentingNewLine]", 
    RowBox[{\(generateAll[N_]\  := \ 
          Module[{v, \[Mu]}, \[IndentingNewLine]v\  = \ 
              Table[generate, {\[Mu], 1, N}]; \[IndentingNewLine]v];\), 
      "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[\(If[test, generateAll[1]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell[TextData[{
  "Dieses Unterprogramm wandelt den Vektor \[Omega] in eine antysymmetrische \
Matrix \[CapitalOmega] um.\nDie Signatur nimmt die Werte ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\))\)\^n\ an . \ 
          Dabei\ ist\ n\ die\ Zahl\ der\ ben\[ODoubleDot]tigten\ \
Transpositionen\ f\[UDoubleDot]r\ das\ Erreichen\ einer\ kanonische\ \
\(\(Reihenfolge\)\(.\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(\[CapitalOmega]\_ij\  = \ \(-\(\[Sum]\+k 
            signatur \((i, j, k)\)*\ \[Omega]\_k\)\)\)], "Text"],

Cell[BoxData[{\(getMatrix[\[Omega]_]\  := \ 
        Module[{i, j, k}, \[IndentingNewLine]\ \[CapitalOmega]\  = 
            Table[\(-Sum[
                  Signature[{i, j, k}] \[Omega][\([k]\)], {k, 1, 3}]\), {i, 
                1, 3}, {j, 1, 
                3}]; \[IndentingNewLine]\ \[CapitalOmega]];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(MatrixForm[getMatrix[{0, 0, 1}]]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm erstellt eine Drehmatrix zu der Drehachse \[Omega] und \
dem Winkel \[CurlyPhi] = |w| t.\
\>", "Text"],

Cell[BoxData[
    \(R\_ij\  = \ \(\[Delta]\_ij\) 
          cos\[CurlyPhi]\  + \ \(e\_i\) \(e\_j\) \((1 - 
              cos\[CurlyPhi])\)\  + \ \(\[CapitalOmega]\_ij\) 
          sin\[CurlyPhi]\)], "Text"],

Cell[BoxData[{
    RowBox[{\(getRotation[\[Omega]_, t_]\ \  := \ 
          Module[{e, \[CurlyPhi], \[CapitalOmega], i, j, 
              R}, \[IndentingNewLine]e = \ \[Omega]/
                norm[\[Omega]]; \[IndentingNewLine]\[CurlyPhi]\  = \ 
              norm[\[Omega]]\ *\ t; \[IndentingNewLine]\[CapitalOmega]\  = \ 
              getMatrix[e]; \[IndentingNewLine]R = 
              Table[If[i \[Equal] j, Cos[\[CurlyPhi]], 0] + 
                  e[\([i]\)] 
                    e[\([j]\)] \((1 - 
                        Cos[\[CurlyPhi]])\) + \[CapitalOmega][\([i, j]\)] 
                    Sin[\[CurlyPhi]], {i, 1, 3}, {j, 1, 
                  3}]; \[IndentingNewLine]R];\), "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(MatrixForm[getRotation[{0, 0, 1}, Pi/2]]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm liefert die normierte Drehachse \[Omega] = a x b.\
\>", "Text"],

Cell[BoxData[{\(getAxes[a_, b_]\  := \ 
        Module[{\[Omega], e}, \[IndentingNewLine]\[Omega]\  = \ 
            Cross[a, b]; \[IndentingNewLine]e\  = \ \[Omega]/
              norm[\[Omega]]; \[IndentingNewLine]e];\), "\[IndentingNewLine]",
   
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, getAxes[{1, 0, 0}, {0, 1, 0}]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert den Winkel zwischen a und b.", "Text"],

Cell[BoxData[{\(getAngle[a_, b_]\  := \ 
        Module[{\[CurlyPhi]}, \[IndentingNewLine]\[CurlyPhi]\  = \ 
            ArcCos[a . 
                  b\ /\ \((norm[a]\ *\ 
                    norm[b])\)]; \[IndentingNewLine]\[CurlyPhi]];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(getAngle[{1, 0, 0}, {0, 1, 0}]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm liefert die Drehmatrix von a nach b.", "Text"],

Cell[BoxData[{\(getRotationFromTo[a_, b_] := 
        Module[{e, \[CurlyPhi], R}, \[IndentingNewLine]e\  = \ 
            getAxes[a, b]; \[IndentingNewLine]\[CurlyPhi]\  = \ 
            getAngle[a, b]; \[IndentingNewLine]R\  = \ 
            getRotation[
              e, \[CurlyPhi]]; \[IndentingNewLine]R];\), \
"\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(MatrixForm[getRotationFromTo[{1, 0, 0}, {0, 1, 0}]]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm erzeugt einen Vektor c, der auf dem Gro\[SZ]kreis durch \
a und b liegt und den Abstand d(a,c) = \[Delta] hat.\
\>", "Text"],

Cell[BoxData[{\(shrink[a_, b_, \[Delta]_]\  := \ 
        Module[{e, R, c}, \[IndentingNewLine]e = 
            getAxes[a, b]; \[IndentingNewLine]R\  = \ 
            getRotation[e, \[Delta]]; \[IndentingNewLine]c\  = \ 
            R . a; \[IndentingNewLine]c];\), "\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0],
      Background->None], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(shrink[{1, 0, 0}, {0, 1, 0}, Pi/2]\),
            FontSlant->"Italic"]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0],
      Background->None]}], "Input"],

Cell["\<\
Dieses Unterprogramm erweitert die Funktion auf mehrere Vektoren.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{\(shrinkAll[a_, b_, \[Delta]_]\  := \ 
          Module[{N, \[CurlyPhi], \[Phi], 
              c, \[Mu]}, \[IndentingNewLine]N\  = \ 
              First[Dimensions[a]]; \[IndentingNewLine]\[CurlyPhi]\  = \ 
              Table[getAngle[a[\([\[Mu]]\)], b[\([\[Mu]]\)]], {\[Mu], 1, 
                  N}]; \[IndentingNewLine]\[Phi]\  = \ 
              Sqrt[Sum[\[CurlyPhi][\([\[Mu]]\)]^2, {\[Mu], 1, 
                    N}]]; \[IndentingNewLine]c\  = \ 
              Table[shrink[a[\([\[Mu]]\)], 
                  b[\([\[Mu]]\)], \[Delta]/\[Phi]\ *\ \
\[CurlyPhi][\([\[Mu]]\)]], {\[Mu], 1, N}]; \[IndentingNewLine]{c, \[Phi]}];\),
       "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"If", "[", 
        RowBox[{"test", ",", 
          StyleBox[\(shrinkAll[{{1, 0, 0}}, {{0, 1, 0}}, Pi/2]\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]]}], "]"}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["\<\
Dieses Unterprogramm zeigt den Status der Rechnung in Prozent an.\
\>", "Text"],

Cell[BoxData[{\(showPercentage[i_, max_]\  := \ 
        Module[{percentage}, \[IndentingNewLine]percentage\  = \ 
            i/\((max/100)\); \[IndentingNewLine]If[
            Mod[percentage, 10]\  \[Equal] \ 0, 
            Print[percentage\ "\<%\>"\ ]];\[IndentingNewLine]];\), "\
\[IndentingNewLine]", 
    StyleBox[\( (*Test*) \),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    StyleBox[\(If[test, showPercentage[10, 100]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"],

Cell["Dieses Unterprogramm gibt das Erbenis der Rechnung aus.    ", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(showResults[results_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          RowBox[{\({loglogresults, g}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(loglogresults\  = \ N[Log[10, results]]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"g", " ", "=", 
                RowBox[{"MultipleListPlot", "[", 
                  RowBox[{
                  "loglogresults", ",", 
                    "\[IndentingNewLine]", \(PlotJoined \[Rule] True\), ",", 
                    "\[IndentingNewLine]", \(PlotRange \[Rule] Automatic\), 
                    ",", "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
                    "\[IndentingNewLine]", \(Ticks \[Rule] \ {LogScale, 
                        LogScale}\), ",", 
                    "\[IndentingNewLine]", \(Frame \[Rule] True\), ",", 
                    "\[IndentingNewLine]", \(FrameTicks \[Rule] {LogScale, 
                        LogScale}\), ",", 
                    "\[IndentingNewLine]", \(SymbolShape \[Rule] None\), ",", 
                    "\[IndentingNewLine]", 
                    StyleBox[\(PlotStyle \[Rule] colors\),
                      FontColor->RGBColor[0, 1, 1]], 
                    StyleBox[",",
                      FontColor->RGBColor[0, 1, 1]], 
                    "\[IndentingNewLine]", \(FrameLabel \[Rule] \
{StyleForm["\<K\>", FontSize \[Rule] 16], 
                        StyleForm[\*"\"\<\!\(\[CapitalLambda]\_k\)(\!\(s\_0\))\
\>\"", FontSize \[Rule] 16], "\<\>", "\<\>"}\), ",", 
                    "\[IndentingNewLine]", \(AspectRatio \[Rule] 0.5\)}], 
                  "]"}]}], ";", "\[IndentingNewLine]", "g"}]}], "]"}]}], 
      ";"}]], "Input"],

Cell["\<\
Dieses Unterprogramm schreibt das Ergebnis der Rechnung in eine Datei.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(saveResults[results_, filename_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            
            StyleBox[\( (*Es\ k\[ODoubleDot]nnen\ nur\ zweidimensionale\ \
Tabellen\ geschrieben\ \(\(werden\)\(.\)\)*) \),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
            
            StyleBox[\( (*Deswegen\ gehen\ wir\ von\ 3  
                  D\ auf\ 2 \( \(D\)\(.\)\)*) \),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->GrayLevel[0.500008]], 
            "\[IndentingNewLine]", \(Export[filename, 
                Flatten[results, 1]];\)}], "\[IndentingNewLine]", "]"}]}], 
      ";"}]], "Input"],

Cell["\<\
Dieses Unterprogramm liest das Ergebnis der Rechnung aus einer Datei.    \
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(loadResults[from_]\), " ", ":=", " ", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({results, temp, allTemp, i}\), ",", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*Es\ k\[ODoubleDot]nnen\ nur\ zweidimensionale\ \
Tabellen\ gelesen\ \(\(werden\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
              
              StyleBox[\( (*Deswegen\ gehen\ wir\ von\ 2  
                    D\ auf\ 3 \( \(D\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], 
              "\[IndentingNewLine]", \(results\  = \ 
                Import[from]; \[IndentingNewLine]temp\  = \ {}; \
\[IndentingNewLine]allTemp\  = \ {}; \[IndentingNewLine]For[i\  = \ 1, 
                i\  \[LessEqual] \ 
                  Length[results], \(i++\), \[IndentingNewLine]temp\  = \ 
                  Append[temp, results[\([i]\)]]; \[IndentingNewLine]If[\ 
                  Mod[i, 100]\  \[Equal] \ 
                    0, \[IndentingNewLine]allTemp\  = \ 
                    Append[allTemp, 
                      temp]; \[IndentingNewLine]temp\  = \ {};\
\[IndentingNewLine]];\[IndentingNewLine]]; \[IndentingNewLine]allTemp\)}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      StyleBox[\( (*Test*) \),
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    StyleBox[\(If[test, loadResults[filename\  <> \ "\<.dat\>"]]\),
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontColor->RGBColor[1, 0, 0]]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hauptprogramm", "Subsection"],

Cell["\<\
Das Hauptprogramm berechnet numerisch den (approximativen) \
Ljapunov-Exponenten.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ljapunov[spins_, systems_, steps_, \[Delta]_, t_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({a, b, c, u, v, w, i, j, \[CapitalDelta], summation, 
              results, allResults, coupling, equations}\), ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*An\ dieser\ Stelle\ werden\ die\ Spin - 
                  Variablen\ \(\(erstellt\)\(.\)\)*) \),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
            RowBox[{\(var\  = \ getVar[spins]\), ";", "\[IndentingNewLine]", 
              StyleBox[\(If[status, Print["\<Coordinates created.\>"]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
              StyleBox[\(If[test, Print[var]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*An\ dieser\ Stelle\ werden\ zuf\[ADoubleDot]llige\
\ Anfangsbedingungen\ \(\(erstellt\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
              StyleBox[\(a\  = \ generateAll[spins]\),
                Background->RGBColor[1, 0, 0]], ";", "\[IndentingNewLine]", 
              StyleBox[\(b\  = \ generateAll[spins]\),
                Background->RGBColor[1, 0, 0]], ";", 
              "\[IndentingNewLine]", \({c, \[CapitalDelta]}\  = \ 
                shrinkAll[a\ , b, \[Delta]]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\(If[status, 
                  Print["\<Initial Conditions created.\>"\ ]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
              StyleBox[\(If[status, Print[a]; \ Print[b]; \ Print[c]]\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox[";",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(allResults\  = \ {}\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              
              StyleBox[\( (*Diese\ Schleife\ durchl\[ADoubleDot]uft\ die\ \
Spin - \(\(Systeme\)\(.\)\)*) \),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
                
                RowBox[{\(i\  = \ 1\), 
                  ",", \(i\  \[LessEqual] Length[systems]\), ",", \(i++\), 
                  ",", "\[IndentingNewLine]", 
                  RowBox[{
                    
                    StyleBox[\(If[status, 
                        Print["\<System \>"\  <> \ 
                            ToString[i]\  <> \ "\< of \>"\  <> \ 
                            ToString[Length[systems]]\  <> \ "\< ...\>"]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*Jedes\ Spin - 
                          System\ beginnt\ mit\ den\ gleichen\ \
\(\(Anfangsbedingugen\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], 
                    "\[IndentingNewLine]", \(u\  = \ a\), ";", 
                    " ", \(v\  = \ b\), ";", " ", \(w\  = \ c\), ";", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\(If[status, 
                        Print["\<Initial Conditions reset.\>"\ ]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    StyleBox[\(If[test, Print[u]; \ Print[v]; \ Print[w]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*An\ dieser\ Stelle\ werden\ die\ Kopplungen\
\ \(\(erstellt\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], 
                    "\[IndentingNewLine]", \(coupling\  = \ 
                      systems[\([i]\)]\), ";", "\[IndentingNewLine]", 
                    StyleBox[\(If[status, Print["\<Coupling created.\>"]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    StyleBox[\(If[test, Print[coupling]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*An\ dieser\ Stelle\ werden\ die\ \
Bewegungsgleichungen\ \(\(erstellt\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], 
                    "\[IndentingNewLine]", \(equations\  = \ 
                      getEquations[spins, coupling, 1]\), ";", 
                    "\[IndentingNewLine]", 
                    
                    StyleBox[\(If[status, 
                        Print["\<Equations created.\>"\ ]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    StyleBox[\(If[test, Print[equations]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", \(summation\  = \ 0\), ";", 
                    "\[IndentingNewLine]", \(results\  = \ {}\), ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    
                    StyleBox[\( (*Diese\ Schleife\ \(d  
                            urchl\[ADoubleDot]uft\)\ abwechselnd\ eine\ \
Zeitentwicklung\ und\ einen\ \(\(Schrumpfprozess\)\(.\)\)*) \),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
                    
                    StyleBox[\(If[status, Print["\<Calculating...\>"\ ]]\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], 
                    StyleBox[";",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                    RowBox[{"For", "[", 
                      
                      RowBox[{\(j = 1\), ",", \(j \[LessEqual] \ steps\), 
                        ",", \(j++\), ",", "\[IndentingNewLine]", 
                        RowBox[{
                          StyleBox[\(If[status, showPercentage[j, steps]]\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 1, 0]], 
                          StyleBox[";",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 1, 0]], 
                          "\[IndentingNewLine]", "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*An\ dieser\ Stelle\ findet\ die\ \
Zeitentwicklung\ \(\(statt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \(u\  = \ 
                            flow[equations, var, u, t]\), ";", 
                          "\[IndentingNewLine]", \(v\  = \ 
                            flow[equations, var, w, t]\), ";", 
                          "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*An\ dieser\ Stelle\ findet\ der\ \
Schrumpfprozess\ \(\(statt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \({w, \[CapitalDelta]}\  = \ 
                            shrinkAll[u, v, \[Delta]]\), ";", 
                          "\[IndentingNewLine]", "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*An\ dieser\ Stelle\ wird\ der\ \
Ljapunov - Exponent\ \(\(bestimmt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \(summation\  = \ 
                            summation\  + \ Log[\[CapitalDelta]/\[Delta]]\), 
                          ";", "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*Nicht\ jeder\ Punkt\ wird\ in\ die\ \
Liste\ \(\(aufgenommen\)\(:\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          StyleBox["\[IndentingNewLine]",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          
                          StyleBox[\( (*\(\(-der\)\ Einschwingvorgang\ wird\ \
ber\[UDoubleDot]cksichtigt\)\(,\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          StyleBox["\[IndentingNewLine]",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          
                          StyleBox[\( (*\(-die\)\ Aufl\[ODoubleDot]sung\ wird\
\ \(\(ber\[UDoubleDot]cksichtigt\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          StyleBox[" ",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", 
                          
                          StyleBox[\( (*\(-der\)\ Imgagin\[ADoubleDot]rteil \
\((numerischer\ Fehler)\)\ wird\ \(\(gestrichen\)\(.\)\)*) \),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            FontColor->GrayLevel[0.500008]], 
                          "\[IndentingNewLine]", \(If[
                            j\  \[GreaterEqual] \((steps/100)\) && \ 
                              Mod[j, \((steps/100)\)] \[Equal] 0, 
                            results\  = \ 
                              Append[
                                results, {j, Re[summation]/\((j\ *\ t)\)}]]\),
                           ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
                    "\[IndentingNewLine]", \(allResults\  = \ 
                      Append[allResults, results]\), ";", 
                    "\[IndentingNewLine]", 
                    StyleBox[\(If[status, showResults[allResults]];\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 1, 0]]}]}], 
                "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
              "allResults"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["If",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["[",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox["SaveOrLoad",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\[IndentingNewLine]",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          RowBox[{
            RowBox[{
              StyleBox["For",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 1]], 
              StyleBox["[",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 1]], 
              RowBox[{
                StyleBox[\(i = 1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[",",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[\(i \[LessEqual] \ loops\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[",",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[\(i++\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox[",",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 1]], 
                StyleBox["\[IndentingNewLine]",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], 
                RowBox[{
                  
                  StyleBox[\(If[status, 
                      Print["\<Loop \>"\  <> \ 
                          ToString[i]\  <> \ "\< of \>"\  <> \ 
                          ToString[loops]\  <> \ "\< ...\>"]]\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 1, 0]], 
                  StyleBox[";",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 1, 0]], "\[IndentingNewLine]", 
                  RowBox[{"results", " ", "=", 
                    
                    StyleBox[\(ljapunov[5, all5, 10\^5, 10\^\(-3\), 
                        10\^\(-1\)]\),
                      Background->RGBColor[1, 0, 0]]}], 
                  StyleBox[";",
                    Background->None], 
                  "\[IndentingNewLine]", \(saveResults[results, 
                    filename\  <> "\<_\>" <> ToString[\ i] <> \ "\<.dat\>"]\),
                   ";", "\[IndentingNewLine]", \(showResults[results]\), 
                  ";"}]}], "\[IndentingNewLine]", 
              StyleBox["]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontColor->RGBColor[1, 0, 1]]}], 
            StyleBox[";",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 1]]}]}], 
        StyleBox["\[IndentingNewLine]",
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[";",
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1]]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["If",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["[",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox[\(! SaveOrLoad\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1]], 
          "\[IndentingNewLine]", \(results\  = 
            loadResults[
              filename\  <> \ "\<.dat\>"]; \[IndentingNewLine]showResults[
            results];\)}], "\[IndentingNewLine]", 
        StyleBox["]",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[";",
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1]]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.40476 0.47619 0.488095 0.149188 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.16716 -0.0125 -14 -12.5625 ]
[.16716 -0.0125 14 0 ]
[.35665 -0.0125 -14 -12.5625 ]
[.35665 -0.0125 14 0 ]
[.5 -0.0125 -17 -12.5625 ]
[.5 -0.0125 17 0 ]
[.64335 -0.0125 -17 -12.5625 ]
[.64335 -0.0125 17 0 ]
[.83284 -0.0125 -17 -12.5625 ]
[.83284 -0.0125 17 0 ]
[.97619 -0.0125 -23 -12.5625 ]
[.97619 -0.0125 23 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -26.4375 ]
[.5 -0.0125 6.78125 -12.5625 ]
[-0.0125 .04053 -34 -6.28125 ]
[-0.0125 .04053 0 6.28125 ]
[-0.0125 .14481 -34 -6.28125 ]
[-0.0125 .14481 0 6.28125 ]
[-0.0125 .18972 -28 -6.28125 ]
[-0.0125 .18972 0 6.28125 ]
[-0.0125 .294 -28 -6.28125 ]
[-0.0125 .294 0 6.28125 ]
[-0.0125 .33891 -22 -6.28125 ]
[-0.0125 .33891 0 6.28125 ]
[-0.0125 .44319 -22 -6.28125 ]
[-0.0125 .44319 0 6.28125 ]
[-0.0125 .4881 -10 -6.28125 ]
[-0.0125 .4881 0 6.28125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .25 -48.9375 -28.4375 ]
[-0.01875 .25 -34 28.4375 ]
[.02381 .5125 -14 0 ]
[.02381 .5125 14 12.5625 ]
[.16716 .5125 -14 0 ]
[.16716 .5125 14 12.5625 ]
[.35665 .5125 -14 0 ]
[.35665 .5125 14 12.5625 ]
[.5 .5125 -17 0 ]
[.5 .5125 17 12.5625 ]
[.64335 .5125 -17 0 ]
[.64335 .5125 17 12.5625 ]
[.83284 .5125 -17 0 ]
[.83284 .5125 17 12.5625 ]
[.97619 .5125 -23 0 ]
[.97619 .5125 23 12.5625 ]
[ 0 .5 .125 0 ]
[1.0125 .04053 0 -6.28125 ]
[1.0125 .04053 34 6.28125 ]
[1.0125 .14481 0 -6.28125 ]
[1.0125 .14481 34 6.28125 ]
[1.0125 .18972 0 -6.28125 ]
[1.0125 .18972 28 6.28125 ]
[1.0125 .294 0 -6.28125 ]
[1.0125 .294 28 6.28125 ]
[1.0125 .33891 0 -6.28125 ]
[1.0125 .33891 22 6.28125 ]
[1.0125 .44319 0 -6.28125 ]
[1.0125 .44319 22 6.28125 ]
[1.0125 .4881 0 -6.28125 ]
[1.0125 .4881 10 6.28125 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .5005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16716 0 m
.16716 .00625 L
s
gsave
.16716 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.35665 0 m
.35665 .00625 L
s
gsave
.35665 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.64335 0 m
.64335 .00625 L
s
gsave
.64335 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.83284 0 m
.83284 .00625 L
s
gsave
.83284 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -84 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.25101 0 m
.25101 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.39436 0 m
.39436 .00375 L
s
.42624 0 m
.42624 .00375 L
s
.45385 0 m
.45385 .00375 L
s
.47821 0 m
.47821 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.7867 0 m
.7867 .00375 L
s
.87055 0 m
.87055 .00375 L
s
.90243 0 m
.90243 .00375 L
s
.93004 0 m
.93004 .00375 L
s
.9544 0 m
.9544 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7813 -30.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.875 translate 1 -1 scale
63.000 14.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
72.563 14.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04053 m
.00625 .04053 L
s
gsave
-0.0125 .04053 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14481 m
.00625 .14481 L
s
gsave
-0.0125 .14481 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .18972 m
.00625 .18972 L
s
gsave
-0.0125 .18972 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .294 m
.00625 .294 L
s
gsave
-0.0125 .294 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33891 m
.00625 .33891 L
s
gsave
-0.0125 .33891 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44319 m
.00625 .44319 L
s
gsave
-0.0125 .44319 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4881 m
.00625 .4881 L
s
gsave
-0.0125 .4881 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .08544 m
.00375 .08544 L
s
0 .11171 m
.00375 .11171 L
s
0 .13035 m
.00375 .13035 L
s
0 .15662 m
.00375 .15662 L
s
0 .16661 m
.00375 .16661 L
s
0 .17526 m
.00375 .17526 L
s
0 .18289 m
.00375 .18289 L
s
0 .23463 m
.00375 .23463 L
s
0 .2609 m
.00375 .2609 L
s
0 .27954 m
.00375 .27954 L
s
0 .30581 m
.00375 .30581 L
s
0 .3158 m
.00375 .3158 L
s
0 .32445 m
.00375 .32445 L
s
0 .33208 m
.00375 .33208 L
s
0 .38382 m
.00375 .38382 L
s
0 .41009 m
.00375 .41009 L
s
0 .42873 m
.00375 .42873 L
s
0 .455 m
.00375 .455 L
s
0 .46499 m
.00375 .46499 L
s
0 .47364 m
.00375 .47364 L
s
0 .48127 m
.00375 .48127 L
s
.25 Mabswid
0 0 m
0 .5 L
s
gsave
-0.01875 .25 -130.906 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
89.4375 11.4688 translate
90 rotate
-89.4375 -11.4688 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.9375 translate 1 -1 scale
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
72.563 17.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 14.938 moveto
(H) show
89.438 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
99.000 17.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.313 14.938 moveto
(L) show
115.875 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .49375 m
.02381 .5 L
s
gsave
.02381 .5125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16716 .49375 m
.16716 .5 L
s
gsave
.16716 .5125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.35665 .49375 m
.35665 .5 L
s
gsave
.35665 .5125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .49375 m
.5 .5 L
s
gsave
.5 .5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.64335 .49375 m
.64335 .5 L
s
gsave
.64335 .5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.83284 .49375 m
.83284 .5 L
s
gsave
.83284 .5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 .49375 m
.97619 .5 L
s
gsave
.97619 .5125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.25101 .49625 m
.25101 .5 L
s
.3105 .49625 m
.3105 .5 L
s
.39436 .49625 m
.39436 .5 L
s
.42624 .49625 m
.42624 .5 L
s
.45385 .49625 m
.45385 .5 L
s
.47821 .49625 m
.47821 .5 L
s
.7272 .49625 m
.7272 .5 L
s
.7867 .49625 m
.7867 .5 L
s
.87055 .49625 m
.87055 .5 L
s
.90243 .49625 m
.90243 .5 L
s
.93004 .49625 m
.93004 .5 L
s
.9544 .49625 m
.9544 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 .04053 m
1 .04053 L
s
gsave
1.0125 .04053 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .14481 m
1 .14481 L
s
gsave
1.0125 .14481 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .18972 m
1 .18972 L
s
gsave
1.0125 .18972 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .294 m
1 .294 L
s
gsave
1.0125 .294 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .33891 m
1 .33891 L
s
gsave
1.0125 .33891 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .44319 m
1 .44319 L
s
gsave
1.0125 .44319 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .4881 m
1 .4881 L
s
gsave
1.0125 .4881 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.99625 .08544 m
1 .08544 L
s
.99625 .11171 m
1 .11171 L
s
.99625 .13035 m
1 .13035 L
s
.99625 .15662 m
1 .15662 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .17526 m
1 .17526 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .23463 m
1 .23463 L
s
.99625 .2609 m
1 .2609 L
s
.99625 .27954 m
1 .27954 L
s
.99625 .30581 m
1 .30581 L
s
.99625 .3158 m
1 .3158 L
s
.99625 .32445 m
1 .32445 L
s
.99625 .33208 m
1 .33208 L
s
.99625 .38382 m
1 .38382 L
s
.99625 .41009 m
1 .41009 L
s
.99625 .42873 m
1 .42873 L
s
.99625 .455 m
1 .455 L
s
.99625 .46499 m
1 .46499 L
s
.99625 .47364 m
1 .47364 L
s
.99625 .48127 m
1 .48127 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.056 g
.001 w
.02381 .40299 m
.16716 .40197 L
.25101 .40073 L
.3105 .40103 L
.35665 .40183 L
.39436 .39924 L
.42624 .39995 L
.45385 .39549 L
.47821 .39417 L
.5 .39284 L
.51971 .39446 L
.53771 .39527 L
.55426 .3964 L
.56958 .39651 L
.58385 .39654 L
.5972 .39632 L
.60974 .3963 L
.62156 .39632 L
.63274 .39534 L
.64335 .3947 L
.65344 .39379 L
.66306 .39302 L
.67225 .39307 L
.68105 .39331 L
.6895 .39366 L
.69761 .39334 L
.70541 .39309 L
.71293 .39343 L
.72019 .39298 L
.7272 .39278 L
.73398 .39259 L
.74055 .39271 L
.74691 .39244 L
.75309 .39274 L
.75908 .39282 L
.76491 .39279 L
.77057 .39257 L
.77609 .39244 L
.78146 .39216 L
.7867 .39208 L
.7918 .39163 L
.79679 .39138 L
.80165 .39105 L
.80641 .39022 L
.81105 .39024 L
.8156 .39058 L
.82005 .39063 L
.8244 .39026 L
.82866 .39044 L
.83284 .39026 L
Mistroke
.83694 .39053 L
.84095 .39061 L
.84489 .39081 L
.84876 .39089 L
.85255 .39043 L
.85628 .39047 L
.85994 .39053 L
.86354 .39082 L
.86707 .39067 L
.87055 .39058 L
.87397 .3906 L
.87733 .39048 L
.88064 .39035 L
.8839 .39054 L
.8871 .39057 L
.89026 .39043 L
.89337 .39049 L
.89643 .39026 L
.89945 .39036 L
.90243 .3902 L
.90536 .39012 L
.90825 .39012 L
.91111 .39025 L
.91392 .39037 L
.9167 .39036 L
.91944 .39044 L
.92214 .39028 L
.92481 .39037 L
.92744 .39028 L
.93004 .39041 L
.93261 .39038 L
.93515 .39056 L
.93766 .39054 L
.94013 .39053 L
.94258 .39087 L
.945 .39105 L
.94739 .39127 L
.94975 .39124 L
.95209 .39135 L
.9544 .39152 L
.95669 .39147 L
.95895 .39154 L
.96118 .39169 L
.96339 .39156 L
.96558 .39142 L
.96775 .39134 L
.96989 .39142 L
.97201 .39164 L
.97411 .39149 L
.97619 .39151 L
Mistroke
Mfstroke
.111 g
.02381 .40587 m
.16716 .39724 L
.25101 .3963 L
.3105 .39946 L
.35665 .39754 L
.39436 .39679 L
.42624 .39792 L
.45385 .39404 L
.47821 .39201 L
.5 .39268 L
.51971 .39191 L
.53771 .3935 L
.55426 .39278 L
.56958 .39192 L
.58385 .392 L
.5972 .39051 L
.60974 .39011 L
.62156 .39042 L
.63274 .3898 L
.64335 .39044 L
.65344 .39041 L
.66306 .39062 L
.67225 .39125 L
.68105 .39152 L
.6895 .39152 L
.69761 .39127 L
.70541 .39117 L
.71293 .39196 L
.72019 .39245 L
.7272 .39174 L
.73398 .39228 L
.74055 .39242 L
.74691 .39218 L
.75309 .39219 L
.75908 .3915 L
.76491 .39198 L
.77057 .39187 L
.77609 .39216 L
.78146 .39162 L
.7867 .39146 L
.7918 .39184 L
.79679 .39186 L
.80165 .39186 L
.80641 .39191 L
.81105 .39152 L
.8156 .39134 L
.82005 .39124 L
.8244 .39126 L
.82866 .3913 L
.83284 .39135 L
Mistroke
.83694 .39115 L
.84095 .39125 L
.84489 .39116 L
.84876 .39121 L
.85255 .39095 L
.85628 .39111 L
.85994 .39115 L
.86354 .39112 L
.86707 .39101 L
.87055 .39093 L
.87397 .39099 L
.87733 .39123 L
.88064 .3912 L
.8839 .39056 L
.8871 .39033 L
.89026 .39042 L
.89337 .38979 L
.89643 .39001 L
.89945 .39028 L
.90243 .39062 L
.90536 .39089 L
.90825 .39095 L
.91111 .39078 L
.91392 .3906 L
.9167 .39059 L
.91944 .39074 L
.92214 .39092 L
.92481 .39046 L
.92744 .39019 L
.93004 .39017 L
.93261 .39006 L
.93515 .39004 L
.93766 .39004 L
.94013 .39017 L
.94258 .39019 L
.945 .39022 L
.94739 .39029 L
.94975 .39036 L
.95209 .39029 L
.9544 .39019 L
.95669 .39011 L
.95895 .39029 L
.96118 .39042 L
.96339 .39033 L
.96558 .39035 L
.96775 .39019 L
.96989 .39005 L
.97201 .3904 L
.97411 .39054 L
.97619 .39059 L
Mistroke
Mfstroke
.167 g
.02381 .39382 m
.16716 .40261 L
.25101 .40056 L
.3105 .39754 L
.35665 .39992 L
.39436 .40366 L
.42624 .4033 L
.45385 .4043 L
.47821 .4036 L
.5 .40362 L
.51971 .40365 L
.53771 .40402 L
.55426 .40319 L
.56958 .40289 L
.58385 .40242 L
.5972 .40248 L
.60974 .40231 L
.62156 .40174 L
.63274 .40207 L
.64335 .40163 L
.65344 .40133 L
.66306 .40145 L
.67225 .40168 L
.68105 .40205 L
.6895 .40246 L
.69761 .40237 L
.70541 .40221 L
.71293 .4014 L
.72019 .40135 L
.7272 .40181 L
.73398 .4018 L
.74055 .40172 L
.74691 .40156 L
.75309 .40151 L
.75908 .40125 L
.76491 .40171 L
.77057 .40149 L
.77609 .40137 L
.78146 .40143 L
.7867 .40191 L
.7918 .40196 L
.79679 .402 L
.80165 .40202 L
.80641 .40186 L
.81105 .40208 L
.8156 .40188 L
.82005 .40173 L
.8244 .40165 L
.82866 .40159 L
.83284 .40161 L
Mistroke
.83694 .40148 L
.84095 .40162 L
.84489 .4016 L
.84876 .40163 L
.85255 .40177 L
.85628 .40181 L
.85994 .40179 L
.86354 .40178 L
.86707 .40172 L
.87055 .40161 L
.87397 .4014 L
.87733 .40133 L
.88064 .40135 L
.8839 .40163 L
.8871 .40164 L
.89026 .40152 L
.89337 .40135 L
.89643 .40121 L
.89945 .40128 L
.90243 .4012 L
.90536 .4013 L
.90825 .40145 L
.91111 .40143 L
.91392 .40148 L
.9167 .40147 L
.91944 .40156 L
.92214 .40151 L
.92481 .40142 L
.92744 .40151 L
.93004 .40142 L
.93261 .40151 L
.93515 .40146 L
.93766 .40157 L
.94013 .40169 L
.94258 .40166 L
.945 .40175 L
.94739 .40184 L
.94975 .40182 L
.95209 .40181 L
.9544 .4018 L
.95669 .40188 L
.95895 .40193 L
.96118 .40193 L
.96339 .40194 L
.96558 .40193 L
.96775 .40191 L
.96989 .40193 L
.97201 .40198 L
.97411 .40181 L
.97619 .40176 L
Mistroke
Mfstroke
.222 g
.02381 .36956 m
.16716 .37352 L
.25101 .3793 L
.3105 .3787 L
.35665 .37845 L
.39436 .37785 L
.42624 .37529 L
.45385 .37421 L
.47821 .37471 L
.5 .37592 L
.51971 .37697 L
.53771 .37699 L
.55426 .37794 L
.56958 .37811 L
.58385 .37753 L
.5972 .37664 L
.60974 .3768 L
.62156 .37676 L
.63274 .37583 L
.64335 .37552 L
.65344 .37459 L
.66306 .37504 L
.67225 .37557 L
.68105 .37636 L
.6895 .37588 L
.69761 .37578 L
.70541 .37568 L
.71293 .37587 L
.72019 .37564 L
.7272 .37521 L
.73398 .37499 L
.74055 .3746 L
.74691 .37455 L
.75309 .37514 L
.75908 .37538 L
.76491 .37571 L
.77057 .37577 L
.77609 .37601 L
.78146 .37573 L
.7867 .37549 L
.7918 .37508 L
.79679 .37542 L
.80165 .37522 L
.80641 .3753 L
.81105 .37529 L
.8156 .37495 L
.82005 .37482 L
.8244 .37446 L
.82866 .37466 L
.83284 .37462 L
Mistroke
.83694 .37454 L
.84095 .37444 L
.84489 .3746 L
.84876 .3747 L
.85255 .37484 L
.85628 .37482 L
.85994 .37483 L
.86354 .3747 L
.86707 .37489 L
.87055 .37497 L
.87397 .37496 L
.87733 .37468 L
.88064 .37468 L
.8839 .37456 L
.8871 .37465 L
.89026 .37445 L
.89337 .37441 L
.89643 .3744 L
.89945 .37424 L
.90243 .37417 L
.90536 .37394 L
.90825 .374 L
.91111 .374 L
.91392 .37405 L
.9167 .37419 L
.91944 .37408 L
.92214 .37411 L
.92481 .37383 L
.92744 .37373 L
.93004 .37366 L
.93261 .37375 L
.93515 .37387 L
.93766 .37373 L
.94013 .37388 L
.94258 .37406 L
.945 .37395 L
.94739 .37392 L
.94975 .37391 L
.95209 .37388 L
.9544 .37388 L
.95669 .37383 L
.95895 .37377 L
.96118 .37375 L
.96339 .37401 L
.96558 .37411 L
.96775 .37411 L
.96989 .3741 L
.97201 .37418 L
.97411 .37406 L
.97619 .37436 L
Mistroke
Mfstroke
.278 g
.02381 .38002 m
.16716 .37718 L
.25101 .37019 L
.3105 .36252 L
.35665 .36336 L
.39436 .3618 L
.42624 .35594 L
.45385 .35507 L
.47821 .35705 L
.5 .35985 L
.51971 .35733 L
.53771 .35531 L
.55426 .35645 L
.56958 .35615 L
.58385 .3554 L
.5972 .35507 L
.60974 .35478 L
.62156 .35576 L
.63274 .35666 L
.64335 .35541 L
.65344 .35756 L
.66306 .35782 L
.67225 .3574 L
.68105 .3565 L
.6895 .35726 L
.69761 .35737 L
.70541 .35793 L
.71293 .3579 L
.72019 .35685 L
.7272 .35555 L
.73398 .35487 L
.74055 .35541 L
.74691 .35583 L
.75309 .35622 L
.75908 .35612 L
.76491 .35663 L
.77057 .35604 L
.77609 .35654 L
.78146 .35689 L
.7867 .35666 L
.7918 .35592 L
.79679 .35508 L
.80165 .35422 L
.80641 .35307 L
.81105 .35331 L
.8156 .35418 L
.82005 .35455 L
.8244 .35489 L
.82866 .35503 L
.83284 .35486 L
Mistroke
.83694 .35483 L
.84095 .35481 L
.84489 .35513 L
.84876 .35549 L
.85255 .35592 L
.85628 .35606 L
.85994 .3564 L
.86354 .35658 L
.86707 .35629 L
.87055 .35628 L
.87397 .35632 L
.87733 .35639 L
.88064 .35705 L
.8839 .35691 L
.8871 .3566 L
.89026 .35643 L
.89337 .35655 L
.89643 .35629 L
.89945 .35645 L
.90243 .35657 L
.90536 .35606 L
.90825 .3555 L
.91111 .35475 L
.91392 .35412 L
.9167 .35472 L
.91944 .35461 L
.92214 .35493 L
.92481 .35524 L
.92744 .35537 L
.93004 .35579 L
.93261 .35586 L
.93515 .35558 L
.93766 .35579 L
.94013 .35626 L
.94258 .35643 L
.945 .35662 L
.94739 .35683 L
.94975 .35671 L
.95209 .35667 L
.9544 .35706 L
.95669 .35731 L
.95895 .35717 L
.96118 .3575 L
.96339 .35763 L
.96558 .35758 L
.96775 .35743 L
.96989 .3575 L
.97201 .35756 L
.97411 .35767 L
.97619 .35774 L
Mistroke
Mfstroke
.333 g
.02381 .38001 m
.16716 .37862 L
.25101 .37867 L
.3105 .37594 L
.35665 .37255 L
.39436 .36969 L
.42624 .37124 L
.45385 .37198 L
.47821 .37259 L
.5 .37124 L
.51971 .36967 L
.53771 .36863 L
.55426 .36561 L
.56958 .36423 L
.58385 .36418 L
.5972 .36305 L
.60974 .36111 L
.62156 .35956 L
.63274 .35831 L
.64335 .35904 L
.65344 .35954 L
.66306 .35891 L
.67225 .35754 L
.68105 .35839 L
.6895 .35902 L
.69761 .35924 L
.70541 .35903 L
.71293 .35845 L
.72019 .35817 L
.7272 .35756 L
.73398 .35859 L
.74055 .35928 L
.74691 .35909 L
.75309 .35951 L
.75908 .35991 L
.76491 .3594 L
.77057 .35912 L
.77609 .35869 L
.78146 .35846 L
.7867 .3583 L
.7918 .35878 L
.79679 .35896 L
.80165 .35998 L
.80641 .36018 L
.81105 .36007 L
.8156 .3598 L
.82005 .35988 L
.8244 .36014 L
.82866 .36044 L
.83284 .36055 L
Mistroke
.83694 .36049 L
.84095 .36062 L
.84489 .36097 L
.84876 .36101 L
.85255 .36156 L
.85628 .36186 L
.85994 .36196 L
.86354 .36237 L
.86707 .36211 L
.87055 .36241 L
.87397 .36218 L
.87733 .36231 L
.88064 .3621 L
.8839 .36193 L
.8871 .36162 L
.89026 .36138 L
.89337 .36172 L
.89643 .36187 L
.89945 .3619 L
.90243 .36204 L
.90536 .36138 L
.90825 .36143 L
.91111 .36129 L
.91392 .36132 L
.9167 .36127 L
.91944 .36098 L
.92214 .36091 L
.92481 .36052 L
.92744 .36063 L
.93004 .36085 L
.93261 .36092 L
.93515 .36098 L
.93766 .36069 L
.94013 .36069 L
.94258 .36098 L
.945 .36106 L
.94739 .36106 L
.94975 .36124 L
.95209 .36095 L
.9544 .36073 L
.95669 .36086 L
.95895 .36106 L
.96118 .3609 L
.96339 .36104 L
.96558 .36097 L
.96775 .36105 L
.96989 .3614 L
.97201 .36152 L
.97411 .36152 L
.97619 .36157 L
Mistroke
Mfstroke
.389 g
.02381 .41852 m
.16716 .41462 L
.25101 .41309 L
.3105 .41475 L
.35665 .41333 L
.39436 .41288 L
.42624 .41401 L
.45385 .41582 L
.47821 .41429 L
.5 .4147 L
.51971 .415 L
.53771 .41651 L
.55426 .41734 L
.56958 .41735 L
.58385 .41748 L
.5972 .41723 L
.60974 .41686 L
.62156 .41626 L
.63274 .41559 L
.64335 .41617 L
.65344 .41583 L
.66306 .41564 L
.67225 .41592 L
.68105 .41592 L
.6895 .41588 L
.69761 .41605 L
.70541 .416 L
.71293 .41605 L
.72019 .41607 L
.7272 .41654 L
.73398 .41658 L
.74055 .41662 L
.74691 .41648 L
.75309 .4163 L
.75908 .41625 L
.76491 .41614 L
.77057 .41609 L
.77609 .41587 L
.78146 .41581 L
.7867 .41605 L
.7918 .41612 L
.79679 .41603 L
.80165 .41583 L
.80641 .41576 L
.81105 .41543 L
.8156 .41534 L
.82005 .41533 L
.8244 .41542 L
.82866 .41545 L
.83284 .4157 L
Mistroke
.83694 .41562 L
.84095 .41558 L
.84489 .4155 L
.84876 .4155 L
.85255 .41541 L
.85628 .41549 L
.85994 .41552 L
.86354 .41577 L
.86707 .41534 L
.87055 .41516 L
.87397 .41519 L
.87733 .41526 L
.88064 .41536 L
.8839 .4155 L
.8871 .4157 L
.89026 .41579 L
.89337 .41576 L
.89643 .4156 L
.89945 .41562 L
.90243 .41572 L
.90536 .41584 L
.90825 .41582 L
.91111 .41587 L
.91392 .4159 L
.9167 .41596 L
.91944 .416 L
.92214 .41611 L
.92481 .41606 L
.92744 .41614 L
.93004 .41613 L
.93261 .41615 L
.93515 .41616 L
.93766 .41604 L
.94013 .41612 L
.94258 .41591 L
.945 .41574 L
.94739 .41564 L
.94975 .41552 L
.95209 .41562 L
.9544 .41564 L
.95669 .41571 L
.95895 .41569 L
.96118 .41556 L
.96339 .41529 L
.96558 .41528 L
.96775 .4153 L
.96989 .41526 L
.97201 .41538 L
.97411 .41544 L
.97619 .41553 L
Mistroke
Mfstroke
.444 g
.02381 .40468 m
.16716 .39756 L
.25101 .39748 L
.3105 .39836 L
.35665 .40017 L
.39436 .39985 L
.42624 .3994 L
.45385 .39885 L
.47821 .39982 L
.5 .40077 L
.51971 .40051 L
.53771 .40108 L
.55426 .39987 L
.56958 .39963 L
.58385 .40036 L
.5972 .40039 L
.60974 .40083 L
.62156 .4008 L
.63274 .40027 L
.64335 .40034 L
.65344 .40044 L
.66306 .40094 L
.67225 .40092 L
.68105 .40102 L
.6895 .40162 L
.69761 .40173 L
.70541 .40136 L
.71293 .40129 L
.72019 .40123 L
.7272 .40127 L
.73398 .40138 L
.74055 .40149 L
.74691 .40158 L
.75309 .40138 L
.75908 .40149 L
.76491 .40173 L
.77057 .40187 L
.77609 .40152 L
.78146 .40195 L
.7867 .40167 L
.7918 .40166 L
.79679 .40209 L
.80165 .40217 L
.80641 .40214 L
.81105 .40189 L
.8156 .40214 L
.82005 .40245 L
.8244 .40244 L
.82866 .40208 L
.83284 .40181 L
Mistroke
.83694 .40173 L
.84095 .40183 L
.84489 .40158 L
.84876 .40149 L
.85255 .40141 L
.85628 .40135 L
.85994 .40126 L
.86354 .40121 L
.86707 .40118 L
.87055 .40097 L
.87397 .40052 L
.87733 .40048 L
.88064 .40068 L
.8839 .40073 L
.8871 .40092 L
.89026 .40086 L
.89337 .40072 L
.89643 .40058 L
.89945 .4006 L
.90243 .40034 L
.90536 .40029 L
.90825 .40012 L
.91111 .40008 L
.91392 .40007 L
.9167 .39999 L
.91944 .40025 L
.92214 .40028 L
.92481 .40032 L
.92744 .40044 L
.93004 .40023 L
.93261 .40035 L
.93515 .40041 L
.93766 .4006 L
.94013 .40051 L
.94258 .40055 L
.945 .40053 L
.94739 .40047 L
.94975 .40045 L
.95209 .40046 L
.9544 .40059 L
.95669 .40071 L
.95895 .40079 L
.96118 .40064 L
.96339 .40058 L
.96558 .40066 L
.96775 .40073 L
.96989 .40067 L
.97201 .40078 L
.97411 .40077 L
.97619 .40076 L
Mistroke
Mfstroke
.5 g
.02381 .36898 m
.16716 .38403 L
.25101 .38868 L
.3105 .39132 L
.35665 .39284 L
.39436 .39328 L
.42624 .39374 L
.45385 .39405 L
.47821 .39446 L
.5 .39484 L
.51971 .39493 L
.53771 .39518 L
.55426 .39527 L
.56958 .39533 L
.58385 .39546 L
.5972 .39562 L
.60974 .39569 L
.62156 .39574 L
.63274 .39588 L
.64335 .396 L
.65344 .39611 L
.66306 .39618 L
.67225 .39623 L
.68105 .39623 L
.6895 .39632 L
.69761 .39633 L
.70541 .39641 L
.71293 .39647 L
.72019 .39645 L
.7272 .39647 L
.73398 .39646 L
.74055 .39644 L
.74691 .39645 L
.75309 .39647 L
.75908 .39649 L
.76491 .39648 L
.77057 .3965 L
.77609 .39652 L
.78146 .39654 L
.7867 .39657 L
.7918 .39664 L
.79679 .39666 L
.80165 .3967 L
.80641 .39669 L
.81105 .39672 L
.8156 .39672 L
.82005 .39675 L
.8244 .39674 L
.82866 .39673 L
.83284 .39676 L
Mistroke
.83694 .39679 L
.84095 .39681 L
.84489 .39682 L
.84876 .39683 L
.85255 .39687 L
.85628 .39686 L
.85994 .39688 L
.86354 .39689 L
.86707 .39692 L
.87055 .39693 L
.87397 .39695 L
.87733 .39693 L
.88064 .39693 L
.8839 .39693 L
.8871 .39693 L
.89026 .39693 L
.89337 .39689 L
.89643 .39688 L
.89945 .39688 L
.90243 .39687 L
.90536 .39688 L
.90825 .39688 L
.91111 .39689 L
.91392 .39691 L
.9167 .39691 L
.91944 .39692 L
.92214 .39692 L
.92481 .39691 L
.92744 .3969 L
.93004 .39689 L
.93261 .39688 L
.93515 .39689 L
.93766 .3969 L
.94013 .3969 L
.94258 .39692 L
.945 .39694 L
.94739 .39693 L
.94975 .39692 L
.95209 .39689 L
.9544 .3969 L
.95669 .3969 L
.95895 .39689 L
.96118 .3969 L
.96339 .39688 L
.96558 .39688 L
.96775 .39687 L
.96989 .39689 L
.97201 .39689 L
.97411 .3969 L
.97619 .3969 L
Mistroke
Mfstroke
1 .429 0 r
[ .01 ] 0 setdash
.02381 .27956 m
.16716 .24425 L
.25101 .22456 L
.3105 .20914 L
.35665 .19568 L
.39436 .18728 L
.42624 .17902 L
.45385 .1706 L
.47821 .16499 L
.5 .15924 L
.51971 .154 L
.53771 .14944 L
.55426 .14405 L
.56958 .14152 L
.58385 .13786 L
.5972 .13269 L
.60974 .13118 L
.62156 .12792 L
.63274 .12517 L
.64335 .1233 L
.65344 .12016 L
.66306 .11883 L
.67225 .11697 L
.68105 .11497 L
.6895 .11333 L
.69761 .11221 L
.70541 .11021 L
.71293 .10909 L
.72019 .10812 L
.7272 .10548 L
.73398 .10545 L
.74055 .10386 L
.74691 .10227 L
.75309 .10175 L
.75908 .09915 L
.76491 .09953 L
.77057 .0984 L
.77609 .09682 L
.78146 .09682 L
.7867 .09491 L
.7918 .09549 L
.79679 .09476 L
.80165 .09349 L
.80641 .09367 L
.81105 .09223 L
.8156 .09245 L
.82005 .09176 L
.8244 .09076 L
.82866 .09072 L
.83284 .08954 L
Mistroke
.83694 .08957 L
.84095 .08868 L
.84489 .08828 L
.84876 .08793 L
.85255 .08678 L
.85628 .087 L
.85994 .08585 L
.86354 .08573 L
.86707 .08535 L
.87055 .08388 L
.87397 .08428 L
.87733 .08319 L
.88064 .08313 L
.8839 .08289 L
.8871 .08145 L
.89026 .08214 L
.89337 .08139 L
.89643 .08145 L
.89945 .08143 L
.90243 .0803 L
.90536 .08093 L
.90825 .08034 L
.91111 .0802 L
.91392 .08015 L
.9167 .07932 L
.91944 .07956 L
.92214 .07895 L
.92481 .07892 L
.92744 .0786 L
.93004 .07814 L
.93261 .07818 L
.93515 .07733 L
.93766 .07764 L
.94013 .07713 L
.94258 .07665 L
.945 .07669 L
.94739 .07558 L
.94975 .07607 L
.95209 .07561 L
.9544 .07503 L
.95669 .07524 L
.95895 .07426 L
.96118 .07491 L
.96339 .07466 L
.96558 .0742 L
.96775 .07458 L
.96989 .07384 L
.97201 .07428 L
.97411 .07407 L
.97619 .07364 L
Mistroke
Mfstroke
1 .857 0 r
.02381 .27954 m
.16716 .24432 L
.25101 .22456 L
.3105 .20907 L
.35665 .1957 L
.39436 .18731 L
.42624 .17899 L
.45385 .17062 L
.47821 .16503 L
.5 .15926 L
.51971 .154 L
.53771 .14938 L
.55426 .14407 L
.56958 .14147 L
.58385 .13769 L
.5972 .13261 L
.60974 .13104 L
.62156 .12772 L
.63274 .12486 L
.64335 .12292 L
.65344 .11967 L
.66306 .11829 L
.67225 .11638 L
.68105 .11417 L
.6895 .11262 L
.69761 .11138 L
.70541 .10925 L
.71293 .10826 L
.72019 .1071 L
.7272 .10447 L
.73398 .1045 L
.74055 .10279 L
.74691 .10126 L
.75309 .10063 L
.75908 .09798 L
.76491 .09846 L
.77057 .09724 L
.77609 .09564 L
.78146 .09565 L
.7867 .09369 L
.7918 .0943 L
.79679 .09351 L
.80165 .09222 L
.80641 .09246 L
.81105 .09099 L
.8156 .09119 L
.82005 .0905 L
.8244 .0895 L
.82866 .08947 L
.83284 .08831 L
Mistroke
.83694 .08831 L
.84095 .08744 L
.84489 .08707 L
.84876 .08669 L
.85255 .08557 L
.85628 .08577 L
.85994 .08462 L
.86354 .08457 L
.86707 .08412 L
.87055 .08268 L
.87397 .08311 L
.87733 .082 L
.88064 .08198 L
.8839 .08169 L
.8871 .08027 L
.89026 .08102 L
.89337 .08024 L
.89643 .08031 L
.89945 .08026 L
.90243 .07916 L
.90536 .07984 L
.90825 .07921 L
.91111 .07907 L
.91392 .07902 L
.9167 .07821 L
.91944 .07848 L
.92214 .07785 L
.92481 .07782 L
.92744 .0775 L
.93004 .07707 L
.93261 .07711 L
.93515 .07625 L
.93766 .07657 L
.94013 .07605 L
.94258 .07561 L
.945 .07564 L
.94739 .07452 L
.94975 .07503 L
.95209 .07457 L
.9544 .074 L
.95669 .07421 L
.95895 .07323 L
.96118 .0739 L
.96339 .07365 L
.96558 .07318 L
.96775 .07355 L
.96989 .07283 L
.97201 .07329 L
.97411 .07308 L
.97619 .07265 L
Mistroke
Mfstroke
.714 1 0 r
.02381 .27967 m
.16716 .24315 L
.25101 .22362 L
.3105 .2078 L
.35665 .19558 L
.39436 .18636 L
.42624 .17677 L
.45385 .1703 L
.47821 .16308 L
.5 .1573 L
.51971 .152 L
.53771 .14673 L
.55426 .14241 L
.56958 .13806 L
.58385 .13414 L
.5972 .13048 L
.60974 .12719 L
.62156 .12373 L
.63274 .12114 L
.64335 .11796 L
.65344 .11557 L
.66306 .11313 L
.67225 .11046 L
.68105 .10877 L
.6895 .10611 L
.69761 .10459 L
.70541 .10253 L
.71293 .10063 L
.72019 .09926 L
.7272 .09716 L
.73398 .09606 L
.74055 .09426 L
.74691 .09292 L
.75309 .09164 L
.75908 .09003 L
.76491 .08905 L
.77057 .08752 L
.77609 .08646 L
.78146 .08524 L
.7867 .084 L
.7918 .083 L
.79679 .08174 L
.80165 .08077 L
.80641 .07963 L
.81105 .07859 L
.8156 .07759 L
.82005 .07652 L
.8244 .07558 L
.82866 .07455 L
.83284 .07361 L
Mistroke
.83694 .07266 L
.84095 .0717 L
.84489 .07082 L
.84876 .06987 L
.85255 .06901 L
.85628 .06811 L
.85994 .06724 L
.86354 .06641 L
.86707 .06552 L
.87055 .06475 L
.87397 .06388 L
.87733 .0631 L
.88064 .06232 L
.8839 .06149 L
.8871 .0608 L
.89026 .05996 L
.89337 .05929 L
.89643 .05852 L
.89945 .05779 L
.90243 .05714 L
.90536 .05636 L
.90825 .05578 L
.91111 .05503 L
.91392 .05442 L
.9167 .05379 L
.91944 .05311 L
.92214 .05258 L
.92481 .05189 L
.92744 .05137 L
.93004 .05075 L
.93261 .05017 L
.93515 .04964 L
.93766 .04902 L
.94013 .04852 L
.94258 .04794 L
.945 .04742 L
.94739 .04689 L
.94975 .04634 L
.95209 .04585 L
.9544 .0453 L
.95669 .04481 L
.95895 .04428 L
.96118 .04378 L
.96339 .0433 L
.96558 .04277 L
.96775 .04232 L
.96989 .0418 L
.97201 .04134 L
.97411 .04087 L
.97619 .04038 L
Mistroke
Mfstroke
.286 1 0 r
.02381 .27916 m
.16716 .2424 L
.25101 .22314 L
.3105 .20716 L
.35665 .19492 L
.39436 .18569 L
.42624 .17591 L
.45385 .1695 L
.47821 .16211 L
.5 .15631 L
.51971 .1509 L
.53771 .14565 L
.55426 .14119 L
.56958 .13695 L
.58385 .13293 L
.5972 .12933 L
.60974 .12615 L
.62156 .12258 L
.63274 .12027 L
.64335 .11699 L
.65344 .11484 L
.66306 .11244 L
.67225 .10987 L
.68105 .10832 L
.6895 .10574 L
.69761 .10436 L
.70541 .10237 L
.71293 .10062 L
.72019 .09927 L
.7272 .09733 L
.73398 .0962 L
.74055 .09453 L
.74691 .09322 L
.75309 .09193 L
.75908 .09046 L
.76491 .08937 L
.77057 .08796 L
.77609 .08683 L
.78146 .08562 L
.7867 .08441 L
.7918 .08334 L
.79679 .08213 L
.80165 .0811 L
.80641 .07998 L
.81105 .07892 L
.8156 .07791 L
.82005 .07682 L
.8244 .0759 L
.82866 .07484 L
.83284 .07392 L
Mistroke
.83694 .07298 L
.84095 .07199 L
.84489 .07118 L
.84876 .07018 L
.85255 .06941 L
.85628 .06851 L
.85994 .06766 L
.86354 .06694 L
.86707 .066 L
.87055 .06538 L
.87397 .0645 L
.87733 .06381 L
.88064 .06311 L
.8839 .0623 L
.8871 .06176 L
.89026 .06092 L
.89337 .06037 L
.89643 .05967 L
.89945 .05901 L
.90243 .05848 L
.90536 .05773 L
.90825 .05727 L
.91111 .05656 L
.91392 .05603 L
.9167 .05548 L
.91944 .05483 L
.92214 .0544 L
.92481 .05372 L
.92744 .05329 L
.93004 .05271 L
.93261 .05218 L
.93515 .05174 L
.93766 .05113 L
.94013 .05075 L
.94258 .05016 L
.945 .04973 L
.94739 .04926 L
.94975 .04873 L
.95209 .04837 L
.9544 .0478 L
.95669 .04744 L
.95895 .04694 L
.96118 .0465 L
.96339 .04612 L
.96558 .04559 L
.96775 .04529 L
.96989 .04476 L
.97201 .04442 L
.97411 .044 L
.97619 .04355 L
Mistroke
Mfstroke
0 1 .143 r
.02381 .28374 m
.16716 .24754 L
.25101 .22711 L
.3105 .21106 L
.35665 .19875 L
.39436 .18873 L
.42624 .17974 L
.45385 .1732 L
.47821 .16637 L
.5 .15985 L
.51971 .15384 L
.53771 .1494 L
.55426 .14532 L
.56958 .14145 L
.58385 .13677 L
.5972 .13327 L
.60974 .13009 L
.62156 .12655 L
.63274 .12479 L
.64335 .12164 L
.65344 .11959 L
.66306 .11639 L
.67225 .11362 L
.68105 .11304 L
.6895 .11116 L
.69761 .10945 L
.70541 .10669 L
.71293 .10541 L
.72019 .10431 L
.7272 .10296 L
.73398 .10132 L
.74055 .09965 L
.74691 .09886 L
.75309 .09737 L
.75908 .09579 L
.76491 .09444 L
.77057 .09378 L
.77609 .09237 L
.78146 .09114 L
.7867 .08973 L
.7918 .08848 L
.79679 .08816 L
.80165 .08622 L
.80641 .08534 L
.81105 .0845 L
.8156 .08333 L
.82005 .0826 L
.8244 .08091 L
.82866 .08029 L
.83284 .07946 L
Mistroke
.83694 .0787 L
.84095 .07746 L
.84489 .07632 L
.84876 .07602 L
.85255 .07463 L
.85628 .07421 L
.85994 .07314 L
.86354 .07224 L
.86707 .07198 L
.87055 .07044 L
.87397 .06993 L
.87733 .06929 L
.88064 .06866 L
.8839 .06792 L
.8871 .06687 L
.89026 .06632 L
.89337 .06554 L
.89643 .06527 L
.89945 .06418 L
.90243 .06351 L
.90536 .06326 L
.90825 .06208 L
.91111 .06185 L
.91392 .06102 L
.9167 .06043 L
.91944 .06017 L
.92214 .05916 L
.92481 .05864 L
.92744 .05808 L
.93004 .05774 L
.93261 .057 L
.93515 .05645 L
.93766 .05602 L
.94013 .0552 L
.94258 .05513 L
.945 .0542 L
.94739 .05375 L
.94975 .05363 L
.95209 .05269 L
.9544 .05245 L
.95669 .0518 L
.95895 .0514 L
.96118 .05106 L
.96339 .05054 L
.96558 .05007 L
.96775 .04945 L
.96989 .04942 L
.97201 .0486 L
.97411 .04841 L
.97619 .04814 L
Mistroke
Mfstroke
0 1 .571 r
.02381 .23882 m
.16716 .21404 L
.25101 .19778 L
.3105 .18274 L
.35665 .17373 L
.39436 .16376 L
.42624 .15675 L
.45385 .15153 L
.47821 .1439 L
.5 .13982 L
.51971 .13485 L
.53771 .13018 L
.55426 .12734 L
.56958 .12208 L
.58385 .11935 L
.5972 .11653 L
.60974 .11253 L
.62156 .11071 L
.63274 .10693 L
.64335 .10463 L
.65344 .10285 L
.66306 .09933 L
.67225 .09793 L
.68105 .0953 L
.6895 .09304 L
.69761 .09179 L
.70541 .0888 L
.71293 .0875 L
.72019 .08571 L
.7272 .08342 L
.73398 .08245 L
.74055 .08003 L
.74691 .07868 L
.75309 .07741 L
.75908 .07523 L
.76491 .07434 L
.77057 .07248 L
.77609 .07103 L
.78146 .07005 L
.7867 .06809 L
.7918 .06716 L
.79679 .06576 L
.80165 .06425 L
.80641 .06343 L
.81105 .06175 L
.8156 .06075 L
.82005 .05966 L
.8244 .0582 L
.82866 .05741 L
.83284 .05604 L
Mistroke
.83694 .05498 L
.84095 .05407 L
.84489 .05274 L
.84876 .05191 L
.85255 .05081 L
.85628 .04973 L
.85994 .04891 L
.86354 .04775 L
.86707 .0469 L
.87055 .04596 L
.87397 .04494 L
.87733 .04415 L
.88064 .04316 L
.8839 .0423 L
.8871 .04146 L
.89026 .04055 L
.89337 .03974 L
.89643 .0389 L
.89945 .03808 L
.90243 .03728 L
.90536 .03649 L
.90825 .03569 L
.91111 .03492 L
.91392 .03419 L
.9167 .03339 L
.91944 .03272 L
.92214 .03196 L
.92481 .03122 L
.92744 .03061 L
.93004 .02979 L
.93261 .0292 L
.93515 .02853 L
.93766 .02777 L
.94013 .02728 L
.94258 .02649 L
.945 .02591 L
.94739 .02538 L
.94975 .02457 L
.95209 .02418 L
.9544 .02346 L
.95669 .02285 L
.95895 .02247 L
.96118 .02163 L
.96339 .02128 L
.96558 .0207 L
.96775 .02 L
.96989 .01978 L
.97201 .01894 L
.97411 .01858 L
.97619 .01819 L
Mistroke
Mfstroke
0 1 1 r
.02381 .28203 m
.16716 .24831 L
.25101 .22656 L
.3105 .21188 L
.35665 .20033 L
.39436 .19005 L
.42624 .18253 L
.45385 .17501 L
.47821 .16875 L
.5 .16346 L
.51971 .1579 L
.53771 .15364 L
.55426 .14923 L
.56958 .14513 L
.58385 .14174 L
.5972 .138 L
.60974 .13494 L
.62156 .13192 L
.63274 .12889 L
.64335 .12636 L
.65344 .12365 L
.66306 .12122 L
.67225 .11893 L
.68105 .11661 L
.6895 .11452 L
.69761 .11244 L
.70541 .11046 L
.71293 .10855 L
.72019 .10675 L
.7272 .10495 L
.73398 .10325 L
.74055 .10165 L
.74691 .09995 L
.75309 .09851 L
.75908 .09696 L
.76491 .09546 L
.77057 .09421 L
.77609 .09265 L
.78146 .09147 L
.7867 .09018 L
.7918 .08876 L
.79679 .0878 L
.80165 .08638 L
.80641 .08531 L
.81105 .08431 L
.8156 .08291 L
.82005 .08217 L
.8244 .08093 L
.82866 .07985 L
.83284 .07914 L
Mistroke
.83694 .07777 L
.84095 .07713 L
.84489 .07615 L
.84876 .075 L
.85255 .07453 L
.85628 .07325 L
.85994 .07261 L
.86354 .07189 L
.86707 .07065 L
.87055 .07036 L
.87397 .06924 L
.87733 .06849 L
.88064 .06808 L
.8839 .0668 L
.8871 .06656 L
.89026 .0657 L
.89337 .06478 L
.89643 .06461 L
.89945 .06337 L
.90243 .0631 L
.90536 .06252 L
.90825 .06141 L
.91111 .06144 L
.91392 .06037 L
.9167 .05989 L
.91944 .05962 L
.92214 .05843 L
.92481 .0585 L
.92744 .05765 L
.93004 .05696 L
.93261 .05698 L
.93515 .05577 L
.93766 .05578 L
.94013 .05528 L
.94258 .05434 L
.945 .05454 L
.94739 .05347 L
.94975 .05328 L
.95209 .05305 L
.9544 .0519 L
.95669 .05223 L
.95895 .0514 L
.96118 .05087 L
.96339 .05099 L
.96558 .04988 L
.96775 .05006 L
.96989 .04952 L
.97201 .0488 L
.97411 .04908 L
.97619 .04797 L
Mistroke
Mfstroke
0 .571 1 r
.02381 .23385 m
.16716 .21103 L
.25101 .19555 L
.3105 .18011 L
.35665 .1716 L
.39436 .16129 L
.42624 .1545 L
.45385 .14967 L
.47821 .14147 L
.5 .13771 L
.51971 .13267 L
.53771 .12794 L
.55426 .1254 L
.56958 .11959 L
.58385 .1171 L
.5972 .11441 L
.60974 .1101 L
.62156 .10855 L
.63274 .10436 L
.64335 .10216 L
.65344 .10059 L
.66306 .09661 L
.67225 .09545 L
.68105 .09262 L
.6895 .09028 L
.69761 .08925 L
.70541 .08578 L
.71293 .08465 L
.72019 .08283 L
.7272 .0803 L
.73398 .07954 L
.74055 .07673 L
.74691 .07544 L
.75309 .07423 L
.75908 .0717 L
.76491 .07098 L
.77057 .06887 L
.77609 .06735 L
.78146 .06647 L
.7867 .06416 L
.7918 .06333 L
.79679 .06181 L
.80165 .06012 L
.80641 .05939 L
.81105 .05742 L
.8156 .05643 L
.82005 .05529 L
.8244 .05361 L
.82866 .05287 L
.83284 .05131 L
Mistroke
.83694 .05017 L
.84095 .04924 L
.84489 .04771 L
.84876 .04688 L
.85255 .04565 L
.85628 .04446 L
.85994 .04362 L
.86354 .0423 L
.86707 .0414 L
.87055 .04037 L
.87397 .03925 L
.87733 .03839 L
.88064 .03732 L
.8839 .03638 L
.8871 .03545 L
.89026 .03449 L
.89337 .03357 L
.89643 .03268 L
.89945 .0318 L
.90243 .03088 L
.90536 .03012 L
.90825 .02918 L
.91111 .02837 L
.91392 .02766 L
.9167 .02667 L
.91944 .02609 L
.92214 .02522 L
.92481 .02439 L
.92744 .02391 L
.93004 .02286 L
.93261 .02237 L
.93515 .02169 L
.93766 .02076 L
.94013 .0205 L
.94258 .01947 L
.945 .01897 L
.94739 .01857 L
.94975 .01749 L
.95209 .01739 L
.9544 .01652 L
.95669 .0159 L
.95895 .01581 L
.96118 .01463 L
.96339 .01458 L
.96558 .01401 L
.96775 .01318 L
.96989 .01336 L
.97201 .0122 L
.97411 .01207 L
.97619 .0119 L
Mistroke
Mfstroke
0 .143 1 r
.02381 .28655 m
.16716 .2508 L
.25101 .2293 L
.3105 .21377 L
.35665 .20158 L
.39436 .19154 L
.42624 .18297 L
.45385 .17552 L
.47821 .16889 L
.5 .16297 L
.51971 .15758 L
.53771 .15267 L
.55426 .14813 L
.56958 .14395 L
.58385 .14006 L
.5972 .13642 L
.60974 .133 L
.62156 .12978 L
.63274 .12673 L
.64335 .12382 L
.65344 .12105 L
.66306 .11838 L
.67225 .11583 L
.68105 .11336 L
.6895 .11098 L
.69761 .10867 L
.70541 .10643 L
.71293 .10425 L
.72019 .10214 L
.7272 .10007 L
.73398 .09807 L
.74055 .09613 L
.74691 .09424 L
.75309 .09241 L
.75908 .09065 L
.76491 .08896 L
.77057 .08733 L
.77609 .08579 L
.78146 .08433 L
.7867 .08296 L
.7918 .08168 L
.79679 .08049 L
.80165 .07939 L
.80641 .07837 L
.81105 .07744 L
.8156 .07658 L
.82005 .07578 L
.8244 .07503 L
.82866 .07432 L
.83284 .07363 L
Mistroke
.83694 .07294 L
.84095 .07224 L
.84489 .0715 L
.84876 .07073 L
.85255 .0699 L
.85628 .06904 L
.85994 .06816 L
.86354 .06731 L
.86707 .06651 L
.87055 .06582 L
.87397 .06524 L
.87733 .06475 L
.88064 .06433 L
.8839 .06395 L
.8871 .06358 L
.89026 .06321 L
.89337 .06283 L
.89643 .06243 L
.89945 .06202 L
.90243 .0616 L
.90536 .06116 L
.90825 .06071 L
.91111 .06025 L
.91392 .05979 L
.9167 .05932 L
.91944 .05885 L
.92214 .05838 L
.92481 .05791 L
.92744 .05744 L
.93004 .05697 L
.93261 .05649 L
.93515 .05602 L
.93766 .05555 L
.94013 .05508 L
.94258 .05461 L
.945 .05415 L
.94739 .05368 L
.94975 .05322 L
.95209 .05276 L
.9544 .05229 L
.95669 .05183 L
.95895 .05138 L
.96118 .05092 L
.96339 .05047 L
.96558 .05001 L
.96775 .04956 L
.96989 .04911 L
.97201 .04867 L
.97411 .04822 L
.97619 .04778 L
Mistroke
Mfstroke
.286 0 1 r
.02381 .28653 m
.16716 .25078 L
.25101 .22928 L
.3105 .21376 L
.35665 .20157 L
.39436 .19153 L
.42624 .18295 L
.45385 .1755 L
.47821 .16888 L
.5 .16295 L
.51971 .15756 L
.53771 .15265 L
.55426 .14812 L
.56958 .14394 L
.58385 .14004 L
.5972 .1364 L
.60974 .13299 L
.62156 .12976 L
.63274 .12671 L
.64335 .12381 L
.65344 .12104 L
.66306 .11837 L
.67225 .11582 L
.68105 .11335 L
.6895 .11097 L
.69761 .10866 L
.70541 .10642 L
.71293 .10424 L
.72019 .10212 L
.7272 .10006 L
.73398 .09805 L
.74055 .0961 L
.74691 .09421 L
.75309 .09238 L
.75908 .09061 L
.76491 .08892 L
.77057 .0873 L
.77609 .08576 L
.78146 .0843 L
.7867 .08294 L
.7918 .08167 L
.79679 .08051 L
.80165 .07943 L
.80641 .07845 L
.81105 .07756 L
.8156 .07673 L
.82005 .07598 L
.8244 .07526 L
.82866 .07458 L
.83284 .07392 L
Mistroke
.83694 .07325 L
.84095 .07255 L
.84489 .07182 L
.84876 .07103 L
.85255 .07019 L
.85628 .06932 L
.85994 .06845 L
.86354 .06761 L
.86707 .06685 L
.87055 .0662 L
.87397 .06565 L
.87733 .06518 L
.88064 .06476 L
.8839 .06437 L
.8871 .06399 L
.89026 .0636 L
.89337 .06321 L
.89643 .06279 L
.89945 .06237 L
.90243 .06193 L
.90536 .06148 L
.90825 .06101 L
.91111 .06055 L
.91392 .06007 L
.9167 .0596 L
.91944 .05912 L
.92214 .05864 L
.92481 .05816 L
.92744 .05768 L
.93004 .0572 L
.93261 .05672 L
.93515 .05625 L
.93766 .05577 L
.94013 .0553 L
.94258 .05482 L
.945 .05435 L
.94739 .05388 L
.94975 .05341 L
.95209 .05295 L
.9544 .05248 L
.95669 .05202 L
.95895 .05156 L
.96118 .0511 L
.96339 .05064 L
.96558 .05019 L
.96775 .04973 L
.96989 .04928 L
.97201 .04883 L
.97411 .04839 L
.97619 .04794 L
Mistroke
Mfstroke
.714 0 1 r
.02381 .28533 m
.16716 .24987 L
.25101 .22879 L
.3105 .2137 L
.35665 .20158 L
.39436 .19188 L
.42624 .18367 L
.45385 .17633 L
.47821 .16996 L
.5 .16433 L
.51971 .15906 L
.53771 .15433 L
.55426 .15004 L
.56958 .14595 L
.58385 .14219 L
.5972 .13871 L
.60974 .13538 L
.62156 .13226 L
.63274 .12934 L
.64335 .12653 L
.65344 .12388 L
.66306 .12137 L
.67225 .11897 L
.68105 .11667 L
.6895 .11447 L
.69761 .11235 L
.70541 .11032 L
.71293 .10837 L
.72019 .10649 L
.7272 .10467 L
.73398 .10292 L
.74055 .10123 L
.74691 .09959 L
.75309 .09801 L
.75908 .09647 L
.76491 .09498 L
.77057 .09354 L
.77609 .09212 L
.78146 .09075 L
.7867 .08944 L
.7918 .08812 L
.79679 .08685 L
.80165 .08566 L
.80641 .08443 L
.81105 .08325 L
.8156 .08216 L
.82005 .08099 L
.8244 .07991 L
.82866 .07891 L
.83284 .0778 L
Mistroke
.83694 .07679 L
.84095 .07587 L
.84489 .07481 L
.84876 .07389 L
.85255 .07303 L
.85628 .07201 L
.85994 .07117 L
.86354 .07036 L
.86707 .06937 L
.87055 .06861 L
.87397 .06783 L
.87733 .06689 L
.88064 .06621 L
.8839 .06544 L
.8871 .06455 L
.89026 .06393 L
.89337 .06317 L
.89643 .06234 L
.89945 .06177 L
.90243 .061 L
.90536 .06025 L
.90825 .05971 L
.91111 .05895 L
.91392 .05827 L
.9167 .05775 L
.91944 .057 L
.92214 .05639 L
.92481 .05587 L
.92744 .05515 L
.93004 .0546 L
.93261 .05407 L
.93515 .05338 L
.93766 .05289 L
.94013 .05234 L
.94258 .0517 L
.945 .05125 L
.94739 .05068 L
.94975 .05009 L
.95209 .04967 L
.9544 .04909 L
.95669 .04856 L
.95895 .04814 L
.96118 .04757 L
.96339 .0471 L
.96558 .04667 L
.96775 .04611 L
.96989 .04569 L
.97201 .04524 L
.97411 .04471 L
.97619 .04432 L
Mistroke
Mfstroke
1 0 .857 r
.02381 .26857 m
.16716 .23565 L
.25101 .21535 L
.3105 .20066 L
.35665 .18906 L
.39436 .17948 L
.42624 .17131 L
.45385 .16417 L
.47821 .15785 L
.5 .15215 L
.51971 .14698 L
.53771 .14222 L
.55426 .13785 L
.56958 .13376 L
.58385 .12997 L
.5972 .12639 L
.60974 .12303 L
.62156 .11984 L
.63274 .11682 L
.64335 .11395 L
.65344 .11121 L
.66306 .1086 L
.67225 .10609 L
.68105 .10369 L
.6895 .10137 L
.69761 .09915 L
.70541 .097 L
.71293 .09494 L
.72019 .09293 L
.7272 .091 L
.73398 .08911 L
.74055 .08729 L
.74691 .08553 L
.75309 .08381 L
.75908 .08214 L
.76491 .08051 L
.77057 .07892 L
.77609 .07738 L
.78146 .07587 L
.7867 .0744 L
.7918 .07297 L
.79679 .07156 L
.80165 .07019 L
.80641 .06884 L
.81105 .06753 L
.8156 .06624 L
.82005 .06498 L
.8244 .06374 L
.82866 .06253 L
.83284 .06134 L
Mistroke
.83694 .06017 L
.84095 .05903 L
.84489 .0579 L
.84876 .0568 L
.85255 .05571 L
.85628 .05464 L
.85994 .05359 L
.86354 .05256 L
.86707 .05154 L
.87055 .05054 L
.87397 .04955 L
.87733 .04858 L
.88064 .04763 L
.8839 .04669 L
.8871 .04576 L
.89026 .04484 L
.89337 .04394 L
.89643 .04305 L
.89945 .04218 L
.90243 .04131 L
.90536 .04046 L
.90825 .03961 L
.91111 .03878 L
.91392 .03796 L
.9167 .03715 L
.91944 .03634 L
.92214 .03555 L
.92481 .03477 L
.92744 .034 L
.93004 .03323 L
.93261 .03248 L
.93515 .03173 L
.93766 .03099 L
.94013 .03027 L
.94258 .02954 L
.945 .02883 L
.94739 .02812 L
.94975 .02743 L
.95209 .02673 L
.9544 .02605 L
.95669 .02537 L
.95895 .0247 L
.96118 .02404 L
.96339 .02338 L
.96558 .02273 L
.96775 .02209 L
.96989 .02145 L
.97201 .02082 L
.97411 .0202 L
.97619 .01957 L
Mistroke
Mfstroke
1 0 .429 r
.02381 .26837 m
.16716 .23549 L
.25101 .21521 L
.3105 .20054 L
.35665 .18895 L
.39436 .17939 L
.42624 .17123 L
.45385 .1641 L
.47821 .15778 L
.5 .15208 L
.51971 .14693 L
.53771 .14218 L
.55426 .13781 L
.56958 .13373 L
.58385 .12994 L
.5972 .12637 L
.60974 .12301 L
.62156 .11983 L
.63274 .11682 L
.64335 .11396 L
.65344 .11123 L
.66306 .10862 L
.67225 .10611 L
.68105 .10372 L
.6895 .10141 L
.69761 .09919 L
.70541 .09705 L
.71293 .09499 L
.72019 .09299 L
.7272 .09106 L
.73398 .08918 L
.74055 .08737 L
.74691 .08561 L
.75309 .0839 L
.75908 .08223 L
.76491 .08061 L
.77057 .07903 L
.77609 .07749 L
.78146 .07599 L
.7867 .07452 L
.7918 .0731 L
.79679 .07169 L
.80165 .07033 L
.80641 .06899 L
.81105 .06768 L
.8156 .0664 L
.82005 .06514 L
.8244 .06391 L
.82866 .06271 L
.83284 .06152 L
Mistroke
.83694 .06036 L
.84095 .05922 L
.84489 .0581 L
.84876 .057 L
.85255 .05592 L
.85628 .05486 L
.85994 .05381 L
.86354 .05279 L
.86707 .05177 L
.87055 .05078 L
.87397 .0498 L
.87733 .04883 L
.88064 .04788 L
.8839 .04695 L
.8871 .04602 L
.89026 .04511 L
.89337 .04422 L
.89643 .04333 L
.89945 .04246 L
.90243 .0416 L
.90536 .04076 L
.90825 .03992 L
.91111 .03909 L
.91392 .03827 L
.9167 .03747 L
.91944 .03667 L
.92214 .03589 L
.92481 .03511 L
.92744 .03434 L
.93004 .03359 L
.93261 .03283 L
.93515 .0321 L
.93766 .03136 L
.94013 .03064 L
.94258 .02992 L
.945 .02922 L
.94739 .02851 L
.94975 .02782 L
.95209 .02714 L
.9544 .02646 L
.95669 .02579 L
.95895 .02512 L
.96118 .02446 L
.96339 .02381 L
.96558 .02317 L
.96775 .02253 L
.96989 .0219 L
.97201 .02127 L
.97411 .02065 L
.97619 .02004 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{910, 455},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>>0001ab000`400?l00000o`00003oo`3ooooo
0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0ooooo`3ooonA0?ooo`00
o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooold0oooo0`000003
0?ooo`800000o`3ooonk0?ooo`00o`3oooo>0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3ooonj0?ooo`00o`3oooo>0?ooo`050000003oool0oooo0?ooo`000000o`3ooonm0?oo
o`00o`3oooo>0?ooo`050000003oool0oooo0?ooo`000000o`3ooonm0?ooo`00o`3oooo>0?ooo`@0
0000o`3ooonn0?ooo`00o`3oooo>0?ooo`030000003oool000000?l0oooo_`3oool00?l0oooocP3o
ool010000000oooo0?ooo`00003o0?oookh0oooo003o0?ooolh0oooo00D000000?ooo`3oool0oooo
0000003o0?oookd0oooo003o0?ooold0oooo0`0000000`3oool000000000000200000?l0oooo^`3o
ool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0ooooo`3ooonA0?ooo`00o`3ooooo0?ooool0
ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0ooooo`3ooonA0?ooo`00C@3oool5
00000080oooo0P0000040?ooo`800000103oool2000005`0oooo100000030?ooo`800000103oool2
000000@0oooo0P0000220?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000F@3oool5
00000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001F0?ooo`@000000`3oool2
000000@0oooo0P0000040?ooo`800000103oool2000007`0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000D03oool500000080oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000003<0oooo001?0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000200?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000005X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00001j0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
D@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0f0?ooo`00C`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000P`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1H
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000O@3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo04l0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
=P3oool004l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1K0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0O`3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000005X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo05D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo07T0oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000540oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0=P3oool004l0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`1I0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000840oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000FP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0D`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000007/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001A0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo03H0oooo001>0?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000G@3oool2000000@0oooo0P0000040?ooo`800000103oool200000880oooo0`0000030?ooo`80
0000103oool2000000@0oooo0P00001J0?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000103oool2000005L0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000O03oool3000000<0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001A0?ooo`80
0000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000i0?ooo`00
o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0ooooo`3ooonA
0?ooo`00o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0oooo
o`3ooonA0?ooo`00o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?oo
ool0ooooo`3ooonA0?ooo`00o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo
003o0?ooool0ooooo`3ooonA0?ooo`00A@3ooooo00000?l00000o`00000J00000380oooo00150?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0<03oool004D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo1000T_lB0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0
oooo0?l0ooooo`3ooool0?ooo`<009;o5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`3o0?ooool0oooonP3oool2002BoaT0oooo00<000000?ooo`3oool0<03oool004D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00
A@3oool00`000000oooo0?ooo`3o0?ooool0ooool@3oool3002Bob40oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooon`0oooo1@00T_lA0?ooo`03003oTP3o
ool0oooo0100oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooon/0oooo00<009;o0?ooo`3oool03`3oool5003oTQ<0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?ooon<0oooo00<009;o0?ooo`3oool05P3oool01000
oi80oooo0?ooo`3o0=/E0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0?l0ooooo`3ooooR0?ooo`03002Bo`3oool0oooo01L0oooo00<0o`3K0?l0K@3o06d00P3o06dD0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooN0?ooo`@0
09;o3`3oool5003oTP80oooo0P3o0=/30?l0KAP0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooom`0oooo0P00T_l?0?ooo`@00?nB1`3oool20?l0KA/0oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooood`3oool2
002Boa40oooo00<00?nB0?ooo`3oool01P3oool20?l0KB@0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?oooll0oooo1000T_l?0?ooo`@00?nB1P3oool30?l0
KBH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooold0
oooo0P00T_l?0?ooo`@00?nB1`3oool30?l0KBT0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooa@3oool00`00T_l0oooo0?ooo`0>0?ooo`03003oTP3o
ool0oooo00L0oooo00<0o`3K0?l0K@3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo`03oool5002Bo`h0oooo0`00oi880?ooo`<0o`1]=03oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo_P3oool2002B
o`l0oooo1000oi860?ooo`<0o`3K0P3o06dg0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0?l0ooooo`3ooooJ0?ooo`80o`1]>@3oool00`000000oooo0?ooo`0`0?ooo`00
A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo0300oooo
000M0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3oool5000000`0oooo00<0
00000?ooo`3oool0o`3ooooo0?oook@0oooo0`00T_l>0?ooo`<00?nB1`3oool20?l0f`80o`1]@P3o
ool00`000000oooo0?ooo`0;0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3o
ool5000000T0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0o`3ooooo0?oook40oooo0`00T_l=0?ooo`@00?nB1`3oool50?l0KD@0oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`00703oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0<0?ooo`H00000o`3ooooo0?oooj/0oooo0`00T_l>0?ooo`800?nB2@3oool20?l0KC<0
oooo102fo`0=0?ooo`H00000303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`00703oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooook0?ooo`@0
]_l05P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0oooo000L
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooojH0
oooo0P00T_l>0?ooo`<00?nB2P3oool00`3o06d0oooo0?ooo`0l0?ooo`0304Wo003oool0oooo0100
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`007@3oool2
000000X0oooo0P0000040?ooo`800000103oool2000000h0oooo00<000000?ooo`3oool0o`3ooooo
0?oooj<0oooo0`00T_l<0?ooo`@00?nB203oool50?l0KC00oooo00<0]_l00?ooo`3oool01`3oool4
04Wo0080]P3o4P3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool2000000@0oooo0P000004
0?ooo`8000002`3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oooil0oooo1000T_l=0?oo
o`800?nB2@3oool30?l0KBl0oooo1P2fo`090?ooo`D0]P3o503oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooook03oool00`2fo`00oooo0?ooo`040?ooo`80
BOl01P3oool00`2f0?l0oooo0?ooo`0G0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0?l0ooooo`3ooonV0?ooo`@00?nB2P3oool00`3o0=/0oooo0?ooo`0f0?ooo`H0BOl0
00<0]P3o0?ooo`3oool02@3oool404T0oa80oooo00<000000?ooo`3oool0<03oool004D0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooi<0oooo1P00T_l:0?ooo`<00?nB2`3oool40?l0KB/0oooo1@2f
o`070?ooo`0304Wo002f0?l0]P3o00@0]P3o1`3oool2003oo`<0B@3o00<0oooo003oo`00ool04`3o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooT03oool3
002Bo`h0oooo0P00oi8;0?ooo`<0o`1]:`3oool40;Ko00@0oooo0P19o`050?ooo`80]P3o:03oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooSP3oool2002B
oa`0oooo0P3o06d`0?ooo`H0BOl02`3oool2003o90@0B@3o803oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooV@3oool00`00oi80oooo0?ooo`0g0?ooo`80
]_l0203oool00`19o`00oooo0?ooo`020?ooo`<0]P3o1P3oool00`00ob@002Co04T0o`0304T0ob@0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oooi@0oooo
1@00oi8:0?ooo`80o`1]:P3oool40;Ko0080oooo00<0BOl00?ooo`3oool0103oool60;H0o`T0oooo
00<00?oo0?ooo`3oool09`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?oo
o`3o0?ooool0ooooPP3oool6002Bo`T0oooo0`00oi8<0?ooo`<0o`1]:P3oool20;Ko0080oooo1019
o`0;0?ooo`8002Co10190?l_0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0
oooo0?l0ooooo`3ooon00?ooo`8009;o3P3oool00`00oi80oooo0?ooo`0:0?ooo`<0o`1];@3oool4
04Wo0080oooo0P2f0?l70?ooo`03003oo`190?l0B@3o00<0B@3o<`3oool00`000000oooo0?ooo`0`
0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool00`00T_l0oooo0?ooo`110?oo
o`80]_l00P19o`080?ooo`@0]P3o0P3oool00`009?l0oooo0?ooo`030?ooo`03003oo`00ob@00?lT
03L0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0
oooo0`00oi8:0?ooo`80o`3K00<0o`1]0?ooo`3oool09P3oool50;Ko0080BOl0203oool20;H0o`80
02Co1@190?lo0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooomg0?ooo`8009;o2P3oool3003oTPX0oooo00<0o`3K0?l0K@3o06d00P3o06dX0?ooo`030;Ko
0019o`00BOl000<0BOl02P3oool404T0o`800?oo0P00obA00?ooo`030000003oool0oooo0300oooo
00150?ooo`030000003oool0oooo0?l0ooooo`3ooomd0?ooo`<009;o2P3oool2003oTPX0oooo1@3o
06dT0?ooo`030;Ko003oool0oooo00L0oooo0`009?l30;H0o`0304T0o`3oool0oooo00<0oooo00<0
0?oo003o9000ob@00P00obA40?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0
oooo0?l0ooooo`3ooom`0?ooo`@009;o5P3oool30?l0KB@0oooo0`2fo`0304Wo00L0oooo1@2f0?l2
0?ooo`03003oo`3oool0oooo04d0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3ooooo0?ooogL0oooo0`00oi8?0?ooo`030?l0K@3oool0oooo0280oooo00<0]_l004Wo
0019o`000`009?l304T0o`H0oooo00<0]P3o0?ooo`3oool01@00ool00`00ob@0oooo0?ooo`1=0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`<0
09;o2P3oool3003oTSL0oooo1P190?l00`3oool0]P3o0?ooo`060?ooo`<00?oo0`00obAB0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooomS0?ooo`@009;o
2P3oool3003oTP/0oooo103o06dS0?ooo`80BOl02@3oool40;H0o`P0oooo00<00?lT0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooH@3o
ool2002BoaT0oooo0`3o06dR0?ooo`80]_l00`009?l00`190?l0oooo0?ooo`050?ooo`<0]P3o0`3o
ool2003ooel0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooofL0oooo1000oi8?0?ooo`80o`1]8`3oool204Wo00D0B@3o2@3oool5003oo`03003o903oool0
oooo05h0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oeH0oooo1000T_l:0?ooo`<00?nB>03oool204T0o`D0oooo00<0]P3o0?ooo`3oool0103oool00`00
ob@00?oo0?ooo`1U0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0
ooooo`3ooomD0?ooo`8009;o303oool2003oTPd0oooo00<0o`3K0?l0K@3oool07`3oool3000To`80
B@3o00<0BOl00?ooo`3oool0203oool30;H0o`03003oo`3oool0oooo05@0oooo00<0om/00?ooo`3o
ool00P3oool00`3of`00oooo0?ooo`0@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0?l0ooooo`3ooomB0?ooo`8009;o6`3oool00`3o0=/0o`1]0?l0K@0N0?ooo`0304Wo
00190?l0B@3o00<0B@3o203oool50;H0o`<00?oo00<00?lT0?ooo`3oool0B03oool50?oK00L0oooo
1@3of`000`3oK@00oooo0?ooo`0@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0ooooo`3ooomB0?ooo`03002Bo`3oool0oooo0080oooo1@00oi8?0?ooo`D0o`1]6@3o
ool604T0o`0304Wo003oool0oooo00`0oooo1@00oom:0?ooo`@0om/01@3oK@080?ooo`<0ofd0503o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool3
002Bo`X0oooo0P00oi8`0?ooo`80B@3o1019o`090?ooo`80]P3o1P3oool2003o9480oooo1@3of`07
0?ooo`<0ofd0903oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooAP3oool2002Bo`/0oooo0P00oi8=0?ooo`80o`1]6P3oool204T0oa00oooo1P2f0?l2003o
odH0oooo103of`050?m]02h0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0o`3ooooo0?oood@0oooo0P00T_l40?ooo`800?nB4P3oool20?l0f`80o`1]6@3oool304T0o`03
0?ooo`19o`00BOl00080BOl02P3oool30;H0o`<00?oo0`00ob@h0?ooo`T0om/01`3oool40?m]03<0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oood<0oooo
00<009;o0?ooo`3oool00P3oool2003oTQ40oooo0`3o0=/20?l0KAL0oooo10190?l0102fo`00BOl0
04Wo0019o`0:0?ooo`@0]P3o0`00ool3003o92h0oooo1`3of`070?ooo`P0ofd0?P3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool2002Bo`X0oooo
0P00oi8D0?ooo`80o`1]703oool204Wo00d0oooo00@00?lT003oo`00ool00?oo<P3oool20?oK00L0
ofd0C@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo
=P3oool4002Bo`X0oooo0P00oi8U0?ooo`D0B@3o0P2fo`000`19o`00oooo0?ooo`0<0?ooo`030;H0
o`3oool0oooo02`0oooo00@0om/00?ooo`3oool0oooo103of`070?ooo`80ofd0E03oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool3002Bo`H0oooo
00<00?nB0?ooo`3oool04@3oool50?l0KA<0oooo0`190?l00`3oool0]_l00;Ko00020;Ko0080BOl0
3@3oool20;H0o`<00?oo;03oool0103oK@00om/00?oK003of`050?m]05`0oooo00<000000?ooo`3o
ool0<03oool004D0oooo1000003o0?ooool0oooo>@3oool2003oTQ40oooo0`3o06dH0?ooo`0304T0
o`3oool0BOl000D0BOl02P3oool50;H0o`800?lT803oool20?oK00<0oooo0`3of`1Y0?ooo`@00000
<P3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooob/0oooo0P00T_l70?ooo`H00?nB4P3o
ool00`3o06d0oooo0?ooo`0[0?ooo`03003o9000ool0oooo02<0oooo00<0om/00?m]003oK@000`3o
f`030?m]06`0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooobP0oooo0`00T_lc0?ooo`<0B@3o0`19o`0=0?ooo`80]P3o00<00?oo0?ooo`3oool0803oool4
0?oK00T0oooo0`3oK@1_0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0?l0ooooo`3ooolV0?ooo`8009;o0`3oool3003oTQ@0oooo103o06dD0?ooo`04000To`190?l0B@3o
04T0oa40oooo0P2f0?l2003ooad0oooo1P3of`040?m]07/0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?ooob@0oooo0P00T_l20?ooo`<00?nB5@3oool20?l0
KAH0oooo00@002Co04T0o`190?l0BOl03P3oool50;H0o`03003oo`3oool0oooo01T0oooo1@3of`06
0?m]07l0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oa`0oooo0P00T_l80?ooo`800?nB5@3oool30?l0KA00oooo00@0]_l004Wo0019o`00BOl0:`3oool6
0?oK00L0oooo103oK@250?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0?l0ooooo`3ooolH0?ooo`@009;o2@3oool00`00oi80oooo0?ooo`0U0?ooo`80]_l000<0BOl004T0
o`190?l0403oool20;H0o`03003oo`3oool0oooo01D0oooo0`3of`060?m]0900oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oooaD0oooo0`00T_l40?ooo`80
0?nB5P3oool20?l0KAD0oooo00<0]_l004T0o`190?l00P190?l;0?ooo`<00?lT102f0?l00`00ool0
oooo0?ooo`070?ooo`T0om/01`3oool30?m]09H0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo1000oi8E0?ooo`<0o`1]5@3oool304T0o`l0oooo
0`2f0?l00`00ool0oooo0?ooo`030?ooo`80om/01`3oool90?m]09l0oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo1000T_l80?ooo`800?nB5P3o
ool30?l0KA00oooo1019o`0M0?ooo`80om/00P3oK@2_0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0?l0ooooo`3oool80?ooo`8009;o<P3oool504Wo00l0oooo00@00?lT
0;H0o`2f0?l0]P3o0P00ool70?ooo`D0om/00P3oK@2a0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`8009;o0P3oool5003oTQH0oooo0P3o06dJ
0?ooo`80B@3o203oool4003o9080]P3o0`00ool20?oK00L0oooo1@3oK@2c0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3oool80?ooo`800?nB603oool30?l0
K@`0oooo1019o`080?ooo`@0B@3o2`3oool30;H0o`03003oo`3oool0om/00080om/000<0oooo0?m]
003oK@00_P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooo`0
oooo0P00T_l70?ooo`800?nB5P3oool0103o0=/0o`1]0?l0K@3o06d=0?ooo`80BOl02@3oool304T0
o`@0oooo1000ob@90?ooo`<0om/0103oK@300?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0?l0oooon03oool4002Boc00oooo0P19o`0?0?ooo`<00?lT00D0oooo0;H0o`2f
0?l0]P3o003oo`080?ooo`<0ofd0a03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000
oooo0?ooo`3o0?ooooD0oooo0`00T_l50?ooo`800?nB5P3oool20?l0K@/0oooo0`19o`0;0?ooo`<0
B@3o203oool2003o9080om/00P2f0?l50?oK0<h0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3oooof0?ooo`L00?nB5P3oool20?l0K@T0oooo1019o`030;Ko00P0oooo
0`190?l4003o90L0oooo102f0?l50?m]0=00oooo00<000000?ooo`3oool0<03oool004D0oooo00<0
00000?ooo`3oool0o`3oooo]0?ooo`8009;o7`3oool50?l0K@T0oooo0P19o`040;Ko00P0oooo0`19
0?l2003o9>D0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3oooo[
0?ooo`8009;o@`3oool50;H0o`03003oo`3of`00oooo0=`0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooV0?ooo`D009;o00@0oooo003oTP00oi800?nB9@3oool2
04Wo01P0oooo0P2f0?l4003oon00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3ooooM0?ooo`8009;o2P3oool3003oTQT0oooo0`3o06d80?ooo`@0BOl03@3oool204T0
o`800?lT1`3oool20;H0o`800?ooi03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool400000?l0
oooofP3oool2002Bo`X0oooo0P00oi8H0?ooo`@0o`1]203oool304Wo00`0oooo0P00ob@304T0o`03
003o903oool0om/000<0om/0jP3oool400000380oooo00150?ooo`030000003oool0oooo0?l0oooo
f@3oool2002Bo`<0oooo0P00oi8O0?ooo`80o`1]4P3oool2003o90H0oooo0`190?l40?oK00<0]P3o
0P00ooo]0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooe`3o
ool2002Bo`030?ooo`00oi800?nB00800?nB9P3oool204Wo00X0oooo0`00ob@30?ooo`80om/01`3o
ool30;H0o`03003oo`3oool0oooo0>l0oooo00<000000?ooo`3oool0<03oool004D0oooo00<00000
0?ooo`3oool0o`3ooooH0?ooo`800?nB6`3oool30?l0K@T0oooo0`19o`090?ooo`<00?lT10190?l2
0?oK0080ofd01@3oool20;H0ooD0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3oooo:0?ooo`H009;o8P3oool30?l0K@T0oooo0`19o`0=0?ooo`80B@3o0`3of`020?m]
00800?ooo@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooolP0
oooo0P00T_l40?ooo`<00?nB7`3oool20?l0KA80oooo0P00ob@60?ooo`80B@3o00<0oooo0?m]003o
K@000P3oool00`00ool0]P3o0;H0o`3n0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0?l0oooo_`3oool2002Bo`T0oooo1000oi8W0?ooo`80BOl02@3oool4003o90@0om/0
1`3oool00`00ool0]P3o0;H0o`020;H0ool0oooo0@3oool00`000000oooo0?ooo`0`0?ooo`00A@3o
ool00`000000oooo0?ooo`3o0?oookd0oooo0P00T_l90?ooo`800?nB7@3oool20?l0K@P0oooo1019
o`000`2fo`00oooo0?ooo`050?ooo`<00?lT00<0om/004T0o`190?l00P190?l90?ooo`80]P3oo`3o
ool50?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo^P3oool3
002Bo`80oooo0P00oi8R0?ooo`@0o`1]1`3oool304Wo00<0]_l02P3oool304T0o`<002Co0P3oool2
003oool0oooo3@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oo
okP0oooo0P00T_l30?ooo`800?nB8@3oool00`3o0=/0o`1]0?l0K@030?ooo`80BOl03@3oool2003o
9080om/00`3oool204T0o`8002Co103oool00`00ool0]P3o0;H0o`3o0?ooo`h0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooonk0?ooo`800?nB9`3oool204Wo0080
]_l02@3oool4003o9080om/00P3oK@070?ooo`03003oo`2f0?l0]P3o0080]P3oo`3oool@0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo/03oool2002Bo`L0oooo
0P00oi8M0?ooo`80o`1]203oool204Wo0080]_l0203oool3003o90<0om/00P190?l80?ooo`<0]P3o
o`3ooolD0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo[03o
ool4002Bob@0oooo103o06d70?ooo`<0BOl03P3oool404T0o`<0oooo0P00oooo0?oooa`0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`<009;o0P3oool4
003oTQl0oooo0`3o06d;0?ooo`030;Ko003oool0oooo00<0oooo0P00ob@20?oK00040?m]003oool0
oooo0?ooo`<0B@3o103oool01000ool0]P3o0;H0o`2f0?oo0?oooad0oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`8009;o203oool4003oTRL0oooo0`19
o`0:0?ooo`<00?lT0P3of`000`3oK@00oooo0?ooo`060?ooo`03003oo`2f0?l0]P3o0080]P3oo`3o
oolP0?ooo`030000003oool0oooo0300oooo00150?ooo`@00000o`3ooonK0?ooo`@009;o:03oool0
0`3o0=/0o`1]0?l0K@070?ooo`<0BOl00`2fo`070?ooo`<00?lT00@0om/00?m]00190?l0B@3o2@3o
ool20;H0ool0oooo8@3oool400000380oooo00150?ooo`030000003oool0oooo0?l0ooooVP3oool2
002Bo`D0oooo0P00oi8Q0?ooo`030?l0f`3o06d0o`1]0080o`1]1`3oool204Wo00<0]_l00`3oool2
0?oK00P0oooo0P190?l40?ooo`800?ooo`3oool[0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo0?l0ooooW@3oool4003oTR40oooo0`3o06d;0?ooo`80]_l00P3oool0103o
f`000?lT003o9000ob@60?ooo`@0B@3o0P3oool2003oo`80]P3oo`3oool]0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooT@3oool2002Bo`L0oooo0`00oi8Z0?oo
o`80BOl0203oool0103of`000?lT003o9000ob@90?ooo`8002Co00<0oooo003oo`2f0?l00`2f0?oo
0?ooobl0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooon=0?oo
o`@009;o:03oool20?l0K@P0oooo1019o`020;Ko00L0oooo0P00ob@>0?ooo`80]P3oo`3ooolc0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooRP3oool3002Bo`D0
oooo0P00oi8R0?ooo`<0o`1]203oool204Wo00@0]_l03P3oool204T0o`030?ooo`00ool00?oo0?l0
oooo>`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooohh0oooo
1000oi8Q0?ooo`<0o`1]2`3oool20;Ko00@0oooo0P00ob@20?oK00H0oooo10190?l40;H0ool0oooo
?03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooh00oooo1000
T_l70?ooo`<00?nB:@3oool304Wo00/0oooo0P00ob@20?oK00H0oooo0P190?l0103oool0]P3o0;H0
o`2f0?oo0?oood00oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oomk0?ooo`D009;o0P3oool2003oTRH0oooo0P3o06d70?ooo`@0BOl00`2fo`080?ooo`<00?lT2`3o
ool20;H0ool0oooo@`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o
0?ooogh0oooo1000oi8T0?ooo`@0o`1]1`3oool204Wo00@0]_l02@3oool2003o90@0oooo0P190?l0
0`3oool00?oo003oo`3o0?ooodX0oooo00<000000?ooo`3oool0<03oool001d0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000040?ooo`8000003P3oool00`000000oooo0?ooo`3o0?oo
og80oooo0P00T_l70?ooo`<00?nB9@3oool30?l0K@/0oooo0P2fo`050?ooo`800?lT0P3of`060?oo
o`@0B@3o0P00ool20;H0ool0ooooB`3oool00`000000oooo0?ooo`0;0?ooo`800000103oool20000
00@0oooo0P0000040?ooo`800000103oool2000000/0oooo000L0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000d0oooo1P00003o0?ooofd0oooo0P00T_lg0?ooo`80BOl0203oool30?oK00800?lT
1`3oool304T0o`800?oo102f0?oo0?ooodP0oooo1P00000<0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000X0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0o`3ooom^0?ooo`8009;o0`3oool2003oTRH0oooo0P3o06d80?ooo`@0BOl00P2fo`060?ooo`D0
0?lT2`3oool30;H0ool0ooooD@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00P0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?ooo`8000003P3oool00`000000oooo0?ooo`3o0?ooof`0
oooo0P00T_l00`3oool00?nB003oTP02003oTR@0oooo103o06d70?ooo`<0BOl0102fo`020?ooo`03
0?oK003oK@00oooo00T0oooo0P190?l00`3oool00?oo003oo`3o0?oooeT0oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool2000000/0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooom/0?ooo`<00?nB9@3oool30?l0K@/0oooo0`2fo`040?ooo`03
003o903of`00oooo00L0oooo10190?l30;H0ool0ooooF`3oool00`000000oooo0?ooo`0:0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00X0oooo000M0?ooo`8000002P3oool2000000@0oooo0P000004
0?ooo`<000003@3oool00`000000oooo0?ooo`3o0?ooof<0oooo0P00T_m00?ooo`@00?lT1`3oool3
04T0o`04003oo`2f0?l0]P3o0;H0ool0ooooGP3oool00`000000oooo0?ooo`0;0?ooo`8000002P3o
ool2000000@0oooo0P0000040?ooo`<000002P3oool004D0oooo00<000000?ooo`3oool0o`3ooomO
0?ooo`@009;o:03oool20?l0K@/0oooo1019o`060?ooo`<00?lT00<0om/00?ooo`3oool02P3oool2
0;H0ool0ooooH@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oo
oe`0oooo0`00T_l20?ooo`D00?nB8P3oool30?l0K@X0oooo0`19o`030;Ko00/0oooo0`190?l00`3o
ool00?oo003oo`3o0?ooofT0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0o`3ooomC0?ooo`<009;o1`3oool4003oTR@0oooo0`3o06d;0?ooo`80BOl00`2fo`03003o9080
om/01P3oool304T0o`<00?oo0P2f0?oo0?ooofX0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`H009;o@03oool20;Ko00<00?lT0`3of`060?ooo`80B@3o
00<0oooo003oo`2f0?l00`2f0?oo0?ooof`0oooo00<000000?ooo`3oool0<03oool004D0oooo00<0
00000?ooo`3oool0o`3ooomC0?ooo`<00?nB9P3oool20?l0K@X0oooo1019o`070?ooo`800?lT0P3o
f`000`3oK@00oooo0?ooo`080?ooo`<0]P3oo`3ooom`0?ooo`030000003oool0oooo0300oooo0015
0?ooo`@00000o`3ooom30?ooo`8009;o1`3oool6003oTRL0oooo0P3o06d:0?ooo`80BOl0102fo`0<
0?ooo`80B@3o00<0oooo003oo`00ool0o`3ooome0?ooo`@00000<P3oool004D0oooo00<000000?oo
o`3oool0o`3ooom00?ooo`@009;o<@3oool00`3o0=/0o`1]0?l0K@020?l0K@X0oooo0P19o`020;Ko
00@0oooo0P3of`060?ooo`@0B@3o0`00ool00`2f0?l0oooo0?ooo`3o0?ooogL0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`<009;o0`3oool4003oTSd0
oooo0P2fo`020?ooo`@00?lT1P3oool204T0o`<00?oo102f0?oo0?ooogX0oooo00<000000?ooo`3o
ool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooold0?ooo`<009;o1`3oool5003oTRX0oooo
0P3o06d<0?ooo`80BOl0203oool3003o90/0oooo102f0?oo0?ooogh0oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0o`3oool`0?ooo`@009;o=@3oool40?l0K@X0oooo1019
o`020;Ko00H0oooo0P00ob@50?ooo`0404T0o`3oool00?oo003oool0ooooQ`3oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooobh0oooo0P00T_l40?ooo`<00?nB;`3o
ool30?l0K@/0oooo0`19o`040;Ko00040?ooo`3of`00om/00?oK00L0oooo10190?l00`00ool0]P3o
0;H0o`3o0?ooohP0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oola0?ooo`<00?nB@03oool30;Ko00040?ooo`3of`00om/00?oK00800?lT1@3oool404T0o`03003o
o`2f0?l0]P3o0080]P3oo`3ooon:0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0?l0oooo9@3oool2002Bo`P0oooo0P00oi8/0?ooo`030?l0f`3o06d0o`1]00`0oooo0P19
o`080?ooo`030?oK0000ob@00?lT00800?lT2@3oool30;H0ool0ooooSP3oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool400000?l0oooo8P3oool2002Boc@0oooo00<0o`3K0?l0K@3o06d00P3o06d<
0?ooo`80BOl00P2fo`000`3oK@00oooo0?ooo`030?ooo`<00?lT103oool3003oool0ooooU03oool4
00000380oooo00150?ooo`030000003oool0oooo0?l0oooo8@3oool2002Bo`<0oooo0P00oi8_0?oo
o`<0o`1]3@3oool304Wo0080]_l00`3of`080?ooo`@0B@3o0P2f0?oo0?oooiP0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`8009;o00<0oooo003oTP00
oi800P00oi8o0?ooo`80BOl000D0]_l00?oK003of`00om/00?ooo`02003o90L0oooo0P190?l40;H0
ool0ooooVP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oooal0
oooo0`00oi8/0?ooo`80o`1]3@3oool204Wo00/0oooo0P00ob@70?ooo`80B@3o0P2f0?oo0?oooih0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`@009;o
<P3oool40?l0K@/0oooo1019o`020;Ko00030?oK003oool0oooo00D0oooo0`00ob@30?ooo`800?oo
o`3ooonV0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo3`3o
ool5002Bo`<0oooo0P00oi8_0?ooo`80o`1]303oool304Wo00@0]_l000<0om/00?ooo`3oool01@3o
ool2003o9080oooo00<00?oo04T0o`190?l00P2f0?oo0?ooojL0oooo00<000000?ooo`3oool0<03o
ool004D0oooo1000003o0?ooo`H0oooo0P00T_l:0?ooo`@00?nB?`3oool30;Ko00<0om/00P00ob@8
0?ooo`80B@3o102f0?oo0?ooojH0oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo1000T_l90?ooo`<00?nB;03oool20?l0K@`0oooo0P19o`080?ooo`030?oK0000ob@00?lT
00800?lT203oool010190?l0]P3o0;H0o`2f0?oo0?ooojd0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3oool3002Bo`@0oooo0P00oi8b0?ooo`@0o`1]2P3oool404Wo
0080]_l01`3oool2003o90H0oooo0P00oooo0?oookD0oooo00<000000?ooo`3oool0<03oool004D0
oooo00<000000?ooo`3oool0m@3oool3002Bo`X0oooo1000oi8a0?ooo`<0o`1]303oool204Wo00@0
]_l000@0oooo0?oK003of`00om/02@3oool00`00ool0B@3o04T0o`020;H0ool0oooo]P3oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3a0?ooo`@009;o2P3oool3003oTT@0
oooo0P2fo`00103oool0om/00?oK003of`02003o90P0oooo0P190?l40;H0ool0oooo^03oool00`00
0000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3_0?ooo`8009;o1@3oool3003oTSH0
oooo0P3o06dF0?ooo`030?oK0000ob@00?lT00800?lT203oool010190?l0]P3o0;H0o`2f0?oo0?oo
ok`0oooo00<000000?ooo`3oool0<03oool004D0oooo1000003a0?ooo`@00?nB=@3oool40?l0K@h0
oooo0P19o`060?ooo`<00?lT1@3oool3003oool0oooo`@3oool400000380oooo00150?ooo`030000
003oool0oooo0>L0oooo0P00T_l70?ooo`800?nB=P3oool30?l0K@h0oooo1019o`00103oool0om/0
0?oK003oK@080?ooo`800?oo00<0B@3o0;H0o`2f0?l0o`3oooo60?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0><0oooo1000T_m@0?ooo`80BOl00P2fo`020?oK00800?lT
203oool00`190?l0]P3o0;H0o`020;H0ool0oooob03oool00`000000oooo0?ooo`0`0?ooo`00A@3o
ool00`000000oooo0?ooo`3P0?ooo`<009;o103oool2003oTSH0oooo0P3o06dE0?ooo`80]_l00P3o
f`000`3oK@000?lT003o90070?ooo`80B@3o0P2f0?oo0?oool`0oooo00<000000?ooo`3oool0<03o
ool002<0oooo0P0000040?ooo`800000103oool2000000<0oooo1@00000<0?ooo`030000003oool0
oooo0><0oooo1000oi8d0?ooo`@0o`1]3`3oool204Wo00P0oooo0`00ob@00`3oool00?oo003oo`02
003oool0ooooe03oool00`000000oooo0?ooo`0;0?ooo`800000103oool2000000@0oooo0P000003
0?ooo`D000003`3oool00280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0e`3oool2002Bo`L0oooo0`00
oi8f0?ooo`80o`1]3`3oool404Wo0080]_l000<0om/00?ooo`3oool00`3oool00`00ob@00?oo003o
o`03003oo`0304T0o`2f0?l0]P3o0?l0ooooe@3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`00
8P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0303oool600000=00oooo1000T_m@0?ooo`<0BOl00P2fo`030?oK00T0oooo00<0B@3o0;H0
o`2f0?l00P2f0?oo0?ooom80oooo1P00000<0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`008P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3A0?ooo`8009;o1@3oool2003oTSH0oooo0P3o06dF0?ooo`<0om/00P3oool2003o90800?oo
103oool010190?l0]P3o0;H0o`2f0?oo0?ooom/0oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03`3oool0
0280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0e03oool4003oTS@0oooo103o06d>0?ooo`040;Ko0019
o`00BOl00?oK00L0oooo0P00ob@4003oool0ooooi@3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?oo
o`008`3oool2000000X0oooo0P0000040?ooo`8000003P3oool00`000000oooo0?ooo`370?ooo`<0
09;o1`3oool3003oTSD0oooo0`3o06d>0?ooo`030;Ko0019o`00BOl00080BOl000<0om/00?ooo`3o
ool01@3oool01@00ob@00?oo003oo`00ool0oooo0080B@3o0P2f0?oo0?ooon@0oooo00<000000?oo
o`3oool02`3oool2000000X0oooo0P0000040?ooo`8000004@3oool004D0oooo00<000000?ooo`3o
ool0``3oool4002BocX0oooo0P3o06dE0?ooo`<0BOl000<0om/00?ooo`3oool02P3oool204T0o`@0
]P3oo`3ooooV0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0<40oooo
0P00T_l40?ooo`@00?nB<P3oool40?l0K@80o`3K6`3oool2003o90800?oo103oool010190?l0]P3o
0;H0o`2f0?oo0?ooonX0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0
^@3oool2002Bo`L0oooo1@00oi8c0?ooo`<0o`1]0P3o0=/@0?ooo`80BOl000<0om/00?m]003oool0
1P3oool4003o90800?ooo`3ooood0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0;D0oooo1000T_mB0?ooo`@0BOl000<0om/00?m]003oool01P3oool2003o90040?ooo`00
ool00?oo04T0o`80]P3oo`3ooood0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0;80oooo0`00T_l20?ooo`@00?nB=P3oool20?l0KAD0oooo00D0]_l004Wo0019o`00om/0
0?m]000<0?ooo`0304T0o`2f0?l0]P3o0080]P3oo`3oooof0?ooo`030000003oool0oooo0300oooo
00150?ooo`030000003oool0oooo0:L0oooo1000T_l70?ooo`D00?nB=P3oool40?l0KAh0oooo0P00
ob@50?ooo`80B@3o0P2f0?oo0?ooooX0oooo00<000000?ooo`3oool0<03oool004D0oooo00<00000
0?ooo`3oool0XP3oool5002Bod@0oooo0P3o06dC0?ooo`80BOl000<0om/00?ooo`3oool01P3oool3
003o90@00?ooo`3ooooo0?ooo`<0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0Z03oool4003oTU00oooo1019o`000`3of`00oooo0?ooo`050?ooo`800?lT1000ool00`19
0?l0]P3o0;H0o`3o0?ooool0oooo103oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000
oooo0?ooo`2H0?ooo`@009;o1`3oool5003oTSX0oooo0P3o06dE0?ooo`<0BOl000<0oooo0?oK003o
f`002`3oool00`190?l0]P3o0;H0o`020;H0ool0ooooo`3oool60?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo09<0oooo1@00T_m60?ooo`@0o`1]6@3oool20?oK00<0oooo
00<00?lT003oo`00ool0103oool204T0o`80]P3oo`3ooooo0?ooo`X0oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0V03oool4003oTSl0oooo0`3o06dC0?ooo`80BOl02@3o
ool00`00ob@00?oo003oo`02003oool0ooooo`3ooolD0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo08P0oooo1000T_l70?ooo`D00?nBE@3oool404Wo00<0om/01@3oool0
1`00ob@00?oo003oo`00ool0oooo000To`190?l00P2f0?oo0?ooool0oooo4`3oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`230?ooo`D009;oB`3oool20?l0KAD0oooo0`19
o`040?oK00T0oooo00<002Co04T0o`2f0?l00`2f0?oo0?ooool0oooo5@3oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool00`000000oooo0?ooo`290?ooo`@00?nB@P3oool40?l0KAP0oooo0P3of`00
103oK@00oooo0?ooo`00ob@3003oo`@0oooo00@0B@3o0;H0o`2f0?l0]P3oo`3ooooo0?oooaT0oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0N03oool4002Bo`P0oooo1@00
oi930?ooo`<0o`1]4P3oool204Wo00T0oooo00<00?lT003oo`00ool00P00oooo0?ooool0oooo903o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`1d0?ooo`@009;oI@3oool4
04Wo0080oooo0P3of`050?ooo`03003o9000ool00?oo0080oooo0P190?l20;H0ool0ooooo`3ooolR
0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo06T0oooo1000T_l<0?oo
o`@00?nBA@3oool30?l0KAH0oooo0P19o`020?ooo`@0om/0203oool204T0o`@0]P3oo`3ooooo0?oo
ob@0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0I03oool5002Bo`/0
oooo1@00oi950?ooo`040?l0f`3o06d0o`1]0?l0KAX0oooo0`3of`020?ooo`03003o9000ool00?oo
00D0oooo00@0B@3o0;H0o`2f0?l0]P3oo`3ooooo0?ooobP0oooo00<000000?ooo`3oool0<03oool0
00l0oooo00<0A4A40?ooo`3oool0<`3oool00`000000oooo0?ooo`2l0?ooo`030?l0f`3o06d0o`1]
01<0oooo0P19o`090?ooo`03003o9000ool00?oo00800?ooo`3ooooo0?oooc<0oooo00<000000?oo
o`3oool0<03oool000d0oooo00<0ZZZZ03<c<`000000=@3oool00`000000oooo0?ooo`1I0?ooo`@0
09;o303oool4003oTTL0oooo0P3o06dH0?ooo`@0BOl000@0oooo0?oK003of`00ofd0103oool2003o
90800?oo0P3oool00`190?l0]P3o0;H0o`3o0?ooool0oooo<P3oool00`000000oooo0?ooo`0`0?oo
o`002P3oool01P3MgMd0IVIV014A4@1VIVH0c<c<000003D0oooo00<000000?ooo`3oool0E03oool5
002Bo``0oooo1000oi970?ooo`@0o`1]0P3o0=/E0?ooo`<0BOl000<0oooo0?oK003of`000P3of`00
0`3oK@00oooo0?ooo`060?ooo`0304T0o`2f0?l0]P3o0080]P3oo`3ooooo0?oooc@0oooo00<00000
0?ooo`3oool0<03oool000P0oooo00@0ZZZZ03<c<`0R8R80VIVI0`3oool00`3<c<`0oooo0?ooo`0c
0?ooo`030000003oool0oooo04X0oooo1000T_l>0?ooo`800?nBC`3oool30?l0K@80o`3K6`3oool2
0?oK00040?m]003oool0oooo003o90800?oo103oool204T0o`80]P3oo`3ooooo0?ooocP0oooo00<0
00000?ooo`3oool0<03oool000L0oooo00<04A4A0000001gMgL0>`3oool00`000000oooo0?ooo`15
0?ooo`D009;o3P3oool4003oTVH0oooo0`19o`090?ooo`03003o9000ool00?oo00800?ooo`3ooooo
0?oood80oooo00<000000?ooo`3oool0<03oool000P0oooo00D0VIVI028R8P0R8R80R8R80>k^kP02
0?ooo`0308R8R03oool0oooo03<0oooo00<000000?ooo`3oool0?03oool2002BoaL0oooo0`00oi9<
0?ooo`030?l0f`3o06d0o`1]01L0oooo1019o`020;Ko0080om/01@3oool01000ob@00?oo003oo`00
ool20?ooo`0304T0o`2f0?l0]P3o0?l0ooooo`3ooom10?ooo`030000003oool0oooo0300oooo000:
0?ooo`060=gMg@1VIVH04A4A05EEE@2k^k/00000=@3oool00`000000oooo0?ooo`0h0?ooo`@009;o
3P3oool4003oTU80oooo00<0o`3K0?l0K@3o06d00P3o06dG0?ooo`80BOl00P2fo`020?oK00/0oooo
00<0B@3o0;H0o`2f0?l00P2f0?oo0?ooool0oooo@`3oool00`000000oooo0?ooo`0`0?ooo`003@3o
ool00`2ZZZX0<c<c0000000e0?ooo`030000003oool0oooo03D0oooo0`00T_l=0?ooo`D00?nBE03o
ool30?l0KA`0oooo0P3of`000`3oK@00oooo0?ooo`04003oo`@0oooo00@0B@3o0;H0o`2f0?l0]P3o
o`3ooooo0?ooodL0oooo00<000000?ooo`3oool0<03oool000l0oooo00<0A4A40?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0Z0?ooo`@009;oP`3oool404Wo0080ofd01`3oool01000ob@00?oo003o
o`00oooo0?ooool0ooooD`3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?oo
o`0V0?ooo`@009;o4@3oool4003oTUH0oooo0P3o06dF0?ooo`@0BOl00P2fo`040?oK00D0oooo00@0
0?lT003oo`00ool0oooo1@2f0?oo0?ooool0ooooD03oool00`000000oooo0?ooo`0`0?ooo`002`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool07@3o
ool2002BoaL0oooo1@00oi9F0?ooo`@0o`1]603oool20;Ko00@0om/02@3oool40;H0o`0304T0o`3o
ool0oooo0?l0ooooo`3ooomB0?ooo`030000003oool0oooo0300oooo000;0?ooo`L00000<`3oool0
0`000000oooo0?ooo`0I0?ooo`@009;o403oool2003oTUl0oooo0`3o06dC0?ooo`80BOl03@3oool0
0`00ob@00?oo003oo`050?ooo`80B@3oo`3ooooo0?oooeP0oooo00<000000?ooo`3oool0<03oool0
00l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0F0?ooo`<009;o403oool4003o
TW<0oooo1019o`020;Ko00030?oK003oK@00oooo00H0oooo00@00?lT003oo`00ool00?oo0P2f0?oo
0?ooool0ooooH03oool00`000000oooo0?ooo`0`0?ooo`003@3oool01@000000oooo0000003oool0
000003<0oooo1000000U0?ooo`<00?nBG03oool30?l0KAD0oooo0`19o`020;Ko00<0om/000<0ofd0
0?ooo`3oool01@3oool00`00ob@00?oo0;H0o`030;H0o`0304T0o`3oool0oooo0?l0ooooo`3ooomL
0?ooo`@00000<P3oool000d0oooo0P0000000`3oool000000000000c0?ooo`030000003oool0oooo
01/0oooo1000oi9P0?ooo`H0o`1]6P3oool20?oK00040?m]003oool0oooo0?ooo`800?oo1P3oool2
0;H0o`<0B@3oo`3ooooo0?ooof<0oooo00<000000?ooo`3oool0<03oool000d0oooo00D000000?oo
o`3oool0oooo0000000c0?ooo`030000003oool0oooo01L0oooo1000oi9T0?ooo`80o`3K4P3oool4
04Wo00X0oooo1000ool00`00ob@0oooo0?ooo`030?ooo`<0B@3oo`3ooooo0?ooofL0oooo00<00000
0?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0MP3oool20?l0KAH0oooo1@19o`020;Ko
00030?m]003of`00om/000H0oooo0`00ool3003o9080]P3oo`3ooooo0?ooofl0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0LP3oool40?l0KAP0oooo0`2fo`000`3oK@00
om/00?oK00020?oK00L0oooo0`00ob@40;H0o`0304T0o`3oool0oooo0?l0ooooo`3ooom^0?ooo`03
0000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0700oooo0P3o06dB0?ooo`<0BOl0
203oool30?oK0080oooo0P00ob@2003oo`D0oooo0`2f0?l304T0ool0ooooo`3ooomb0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0840oooo0`19o`030;Ko0080om/01`3o
ool2003o90@00?oo1P3oool304T0ool0ooooo`3ooomf0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo06D0oooo103o06dF0?ooo`80BOl00`2fo`030?oK00L0oooo00@00?lT
003oo`00ool00?oo0`3oool20;H0ool0ooooo`3ooomn0?ooo`030000003oool0oooo0300oooo0009
0?ooo`L00000=@3oool00`000000oooo0?ooo`1P0?ooo`D0o`1]0P3o0=/G0?ooo`80]_l00`3of`0>
0?ooo`@0]P3oo`3ooooo0?oooh00oooo00<000000?ooo`3oool0<03oool000L0oooo0P0000070?oo
o`800000<`3oool00`000000oooo0?ooo`1P0?ooo`<0o`3K4`3oool204Wo00`0oooo0P00ob@2003o
o`H0oooo0`2f0?l204T0ool0ooooo`3ooon20?ooo`030000003oool0oooo0300oooo00060?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1H0?ooo`80
o`1]603oool404Wo0080]_l000<0om/00?ooo`3oool01@3oool3003o90<00?oo1`3oool204T0ool0
ooooo`3ooon60?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo05@0oooo
103o06dG0?ooo`<0BOl0102fo`000`3of`00oooo0?ooo`050?ooo`800?lT0`00ool0103oool0]P3o
0;H0o`2f0?oo0?ooool0ooooSP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo
0?ooo`1A0?ooo`<0o`1]6`3oool30;Ko00030?oK003oool0oooo00`0oooo0`2f0?l204T0ool0oooo
o`3ooon?0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo06L0oooo0P19
o`0=0?ooo`03003o9000ool00?oo00H0oooo0P2f0?l304T0ool0ooooo`3ooonA0?ooo`030000003o
ool0oooo0300oooo000:0?ooo`8000000P3oool2000003D0oooo00<000000?ooo`3oool0B03oool2
0?l0KAT0oooo1019o`000`2fo`00om/00?oK00080?ooo`03003o9000ool00?oo00800?oo1P3oool3
04T0ool0ooooo`3ooonE0?ooo`030000003oool0oooo0300oooo00090?ooo`060000003oool0oooo
0000003oool00000=P3oool00`000000oooo0?ooo`140?ooo`@0o`1]603oool304Wo00030;Ko003o
f`00om/00080om/01`3oool01000ob@00?oo003oo`00ool30?ooo`80]P3oo`3ooooo0?oooid0oooo
00<000000?ooo`3oool0<03oool000T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0440oooo0`3o06dM0?ooo`<0om/03P3oool40;H0o`0304T0
o`3oool0oooo0?l0ooooo`3ooonL0?ooo`030000003oool0oooo0300oooo00090?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0i0?ooo`80o`1]
703oool204Wo00d0oooo0P00ob@2003oo`D0oooo0`2f0?l304T0ool0ooooo`3ooonP0?ooo`030000
003oool0oooo0300oooo00090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0e0?ooo`@0o`1]6P3oool404Wo00040?m]003of`00om/00?m]00L0
oooo0P00ob@4003oo`H0oooo0`190?oo0?ooool0ooooY03oool00`000000oooo0?ooo`0`0?ooo`00
2@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0<P3oool30?l0KA/0oooo00@0]_l004Wo0019o`00ofd0103of`080?ooo`04003o9000ool00?oo
003oo`<0oooo0P2f0?oo0?ooool0oooo[03oool00`000000oooo0?ooo`0`0?ooo`002@3oool20000
0080oooo0P00000f0?ooo`030000003oool0oooo0580oooo0P3of`040?ooo`800?oo2@3oool40;H0
ool0ooooo`3ooon^0?ooo`030000003oool0oooo0300oooo00150?ooo`@00000:03oool20?l0KAd0
oooo0P19o`000`3of`00oooo0?ooo`070?ooo`@00?oo00<00?lT0?ooo`3oool01@3oool30;H0o`80
B@3oo`3ooooo0?ooojd0oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`0U0?ooo`@0o`1]
6`3oool404Wo00030?oK003oool0oooo00L0oooo0P00ool3003o9080]P3o1P3oool204T0ool0oooo
o`3ooond0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo02<0oooo0P3o
06dL0?ooo`<0BOl000<0om/00?ooo`3oool02@3oool3003o90@0]P3o00<0B@3o0?ooo`3oool0o`3o
oooo0?oook/0oooo00<000000?ooo`3oool0<03oool000`0oooo1@00000d0?ooo`030000003oool0
oooo01X0oooo0P3o06d]0?ooo`800?oo1P3oool20;H0o`<0B@3o0P009?oo0?ooool0oooo_@3oool0
0`000000oooo0?ooo`0`0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool05P3oool40?l0K@80o`3K7@3oool204Wo00030?oK003oool0oooo
00L0oooo1000ool00`00ob@0oooo0?ooo`030?ooo`<0B@3o0P009?oo0?ooool0oooo`@3oool00`00
0000oooo0?ooo`0`0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool04`3oool30?l0K@80o`3K7@3oool404Wo00030?oK003oool0oooo00H0
oooo0`00ool3003o9080]P3oo`3ooooo0?oool/0oooo00<000000?ooo`3oool0<03oool000/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0380oooo
0`19o`000`3of`00oooo0?ooo`090?ooo`<00?lT102f0?l00`190?l0oooo0?ooo`3o0?ooool0oooo
bP3oool00`000000oooo0?ooo`0`0?ooo`00303oool5000003@0oooo00<000000?ooo`3oool0>@3o
ool2003oo`H0oooo0`2f0?l304T0ool0ooooo`3oooo>0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo02T0oooo0P19o`000`3of`00ofd00?ooo`070?ooo`@00?oo00<00?lT
0?ooo`3oool0103oool304T0ool0ooooo`3ooooB0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo02D0oooo1019o`000`3of`00ofd00?ooo`060?ooo`04003o9000ool00?oo
003o90<0oooo0P2f0?oo0?ooool0oooofP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`0S0?ooo`80BOl000<0om/00?m]003oool00P3oool2003oo`T0oooo102f0?oo0?oo
ool0oooog03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0V0?ooo`@0
0?oo00<00?lT0?ooo`3oool01@3oool30;H0o`80B@3oo`3ooooo0?ooomh0oooo00<000000?ooo`3o
ool0<03oool000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo01X0oooo0P19o`000`3of`00oooo0?ooo`040?ooo`<00?oo0`00ob@80?ooo`80B@3o
o`3ooooo0?ooon80oooo00<000000?ooo`3oool0<03oool000L0oooo0P0000070?ooo`800000<`3o
ool00`000000oooo0?ooo`0F0?ooo`@0BOl000<0om/00?ooo`3oool01@3oool3003o90@0oooo0P2f
0?oo0?ooool0oooojP3oool00`000000oooo0?ooo`0`0?ooo`002@3oool7000003D0oooo00<00000
0?ooo`3oool04`3oool304Wo00030?oK003oool0oooo0080oooo0P00ool80?ooo`@0]P3o00<0B@3o
0?ooo`3oool0o`3ooooo0?ooonT0oooo00<000000?ooo`3oool0<03oool004D0oooo1000000F0?oo
o`@00?oo00<00?lT0?ooo`3oool01@3oool20;H0o`<0B@3oo`3ooooo0?ooonX0oooo1000000b0?oo
o`00A@3oool00`000000oooo0?ooo`0D0?ooo`<00?oo0`00ob@70?ooo`<0B@3oo`3ooooo0?oooo40
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool04`3oool3003o9080oooo
102f0?oo0?ooool0oooon@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?oo
o`0C0?ooo`D0]P3o00<0oooo04T0o`190?l0o`3ooooo0?ooooX0oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool05@3oool404T0ool0ooooo`3ooool0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0180oooo0`190?oo0?ooool0ooooo`3oool10?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooaH0oooo00<000000?ooo`3oool0<03oool002<0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P00000>0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?oo
o`3oool02`3oool2000000@0oooo0P0000040?ooo`800000103oool200000140oooo000R0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000=0?ooo`H00000o`3ooooo0?ooool0oooo3P3oool6000000`0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000100oooo000R0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
3P3oool00280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`80
00003P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`8000004@3oool0
0280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0@0?ooo`008`3oool2000000X0oooo0P0000040?ooo`<000003@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo00/0oooo0P00000:0?ooo`800000
103oool300000100oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool400000?l0ooooo`3ooooo0?oooa80oooo1000
000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool400000?l0ooooo`3ooooo0?oooa80oooo1000000b0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0
<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool400000?l0ooooo`3ooooo0?oooa80oooo1000000b0?ooo`00A@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo0300
oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0
<03oool004D0oooo1000003o0?ooool0ooooo`3ooolB0?ooo`@00000<P3oool004D0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0<03oool002T0oooo
0P0000040?ooo`8000000`3oool5000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo0?ooo`0;0?ooo`800000103oool2000000<0oooo1@00000E0?ooo`00:03o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool05@3oool002P0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`0<0?ooo`H00000o`3ooooo0?ooool0oooo3P3oool6000000`0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`0E0?ooo`00:03oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`00
0000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool05@3oool0
02P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo01D0oooo000Y0?ooo`8000002P3oool2000000h0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool2
000001L0oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?oo
o`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooog/0oooo
1`17AdNC0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooFP3o
ool?04M7AfP0oooo5017AdMK0?ooo`D0AdM7;P3oool704M7A`L0oooo5`17AdLf0?ooo`X0AdM7?03o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooodd0oooo3@17AdL?
0?ooo`X0AdM7;P3oool=04M7A`d0oooo5P17AdLD0?ooo`T0AdM72@3oool704M7Acd0oooo1@17AdL5
0?oooa<0AdM71@3oool404M7A`h0oooo1017AdLU0?ooo``0AdM71P3oool804M7Aa00oooo0P17AdL5
0?ooo`D0AdM72P3oool>04M7Abh0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`D0AdM79P3oool:04M7AaT0oooo2`17AdL=0?ooo`d0AdM7<`3oool904M7
A`L0oooo2017AdL80?ooo`80AdM71@1EEEDC04M7A`d0oooo1P17AdL505EEEAP0oooo1@17AdL40?oo
o`h0AdM7=@3oool604M7A`P0oooo4017AdL20?ooo`D0AdM77@3oool@04M7A`<0oooo1P17AdLE0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo@`3oool504M7AcD0
oooo2017AdL90?ooo`P0AdM7F03oool805EEEA00oooo1P17AdL405EEE@D0oooo1`1EEED<0?ooo`L0
AdM7301EEED50?ooo`D0EEEE7@3oool@05EEEH@0oooo0`17AdL60?ooo`<0AdM74P3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooocd0oooo1P17AdM20?ooo`T0AdM7
E`3oool905EEE@P0oooo5P1EEED@0?oooa<0EEEE5P3ooolM05EEEA00oooo1`1EEED50?ooo`d0EEEE
R@3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooocP0oooo1@17
AdNQ0?ooo`L0EEEEU03oool505EEE@d0oooo501EEEDN0?ooo`80EEEE2P3oool205EEE@<0oooo;`1E
EEDG0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0>l0oooo5P17AdLQ
0?oooa40AdM7X@3oool505EEEL40oooo7P1EEED20?ooo`X0EEEE0P3oool305EEEBl0oooo1@1EEEDB
0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0>L0oooo2017AdLF0?oo
ob40AdM7ZP3oool805EEEOl0oooo?03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000
oooo0?ooo`3O0?ooo`P0AdM7d`3ooolF05EEEOl0ooooA03oool00`000000oooo0?ooo`0`0?ooo`00
A@3oool00`000000oooo0?ooo`3G0?ooo`P0AdM7d@3oool:05EEEOl0ooooFP3oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3?0?ooo`P0AdM7d`3oool605EEEOl0ooooI03o
ool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0@0?ooo`D0Ogmo/P3oool8
04M7Am40oooo2P1EEEGo0?ooofX0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0403oool503Ph>0X0Ogmo100h>3RK0?ooo`T0AdM7IP3ooolD05EEEE00oooo3`1EEEGo0?oo
og@0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool07`3oool907moOb40
>3PhJP3oool;04M7Af40oooo3P1EEEDD0?oooaP0EEEE9`3ooolA05EEEOl0ooooP`3oool00`000000
oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0X0?ooo`T0Ogmo603ooolV03Ph>3T0oooo
2`17AdMN0?ooo`h0EEEE>P3ooolW05EEEOl0ooooU03oool00`000000oooo0?ooo`0`0?ooo`00A@3o
ool00`000000oooo0?ooo`0a0?ooo`X0Ogmo=03ooolI03Ph>1D0oooo2`17AdMM0?ooo``0EEEEo`3o
oonh0?ooo`P0>3Ph203oool=03Ph>0<0oooo3`0h>3PL0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo03/0oooo2@1oOgm40?ooo`X0>3Ph2`17AdML0?ooo``0EEEE@`3ooolh
03Ph>7h0oooo3`0h>3P]0?oooaT0>3Ph6`3oool303Ph>0@0ooooD`0h>3P80?ooo`P0>3Ph3@3oool3
03Ph>0l0oooo2P0h>3PB0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
04@0oooo2P1oOgli0?ooo`/0AdM70`3oool=03Ph>4D0oooo4P1EEEE20?ooo`d0>3Ph>03oool@03Ph
>5d0oooo4@0h>3P?0?ooobd0>3Ph6@3ooolK03Ph>0<0oooo100h>3RN0?ooo`030000003oool0oooo
0300oooo00150?ooo`030000003oool0oooo04h0oooo2@1oOgl>0?ooob80AdM76`3oool>03Ph>1l0
oooo601EEEDo0?oooaD0>3PhE@3ooolM03Ph>1P0oooo:00h>3So0?ooobL0oooo00<000000?ooo`3o
ool0<03oool004D0oooo00<000000?ooo`3oool0;@3ooolL04M7A`h0EEEE2P1oOgm^05EEE@`0oooo
B`0h>3R70?oooaP0>3Pho`3ooom?0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0100oooo>@1EEEDH0?ooo`T0OgmoD`3ooolN03Ph>?l0ooooo`3ooolj0?ooo`030000003o
ool0oooo0300oooo00150?ooo`030000003oool0oooo06X0oooo2@1oOgoo0?ooool0ooooXP3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`1c0?ooo`X0Ogmoo`3ooooo0?oo
oiP0oooo00<000000?ooo`3oool0<03oool004D0oooo1000001l0?ooo`d0Ogmoo`3ooooo0?ooohP0
oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`2:0?oooa00Ogmoo`3ooooo0?ooog/0oooo
00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0VP3ooolA07moOol0ooooo`3o
oomZ0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0:/0oooo401oOgoo
0?ooool0ooooFP3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`2k0?oo
oa@0Ogmoo`3ooooo0?ooodH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3o
ool0c`3ooolH07moOo@0oooo:P0L71ad0?ooo`L03Ph>1`3oool:00h>3Pd0oooo1@0>3Ph?0?ooo`@0
3Ph>0`3oool<01`L71<03Ph>9P0L71`E0?ooo`030000003oool0oooo0300oooo00150?ooo`030000
003oool0oooo0>L0oooo7P1oOgo;0?ooo`/071`L:P3ooolX01`L70d0oooo1@0L71`D0?ooo`@071`L
3P3oool801`L70030?ooo`0>3Ph03Ph>00T03Ph>103oooll01`L70<03Ph>2@3ooolC01`L70L0oooo
7`0>3Ph301`L7180oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
ool60?ooob40OgmoB03ooola01`L70h0oooo8`0L71`f0?ooo`L03Ph>803oool=01`L70D03Ph>500L
71`400h>3Ph071`L200>3Ph@01`L79H0oooo00<000000?ooo`3oool0<03oool004D0oooo00<00000
0?ooo`3oool0403oool902XZ:_l0oooo3P3ooom707moO`0301`L700>3Ph03Ph>01003Ph>303oool8
00h>3P/0oooo3P0L71aA0?ooo`P03Ph>1`3ooolW00h>3]l0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool06@3oool@02XZ:_l0oooo<@3oool701`L70030?ooo`0>3Ph03Ph>
00X03Ph>H`1oOglM0?oooa403Ph>o`3ooolF0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo02T0oooo400Z:RYZ0?ooobP071`LF`3ooolK01`L7140oooo1`0L71`30?ooo`D0
3Ph>C03ooolS00h>3//0OgmoN03oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo
0?ooo`0i0?oooa00:RXZ;`3ooomS075aL@`0oooo5@0Z:RXB0?oooaP071`L6`3ooolA01`L70@0oooo
1P0>3Pko0?oood00ooooIP1oOglB0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo04T0oooo400Z:RX<0?oooa<0LG5a00<071`L0?ooo`3oool0E03oool<02XZ:RX0LG5a2@0Z
:RXO0?oooa@03Ph>403oool500h>3P<0oooo501aLG7o0?ooojL0oooo00<000000?ooo`3oool0<03o
ool004D0oooo00<000000?ooo`3oool0DP3ooolC075aL@@0:RXZBP3ooolL02XZ:Q`0oooo4@0L71`9
0?oooe@0LG5a503ooolC075aLA40oooo3P1aLG4>0?ooobd0LG5a4`3ooolH075aLJX0oooo1@1aLG4=
0?ooobl0LG5a1P3oool00`1aLG40oooo0?ooo`0J0?ooo`030000003oool0oooo0300oooo00150?oo
o`030000003oool0oooo0400oooo4P1aLG4701`L7100oooo400Z:RXI0?ooob40:RXZJ@0>3Ph:02XZ
:UX0oooo4@1aLG4>0?ooo`h0LG5a;@3ooolC075aL@T0oooo3`0Z:RYO075aL@D0:RXZ201aLG480?oo
o`<0:RXZ00@0oooo075aL@1aLG40LG5a3P0Z:RXQ075aL@D0:RXZ3@1aLG4_02XZ:PH0LG5a00<0oooo
075aL@1aLG40201aLG4B0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0100oooo7@0>3PhC075aL@T071`L<00>3PhI02XZ:Q403Ph>P`3oool:02XZ:XX0oooo:P0Z:RX90?oo
o`T0:RXZ7P3ooolJ02XZ:SH0oooo1@1aLG4802XZ:P`0LG5a0`0Z:RX>075aLF@0oooo3@0Z:RXD0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo01X0oooo4`1aLG4<01`L7?L0
ooooRP0Z:R[o0?oooeX0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0
403oool:075aL@l071`Lo`3ooooo0?ooon`0oooo00<000000?ooo`3oool0<03oool004D0oooo00<0
00000?ooo`3oool0403oool901`L7?l0ooooo`3ooool0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0<03oool0
04D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0`0?oo
o`00A@3oool400000?l0ooooo`3ooooo0?oooa80oooo1000000b0?ooo`00A@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003o
ool0oooo0;<0oooo701SHf=G0?oooa/0Hf=So`3ooooC0?ooo`030000003oool0oooo0300oooo0015
0?ooo`030000003oool0oooo0980oooo8@1SHf<L0?oooaP0Hf=S7P3ooolQ06=SHa/0oooo4`1SHf<O
0?ooo`d0Hf=So`3ooonD0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
06l0oooo8`1SHf=E0?oooah0Hf=SC`3oool:06=SH`/0oooo2P1SHf<=0?oooal0Hf=SCP3oool806=S
Ha40oooo1`1SHf=/0?ooodh0Hf=S8@3ooolI06=SHa80oooo00<000000?ooo`3oool0<03oool004D0
oooo00<000000?ooo`3oool0B@3ooolV06=SHnl0oooo2`1SHf<f0?ooo`h0Hf=S;P3ooolB06=SH`P0
oooo4@1SHf<70?ooof`0Hf=SCP3ooolQ06=SHb/0oooo00<000000?ooo`3oool0<03oool004D0oooo
00<000000?ooo`3oool08`3ooolV06=SHol0ooooI@3oool^06=SHol0oooo>@3oool00`000000oooo
0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0@0?oooa<0Hf=So`3ooooo0?oooo80oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool400000?l0ooooo`3ooooo0?oooa80
oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00:@3oool2000000@0oooo0P0000040?ooo`80
00003P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo00/0
oooo0P0000040?ooo`800000103oool2000001L0oooo000X0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool600000?l0ooooo`3ooooo0?ooo`h0oooo1P00000<0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000005P3oool002P0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?oooaH0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo01@0oooo000X0?ooo`040000003oool0oooo000000T0oooo0P00000>0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`0000090?ooo`8000005`3oool002P0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01H0oooo000Y0?ooo`80
00002P3oool3000000d0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000
oooo0?ooo`0;0?ooo`8000002P3oool3000001H0oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo1000003o0?ooool0
ooooo`3ooolB0?ooo`@00000<P3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool400000?l0ooooo`3ooooo
0?oooa80oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolF0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?oooaH0oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo5P3oool00`000000oooo0?ooo`0`0?ooo`00A@3oool400000?l0ooooo`3ooooo0?oooa80
oooo1000000b0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000
003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<0
00000?ooo`3oool0<03oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool0
0`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?oo
o`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool0<03oool004D0oooo1000003o0?ooool0ooooo`3ooolB0?ooo`@00000
<P3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?oo
o`0`0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolF0?ooo`030000003oool0
oooo0300oooo00150?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?oo
o`3oool0<03oool003@0oooo1@00000<0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<000000?ooo`3oool02P3oool500000240oooo000f0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0240oooo000f0?ooo`030000003oool0oooo00`0oooo1P00003o0?ooool0ooooo`3o
ool>0?ooo`H000003P3oool00`000000oooo0?ooo`0Q0?ooo`00=P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0Q0?ooo`00=P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Q0?oo
o`00=@3oool2000000h0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`000000
oooo0?ooo`0;0?ooo`8000008`3oool004D0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0300oooo00150?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0`0?ooo`00A@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0<03oool004D0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0300oooo00150?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0`0?ooo`00
A@3ooooo00000?l00000o`00000J00000380oooo003o0?ooool0ooooo`3ooonA0?ooo`00o`3ooooo
0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0ooooo`3ooonA0?ooo`00
o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0ooooo`3ooonA
0?ooo`00o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?ooool0oooo
o`3ooonA0?ooo`00o`3ooooo0?ooool0ooooT@3oool00?l0ooooo`3ooooo0?oooi40oooo003o0?oo
ool0ooooo`3ooonA0?ooo`00o`3ooooo0?ooool0ooooT@3oool004d0oooo1@0000020?ooo`800000
103oool2000000@0oooo0P00001L0?ooo`@000000`3oool2000000@0oooo0P0000040?ooo`800000
PP3oool2000000@0oooo0P0000040?ooo`800000103oool2000005T0oooo1@0000020?ooo`800000
103oool2000000@0oooo0P0000040?ooo`800000EP3oool4000000<0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P00001l0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
103oool200000500oooo1@0000020?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P00000c0?ooo`00C`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000P03oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
001J0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000NP3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000540oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0=P3oool004l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000008<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0F03oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000007d0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`1?0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03H0oooo001?0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0F`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
07l0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00001J0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`1E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`1i0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001A0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo03H0oooo001?0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0F@3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000210?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000005X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo05<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001k0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000D@3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0f0?ooo`00CP3oool2000000@0oooo0P0000040?ooo`800000103oool2000005d0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000220?ooo`<000000`3oool2000000@0oooo0P000004
0?ooo`800000FP3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001G
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000007`0oooo0`000003
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000D@3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000>@3oool00?l0ooooo`3ooooo0?oo
oi40oooo003o0?ooool0ooooo`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 909}, {454, 0}} -> {2.76615, -3.57966, 0.00265666, \
0.00847972}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "rsteinig", "notebooks"}, \
"ljapunov_4er.nb.ps", CharacterEncoding -> "WindowsANSI"],
"Magnification"->1},
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 32, 0, 53, "Section"],
Cell[1774, 53, 50, 1, 30, "Input"],
Cell[1827, 56, 52, 0, 33, "Text"],
Cell[1882, 58, 150, 4, 30, "Input"],
Cell[2035, 64, 60, 0, 33, "Text"],
Cell[2098, 66, 151, 4, 30, "Input"],
Cell[2252, 72, 97, 2, 33, "Text"],
Cell[2352, 76, 180, 4, 30, "Input"],
Cell[2535, 82, 62, 0, 33, "Text"],
Cell[2600, 84, 147, 4, 30, "Input"],
Cell[2750, 90, 51, 0, 33, "Text"],
Cell[2804, 92, 259, 6, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3100, 103, 65, 0, 69, "Title"],

Cell[CellGroupData[{
Cell[3190, 107, 31, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[3246, 111, 29, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[3300, 115, 31, 0, 43, "Subsubsection"],
Cell[3334, 117, 62, 0, 33, "Text"],
Cell[3399, 119, 696, 16, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4132, 140, 30, 0, 43, "Subsubsection"],
Cell[4165, 142, 67, 0, 33, "Text"],
Cell[4235, 144, 510, 11, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4782, 160, 31, 0, 43, "Subsubsection"],
Cell[4816, 162, 62, 0, 33, "Text"],
Cell[4881, 164, 377, 9, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5295, 178, 32, 0, 43, "Subsubsection"],
Cell[5330, 180, 3660, 63, 730, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9039, 249, 36, 0, 47, "Subsection"],
Cell[9078, 251, 396, 9, 70, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9523, 266, 38, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[9586, 270, 36, 0, 47, "Subsection"],
Cell[9625, 272, 137, 3, 33, "Text"],
Cell[9765, 277, 679, 14, 110, "Input"],
Cell[10447, 293, 483, 9, 75, "Text"],
Cell[10933, 304, 796, 16, 130, "Input"],
Cell[11732, 322, 68, 0, 33, "Text"],
Cell[11803, 324, 818, 19, 130, "Input"],
Cell[12624, 345, 60, 0, 33, "Text"],
Cell[12687, 347, 554, 12, 110, "Input"],
Cell[13244, 361, 490, 11, 110, "Input"],
Cell[13737, 374, 812, 17, 110, "Input"],
Cell[14552, 393, 83, 1, 33, "Text"],
Cell[14638, 396, 703, 15, 130, "Input"],
Cell[15344, 413, 72, 0, 33, "Text"],
Cell[15419, 415, 357, 8, 70, "Input"],
Cell[15779, 425, 87, 1, 33, "Text"],
Cell[15869, 428, 746, 15, 190, "Input"],
Cell[16618, 445, 399, 8, 52, "Text"],
Cell[17020, 455, 126, 2, 44, "Text"],
Cell[17149, 459, 751, 18, 110, "Input"],
Cell[17903, 479, 133, 3, 33, "Text"],
Cell[18039, 484, 206, 4, 32, "Text"],
Cell[18248, 490, 1145, 24, 170, "Input"],
Cell[19396, 516, 94, 2, 33, "Text"],
Cell[19493, 520, 553, 12, 130, "Input"],
Cell[20049, 534, 73, 0, 33, "Text"],
Cell[20125, 536, 681, 17, 110, "Input"],
Cell[20809, 555, 73, 0, 33, "Text"],
Cell[20885, 557, 773, 18, 150, "Input"],
Cell[21661, 577, 155, 3, 33, "Text"],
Cell[21819, 582, 755, 18, 150, "Input"],
Cell[22577, 602, 89, 2, 33, "Text"],
Cell[22669, 606, 1202, 26, 170, "Input"],
Cell[23874, 634, 89, 2, 33, "Text"],
Cell[23966, 638, 606, 13, 130, "Input"],
Cell[24575, 653, 75, 0, 33, "Text"],
Cell[24653, 655, 1745, 32, 290, "Input"],
Cell[26401, 689, 94, 2, 33, "Text"],
Cell[26498, 693, 852, 19, 110, "Input"],
Cell[27353, 714, 97, 2, 33, "Text"],
Cell[27453, 718, 1809, 39, 330, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29299, 762, 35, 0, 31, "Subsection"],
Cell[29337, 764, 105, 3, 33, "Text"],
Cell[29445, 769, 14457, 284, 1250, "Input"],
Cell[43905, 1055, 3949, 102, 171, "Input"],

Cell[CellGroupData[{
Cell[47879, 1161, 1048, 31, 90, "Input"],
Cell[48930, 1194, 146795, 4959, 463, 71352, 4023, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

